@@ -1227,6 +1227,7 @@ class FilesHooks {
 			$affectedUsers[$mount->getUser()->getUID()] = $this->getVisiblePath($mount->getPath());
 			$cachedMounts[] = [
 				'userId' => $mount->getUser()->getUID(),
+				'provider' => str_replace('\\\\', '\\', $mount->getMountProvider()),
 				'path' => $mount->getPath(),
 				'visiblePath' => $this->getVisiblePath($mount->getPath()),
 				'storageId' => $mount->getStorageId()
@@ -1234,6 +1235,7 @@ class FilesHooks {
 		}
 
 		$unrelatedUsers = $this->getUnrelatedUsers($fileId, $cachedMounts);
+
 		return array_filter($affectedUsers, function ($userId) use ($unrelatedUsers): bool {
 			return !in_array($userId, $unrelatedUsers);
 		}, ARRAY_FILTER_USE_KEY);
@@ -1250,8 +1252,10 @@ class FilesHooks {
 	 */
 	private function getUnrelatedUsers(int $fileId, array $cachedMounts): array {
 		/** @var \OCA\GroupFolders\ACL\RuleManager $ruleManager */
+		/** @var \OCA\GroupFolders\Folder\FolderManager $folderManager */
 		try {
 			$ruleManager = \OC::$server->get(\OCA\GroupFolders\ACL\RuleManager::class);
+			$folderManager = \OC::$server->get(\OCA\GroupFolders\Folder\FolderManager::class);
 		} catch (\Exception $e) {
 			return []; // if we have no access to RuleManager, we cannot filter unrelated users
 		}
@@ -1259,6 +1263,10 @@ class FilesHooks {
 		/** @var \OCA\GroupFolders\ACL\Rule[] $rules */
 		$rules = $knownRules = $knownGroupRules = $usersToCheck = $cachedPath = [];
 		foreach ($cachedMounts as $cachedMount) {
+			// we are only interested in filtering GroupFolders ACL
+			if ($cachedMount['provider'] !== 'OCA\GroupFolders\Mount\MountProvider') {
+				continue;
+			}
 
 			// caching rules based on storage id
 			$storageId = $cachedMount['storageId'];
@@ -1275,14 +1283,14 @@ class FilesHooks {
 					$node = $this->rootFolder->get($fullPath);
 					$mountPoint = $node->getMountPoint();
 
-					if (!$mountPoint instanceof \OCA\GroupFolders\Mount\GroupMountPoint) {
-						continue;
+					if (!$mountPoint instanceof \OCA\GroupFolders\Mount\GroupMountPoint
+						|| !$folderManager->getFolderAclEnabled($mountPoint->getFolderId())) {
+						continue; // acl are disable
 					}
 
-					$folderPath = trim($mountPoint->getSourcePath(), '/');
+					$folderPath = $mountPoint->getSourcePath();
 					$path = substr($fullPath, strlen($mountPoint->getMountPoint()));
 				} catch (\Exception $e) {
-
 					// in case of issue during the process, we can imagine the user have no access to the file
 					$usersToCheck[] = $cachedMount['userId'];
 					continue; // we'll catch rules on next user with access to the file
@@ -1351,6 +1359,7 @@ class FilesHooks {
 			}
 		}
 
+
 		// now that we have a list of eventuals filtered users, we confirm they have no access to the file
 		$filteredUsers = [];
 		foreach ($usersToCheck as $userId) {
