@@ -72,33 +72,50 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} 님이 {circle} 가입 요청을 보냄",
     "You are the new owner of {circle}" : "여러분이 {circle}의 새 소유자가 됨",
     "{member} is the new owner of {circle}" : "{member} 님이 {circle}의 새 소유자가 됨",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "소속된 <strong>서클</strong>에서 일어나는 이벤트",
     "Any important event in a <strong>Circle</strong> you are moderating" : "관리하는 <strong>서클</strong>의 중요한 이벤트",
     "Personal" : "개인",
     "System" : "시스템",
     "Visible" : "보임",
     "Open" : "열기",
+    "Invite" : "초대",
+    "Join Request" : "요청 참여",
+    "Friends" : "친구",
+    "Password Protected" : "암호로 보호됨",
+    "No Owner" : "소유자 없음",
     "Hidden" : "숨겨짐",
+    "Backend" : "백엔드",
     "Local" : "로컬",
     "Root" : "루트",
+    "Circle Invite" : "서클 초대",
     "Federated" : "연합",
+    "Nextcloud Account" : "Nextcloud 계정",
+    "Nextcloud Group" : "Nextcloud 그룹",
+    "Email Address" : "이메일 주소",
     "Contact" : "연락처",
     "Circle" : "서클",
+    "Nextcloud App" : "Nextcloud 앱",
     "Member" : "회원",
     "Moderator" : "중재자",
     "Admin" : "관리자",
     "Owner" : "소유자",
     "%s shared »%s« with you." : "%s 님이 \"%s\"을(를) 공유했습니다.",
+    "%s shared »%s« with \"%s\"." : "%s 님이 »%s«을(를) \"%s\"와(과) 공유했습니다.",
     "%s on %s" : "%s(%s의)",
     "Password to access »%s«" : "%s에 접근할 수 있는 암호",
     "It is protected with the following password:" : "비밀번호로 보호됩니다.",
     "%1$s via %2$s" : "%1$s(%2$s 경유)",
     "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
     "Open »%s«" : "%s 열기",
+    "Password to access files shared to you by %1$s" : "%1$s님이 공유한 파일에 접근하기 위한 암호",
+    "Password to access files" : "파일에 접근하기 위한 암호",
+    "%s shared multiple files with \"%s\"." : "%s님이 \"%s\"와(과) 여러 파일을 공유했습니다.",
+    "%s shared multiple files with you." : "%s님이 여러 파일을 공유했습니다.",
+    "Testing Basic Circle Creation" : "기본 서클 생성 테스트 중",
     "Circle not found" : "서클을 찾을 수 없음",
-    "A circle with that name exists" : "같은 이름의 서클이 이미 존재함",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "시스템 관리자가 서클 형식을 허용하지 않는 한 서클 앱을 사용할 수 없습니다",
+    "Circle not found " : "서클을 찾을 수 없음",
     "This member does not exist" : "이 회원이 존재하지 않음",
-    "This user is already a member of the circle" : "이 사용자가 이미 서클 회원임",
+    "This account is already a member of the circle" : "이 계정은 이미 서클 회원임",
     "Federated link not found" : "연합 연결을 찾을 수 없음",
     "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
     "The circle is not federated" : "연합 서클이 아님",
@@ -109,28 +126,51 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
     "You are already a member of this circle" : "이미 서클 회원임",
     "You have been blocked from this circle" : "이 서클에서 차단됨",
-    "The user is already a member of this circle" : "이 사용자가 이미 서클 회원임",
-    "The user has already been invited into this circle" : "이 사용자를 이미 서클에 초대함",
+    "The account is already a member of this circle" : "이 계정은 이미 이 서클의 회원임",
+    "The account has already been invited into this circle" : "이 계정을 이미 이 서클에 초대함",
+    "%s (Circle owned by %s)" : "%s (%s이(가) 소유한 서클)",
+    "You are now a member of the Circle \"%2$s\"" : "당신은 이제 서클 \"%2$s\"의 회원입니다",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s님이 당신을 서클 \"%2$s\"에 초대했습니다",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s님이 당신에게 서클 \"%2$s\"의 회원이 될 것을 요청했습니다",
     "Accept" : "수락",
+    "Leave the circle" : "서클 떠나기",
     "%s" : "%s",
     "Personal Circle" : "개인 서클",
+    "%s owned by %s" : "%s이(가) 소유한 %s",
     "You need a specify a type of circle" : "서클 형식을 지정해야 함",
+    "A circle with that name exists" : "같은 이름의 서클이 이미 존재함",
     "This member is not the owner of the circle" : "이 회원은 서클 소유자가 아님",
     "This member is not an admin of the circle" : "이 회원은 서클 관리자가 아님",
+    "Group contains too many members" : "그룹에 너무 많은 회원이 있음",
     "This group does not exist" : "이 그룹이 존재하지 않음",
     "This group is already linked to the circle" : "이 그룹이 서클에 이미 연결됨",
     "You cannot edit level in a personal circle" : "개인 서클의 단계를 편집할 수 없음",
     "Group cannot be set as owner of a circle" : "그룹을 서클 소유자로 설정할 수 없음",
     "now" : "현재",
-    "This user does not exist" : "이 사용자가 존재하지 않음",
+    "This account does not exist" : "계정이 존재하지 않음",
     "Email format is not valid" : "이메일 주소가 올바르지 않음",
     "This contact is not available" : "이 연락처를 사용할 수 없음",
-    "Could not find share" : "공유를 찾을 수 없음",
+    "You have no permission to create a new circle" : "새 서클 생성 권한이 없음",
+    "%s shared a file with \"%s\"." : "%s님이 \"%s\"에게 파일을 공유했습니다.",
+    "%s shared a file with you." : "%s님이 파일을 공유했습니다.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s님이 공유한 것이 있습니다. \n함께 발송한 별도의 이메일에서 링크를 눌러 이 공유에 접근하십시오.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s님이 공유한 것이 있습니다.\n함께 발송한 별도의 이메일에서 링크를 눌로 이 공유에 접근하십시오.",
+    "Password to access content shared with you by %1$s" : "%1$s님의 공유에 접근하기 위한 암호",
+    "This item is already shared with this circle" : "이 항목은 이 서클에 이미 공유했습니다",
     "Bring cloud-users closer together." : "클라우드 사용자를 더 가깝게 연결합니다.",
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "서클을 통해 누구나 동료/친구 등 다양한 그룹을 생성할 수 있습니다.\n이 집단(서클)은 다른 앱에서도 공유의 단위로 사용할 수 있습니다.",
     "No files in here" : "여기에 파일 없음",
     "No entries found in this folder" : "이 폴더에서 항목을 찾을 수 없음",
     "Name" : "이름",
     "Size" : "크기",
-    "Modified" : "수정한 날짜"
+    "Modified" : "수정한 날짜",
+    "Nextcloud User" : "Nextcloud 사용자",
+    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "시스템 관리자가 서클 형식을 허용하지 않는 한 서클 앱을 사용할 수 없습니다",
+    "This user is already a member of the circle" : "이 사용자가 이미 서클 회원임",
+    "The user is already a member of this circle" : "이 사용자가 이미 서클 회원임",
+    "The user has already been invited into this circle" : "이 사용자를 이미 서클에 초대함",
+    "This user does not exist" : "이 사용자가 존재하지 않음",
+    "Could not find share" : "공유를 찾을 수 없음",
+    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "서클을 통해 누구나 동료/친구 등 다양한 그룹을 생성할 수 있습니다.\n이 집단(서클)은 다른 앱에서도 공유의 단위로 사용할 수 있습니다."
 },
 "nplurals=1; plural=0;");
