@@ -72,31 +72,61 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} sendte et ønske om å få bli med i {circle}",
     "You are the new owner of {circle}" : "Du er den nye eieren av {circle}",
     "{member} is the new owner of {circle}" : "{member} er den nye eieren av {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "På hendelser som skjer i en <strong>sirkel</strong> hvor du er medlem",
     "Any important event in a <strong>Circle</strong> you are moderating" : "Ønsker du å bli varslet om hendelser i <strong>sirkler</strong> du modererer?",
+    "On global events happening in any <strong>Circle</strong>" : "På global hendelse som skjer i en <strong>sirkel</strong>",
+    "Single" : "Enkel",
     "Personal" : "Personlig",
     "System" : "System",
     "Visible" : "Synlig",
     "Open" : "Åpne",
     "Invite" : "Invitere",
+    "Join Request" : "Forespørsel om å delta",
+    "Friends" : "Venner",
+    "Password Protected" : "Passordbeskyttet",
+    "No Owner" : "Ingen eier",
     "Hidden" : "Skjult",
     "Local" : "Lokal",
     "Root" : "Rot",
+    "Circle Invite" : "Sirkel-invitasjo",
     "Federated" : "Sammenknyttet",
+    "Mount point" : "Monteringspunkt",
+    "Nextcloud Account" : "Nextcloud-konto",
+    "Nextcloud Group" : "Nextcloud-gruppe",
+    "Email Address" : "Epostadresse",
     "Contact" : "Kontakt",
     "Circle" : "Sirkel",
+    "Nextcloud App" : "Nextcloud-app",
     "Member" : "Medlem",
     "Moderator" : "Moderator",
     "Admin" : "Admin",
     "Owner" : "Eier",
     "%s shared »%s« with you." : "%s delte »%s« med deg.",
+    "%s shared »%s« with \"%s\"." : "%s delte »%s« med \"%s\".",
     "%s on %s" : "%s på %s",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte »%2$s« med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s delte »%2$s« med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
+    "Password to access »%1$s« shared to you by %2$s" : "Passord for tilgang til »%1$s« delt med deg av %2$s",
     "Password to access »%s«" : "Passord for å benytte »%s«",
     "It is protected with the following password:" : "Den er beskyttet med følgende passord:",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Click the button below to open it." : "Klikk på knappen nedenfor for å åpne den.",
     "Open »%s«" : "Åpne \"%s\"",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s delte flere filer med deg.\nDu bør allerede ha mottatt en separat epost med en link for å få tilgang til det.\n",
+    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s shared multiple files with you. You should have already received a separate email with a link to access them.",
+    "Password to access files shared to you by %1$s" : "Passord for tilgang til filene som ble delt av %1$s",
+    "Password to access files" : "Passord for tilgang til filer.",
+    "%s shared multiple files with \"%s\"." : "%s delte flere filer med \"%s\".",
+    "%s shared multiple files with you." : "%s delte flere filer med deg.",
+    "Boot up" : "Start opp",
+    "Fresh installation status" : "Status på fersk installasjon",
+    "Building Local Database" : "Bygger lokal database",
+    "Testing Basic Circle Creation" : "Tester opprettelse av grunnleggende sirkel",
+    "Adding local users and moderators" : "Legger til lokale brukere og moderatorer",
     "Circle not found" : "Fant ikke sirkelen",
+    "Circle not found " : "Fant ikke sirkelen",
     "This member does not exist" : "Dette medlemmet finnes ikke",
+    "This account is already a member of the circle" : "Denne kontoen er allerede medlem av sirkelen",
     "Federated link not found" : "Fant ikke den sammenknyttede lenken",
     "This feature is not available for personal circles" : "Funksjonen er ikke tilgjengelig for personlige sirkler",
     "The circle is not federated" : "Sirkelen er ikke sammenknyttet",
@@ -107,26 +137,44 @@ OC.L10N.register(
     "Level cannot be changed for this type of member" : "Nivået kan ikke endres for den typen medlem",
     "You are already a member of this circle" : "Du er allerede medlem av denne sirkelen",
     "You have been blocked from this circle" : "Du har blitt blokkert fra denne sirkelen",
+    "The account is already a member of this circle" : "Denne kontoren er allerede medlem av sirkelen",
+    "The account has already been invited into this circle" : "Denne kontoen har allerede blitt invitert til denne sirkelen",
+    "%s (Circle owned by %s)" : "%s (Sirkelen eies av %s)",
+    "You are now a member of the Circle \"%2$s\"" : "Du er nå medlem av sirkelen \"%2$s\"",
+    "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blitt invitert av %1$s til sirkelen \"%2$s\"",
+    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendte en forespørsel om å bli medlem av sirkelen \"%2$s\"",
     "Accept" : "Aksepter",
+    "Refuse" : "Avvis",
+    "Leave the circle" : "Forlat sirkelen",
     "%s" : "%s",
     "Personal Circle" : "Personlig sirkel",
+    "%s owned by %s" : "%s eid av %s",
     "You need a specify a type of circle" : "Du må oppgi sirkeltype",
     "A circle with that name exists" : "En sirkel med det navnet finnes",
     "This member is not the owner of the circle" : "Dette medlemmet eier ikke denne sirkelen",
     "This member is not an admin of the circle" : "Dette medlemmet er ikke administrator av sirkelen",
+    "Group contains too many members" : "Gruppen inneholder for mange medlemmer",
     "This group does not exist" : "Denne gruppen finnes ikke",
     "This group is already linked to the circle" : "Gruppen er allerede lenket til sirkelen",
     "You cannot edit level in a personal circle" : "Du kan ikke endre nivå i en personlig sirkel",
     "Group cannot be set as owner of a circle" : "Gruppe kan ikke settes som eier av en sirkel",
     "now" : "nå",
+    "This account does not exist" : "Denne kontoen finnes ikke",
     "Email format is not valid" : "E-postadressen er ikke gyldig",
     "This contact is not available" : "Denne kontakten er ikke tilgjengelig",
+    "You have no permission to create a new circle" : "Du har ikke tilgang til å opprette ny sirkel",
+    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
+    "%s shared a file with you." : "%s delte en fil med deg.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delte innhold med deg.\nDu bør allerede ha mottatt en separat epist med en link for å få tilgang til det.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delte innhold med deg. Du bør allerede ha mottatt en separat epost med en link for å få tilgang til det.",
     "Bring cloud-users closer together." : "Bring sky-brukere nærmere hverandre.",
     "No files in here" : "Ingen filer her",
     "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
     "Name" : "Navn",
     "Size" : "Størrelse",
     "Modified" : "Endret",
+    "Initialisation Nextcloud" : "Forbereder Nextcloud",
+    "Initialisation Circles App" : "Forbereder Sirkel-app",
     "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kan ikke bruke sirkel-appen før administratoren din har tillat minst én type sirkler",
     "This user is already a member of the circle" : "Denne brukeren er allerede medlem av sirkelen",
     "The user is already a member of this circle" : "Brukeren er allerede medlem av denne sirkelen",
