@@ -44,7 +44,7 @@ OC.L10N.register(
     "{external} has been added to {circle} by {author}" : "{external} je avtor {author} dodal v članstvo kroga {circle}.",
     "You accepted {member}'s request to join {circle}" : "Sprejeli ste prošnjo člana {member} za pristop v krog {circle}",
     "Your request to join {circle} has been accepted by {author}" : "{author} sprejme vašo prošnjo za članstvo v krogu {circle}",
-    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu  {circle}",
+    "{member}'s request to join {circle} has been accepted by {author}" : "{author} sprejme prošnjo člana {member} za članstvo v krogu {circle}",
     "You left {circle}" : "Zapustite krog {circle}",
     "{member} left {circle}" : "{member} zapusti krog {circle}",
     "You declined the invitation to join {circle}" : "Zavrnete vabilo v krog {circle}",
@@ -105,21 +105,22 @@ OC.L10N.register(
     "%s shared »%s« with you." : "%s vam omogoča souporabo »%s«.",
     "%s shared »%s« with \"%s\"." : "%s omogoči souporabo »%s« z »%s«.",
     "%s on %s" : "%s na %s",
-    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nMorali bi že prejeti ločeno sporočilo s povezavo po elektronski pošti.\n",
-    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nMorali bi že prejeti ločeno sporočilo s povezavo po elektronski pošti.",
+    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
+    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoči souporabo »%2$s«.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
     "Password to access »%1$s« shared to you by %2$s" : "%2$s vam pošilja geslo za dostop do datoteke »%1$s«.",
     "Password to access »%s«" : "Geslo za dostop do »%s«",
     "It is protected with the following password:" : "Zaščiten je z geslom:",
     "%1$s via %2$s" : "%1$s prek %2$s",
     "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
     "Open »%s«" : "Odpri »%s«",
-    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi morali prejeti tudi sporočilo s povezavo.\n",
-    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi morali prejeti tudi sporočilo s povezavo.",
+    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s vam omogoča souporabo več datotek.\nPo elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.\n",
+    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s vam omogoča souporabo več datotek. Po elektronski pošti bi že morali prejeti ločeno sporočilo s povezavo.",
     "Password to access files shared to you by %1$s" : "%1$s vam pošilja geslo za dostop do datoteke v souporabi.",
     "Password to access files" : "Geslo za dostop do datotek",
-    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom \"%s\".",
+    "%s shared multiple files with \"%s\"." : "%s omogoči souporabo več datotek z uporabnikom »%s«.",
     "%s shared multiple files with you." : "%s vam omogoči souporabo več datotek.",
     "Boot up" : "Zaganjanje",
+    "Nextcloud Initialization" : "Zaganjanje oblaka Nextcloud",
     "Fresh installation status" : "Stanje sveže namestitve",
     "Building Local Database" : "Poteka izgradnja krajevne podatkovne zbirke",
     "Testing Basic Circle Creation" : "Preizkušanje ustvarjanja osnovnega kroga",
@@ -164,8 +165,8 @@ OC.L10N.register(
     "Email format is not valid" : "Zapis elektronskega naslova ni veljaven",
     "This contact is not available" : "Ta stik ni na voljo.",
     "You have no permission to create a new circle" : "Ni ustreznih dovoljenj za ustvarjanje novega kroga.",
-    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z \"%s\".",
-    "%s shared a file with you." : "%s omogoča souporabo datoteke z vami.",
+    "%s shared a file with \"%s\"." : "%s omogoča souporabo datoteke z »%s«.",
+    "%s shared a file with you." : "%s vam omogoča souporabo datoteke.",
     "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s vam omogoča souporabo vsebine.\nMorali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.\n",
     "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s vam omogoča souporabo vsebine. Morali bi že prejeti ločeno sporočilo s povezavo za dostop po elektronski pošti.",
     "Password to access content shared with you by %1$s" : "%1$s vam pošilja geslo za dostop do vsebine v souporabi.",
