@@ -120,8 +120,7 @@ class DeprecatedListener {
 
 		foreach ($circles as $circle) {
 			// we are only interested in direct membership
-			if (!$circle->hasInitiator()
-				|| $circle->getInitiator()->getSingleId() !== $federatedUser->getSingleId()) {
+			if ($circle->getInitiator()->getSingleId() !== $federatedUser->getSingleId()) {
 				continue;
 			}
 
