@@ -3,7 +3,6 @@ OC.L10N.register(
     {
     "Comments" : "Σχόλια",
     "You commented" : "Σχολιάσατε",
-    "%1$s commented" : "%1$s σχολίασε",
     "{author} commented" : "Ο {author} σχολίασε",
     "You commented on %1$s" : "Σχολιάσατε στο %1$s",
     "You commented on {file}" : "Σχολιάσατε στο {file}",
@@ -28,7 +27,6 @@ OC.L10N.register(
     "Comment deleted" : "Το σχόλιο διαγράφηκε",
     "An error occurred while trying to delete the comment" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια διαγραφής του σχολίου",
     "An error occurred while trying to create the comment" : "Παρουσιάστηκε σφάλμα κατά την προσπάθεια δημιουργίας του σχολίου",
-    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Το όνομά σας αναφέρθηκε στο “{file}”, σε σχόλιο ενός χρήστη ο οποίος έχει πλέον διαγραφεί",
-    "{user} mentioned you in a comment on “{file}”" : "Ο {user} σας ανέφερε σε σχόλιο στο “{file}”"
+    "%1$s commented" : "%1$s σχολίασε"
 },
 "nplurals=2; plural=(n != 1);");
