@@ -8,7 +8,7 @@ OC.L10N.register(
     "You commented on {file}" : "{file} hakkında yorum yaptınız",
     "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
     "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
-    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
+    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorum</strong> yapıldığında",
     "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "\"{file}\" hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
     "{user} mentioned you in a comment on \"{file}\"" : "{user}, \"{file}\" hakkındaki bir yorumda sizi andı",
     "Files app plugin to add comments to files" : "Dosyalara notlar eklenmesini sağlayan dosyalar uygulaması eki",
