@@ -6,4 +6,4 @@ OC.L10N.register(
     "Manages interaction between users and contacts" : "Gerenciar interação entre usuários e contatos",
     "Collect data about user and contacts interactions and provide an address book for the data" : "Coletar dados sobre usuários e interação de contatos e prover um livro de endereços para o dado"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
