@@ -3,7 +3,8 @@ OC.L10N.register(
     {
     "Dashboard" : "Panela",
     "Dashboard app" : "Panela aplikazioa",
-    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Hasi eguna informatuta\n\nNextcloud Panela zure eguneko abiapuntua da, zure hurrengo \nhitzorduen ikuspegi orokorra, premiazko mezu elektronikoak, txat \nmezuak, sarrerako txartelak, azken txioak eta askoz gehiago erakutsiz! \nErabiltzaileek trepetak gehi ditzakete eta atzealdea aldatu nahieran.",
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Hasi zure eguna informatuta\n\nNextcloud Panela da zure eguneko abiapuntua, eta zure hurrengo hitzorduen, premiazko mezu elektronikoen, txat-mezuen, sarrerako txartelen, azken txioen eta askoz gehiagoren ikuspegi orokorra eskaintzen dizu! Erabiltzaileek gogoko trepetak gehi ditzakete eta atzealdea nahieran aldatu.",
+    "\"{title} icon\"" : "\"{title} ikonoa\"",
     "Customize" : "Pertsonalizatu",
     "Edit widgets" : "Editatu trepetak",
     "Get more widgets from the App Store" : "Lortu trepeta (widget) gehiago Aplikazioen Dendatik",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Good evening, {name}" : "Gabon, {name}",
     "Hello" : "Kaixo",
     "Hello, {name}" : "Kaixo, {name}",
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Hasi eguna informatuta\n\nNextcloud Panela zure eguneko abiapuntua da, zure hurrengo \nhitzorduen ikuspegi orokorra, premiazko mezu elektronikoak, txat \nmezuak, sarrerako txartelak, azken txioak eta askoz gehiago erakutsiz! \nErabiltzaileek trepetak gehi ditzakete eta atzealdea aldatu nahieran.",
     "Change background image" : "Aldatu atzeko planoko irudia",
     "Pick from Files" : "Aukeratu fitxategietatik",
     "Default images" : "Irudi lehenetsiak",
