@@ -55,6 +55,7 @@ OC.L10N.register(
     "A calendar <strong>to-do</strong> was modified" : "Eine Kalender-<strong>Aufgabe</strong> wurde geändert",
     "Contact birthdays" : "Geburtstage von Kontakten",
     "Death of %s" : "Todestag von %s",
+    "Untitled calendar" : "Unbenannter Kalender",
     "Calendar:" : "Kalender:",
     "Date:" : "Datum:",
     "Where:" : "Wo:",
@@ -74,6 +75,9 @@ OC.L10N.register(
     "Cancelled: %1$s" : "Abgesagt: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" wurde abgebrochen.",
     "Re: %1$s" : "Re: %1$s",
+    "%1$s has accepted your invitation" : "%1$s hat deine Einladung angenommen.",
+    "%1$s has tentatively accepted your invitation" : "%1$s hat deine Einladung vorläufig angenommen.",
+    "%1$s has declined your invitation" : "%1$s hat deine Einladung abgelehnt.",
     "%1$s has responded to your invitation" : "%1$s hat auf deine Einladung geantwortet.",
     "Invitation updated: %1$s" : "Einladung aktualisiert: %1$s",
     "%1$s updated the event \"%2$s\"" : "%1$s hat die Veranstaltung \"%2$s\" aktualisiert",
