@@ -62,9 +62,6 @@ OC.L10N.register(
     "Birthday calendars will be generated by a background job." : "Los calendarios de cumpleaños serán generados por un trabajo de segundo plano",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Por lo tanto no estarán disponbiles inmediatamente después de habilitarlos pero se mostrarán después de un tiempo.",
     "Hello %s," : "Hola %s,",
-    "When:" : "Cuándo:",
-    "Technical details" : "Detalles técnicos",
-    "Remote Address: %s" : "Dirección remota: %s",
-    "Request ID: %s" : "ID de solicitud: %s"
+    "When:" : "Cuándo:"
 },
 "nplurals=2; plural=(n != 1);");
