@@ -55,6 +55,7 @@ OC.L10N.register(
     "A calendar <strong>to-do</strong> was modified" : "Egutegi baten <strong>egiteko</strong> bat aldatu da",
     "Contact birthdays" : "Kontaktuen urtebetetzeak",
     "Death of %s" : "%s(r)en heriotza",
+    "Untitled calendar" : "Izenik gabeko egutegia",
     "Calendar:" : "Egutegia:",
     "Date:" : "Data:",
     "Where:" : "Non:",
@@ -74,6 +75,9 @@ OC.L10N.register(
     "Cancelled: %1$s" : "Utzita: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" bertan behera utzi da",
     "Re: %1$s" : "Er: %1$s",
+    "%1$s has responded to your invitation" : "%1$s -(e)k zure gonbidapena erantzun du",
+    "Invitation updated: %1$s" : "Gonbidapena eguneratuta: %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s-k \"%2$s\" ekitaldia eguneratu du",
     "Invitation: %1$s" : "Gonbidapena: %1$s",
     "%1$s would like to invite you to \"%2$s\"" : "%1$s-k \"%2$s\"-ra gonbidatu nahi zaitu",
     "Organizer:" : "Antolatzailea:",
