@@ -38,6 +38,7 @@ OC.L10N.register(
     "A calendar <strong>event</strong> was modified" : "Kalenterin <strong>tapahtumaa</strong> on muokattu",
     "Contact birthdays" : "Yhteystietojen syntymäpäivät",
     "Death of %s" : "%s kuolema",
+    "Untitled calendar" : "Nimetön kalenteri",
     "Calendar:" : "Kalenteri:",
     "Date:" : "Päiväys:",
     "Where:" : "Missä:",
@@ -54,6 +55,8 @@ OC.L10N.register(
     "Where: %s" : "Missä: %s",
     "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
     "Cancelled: %1$s" : "Peruutettu: %1$s",
+    "\"%1$s\" has been canceled" : "\"%1$s\" on peruttu",
+    "%1$s has responded to your invitation" : "%1$s on vastannut kutsuusi",
     "Invitation: %1$s" : "Kutsu: %1$s",
     "Organizer:" : "Järjestäjä:",
     "Attendees:" : "Osallistujat:",
