@@ -55,6 +55,7 @@ OC.L10N.register(
     "A calendar <strong>to-do</strong> was modified" : "Um calendário <strong>tarefa</strong> foi modificado",
     "Contact birthdays" : "Aniversário dos contatos",
     "Death of %s" : "Morte de %s",
+    "Untitled calendar" : "Calendário sem título",
     "Calendar:" : "Calendário:",
     "Date:" : "Data:",
     "Where:" : "Onde:",
@@ -75,6 +76,8 @@ OC.L10N.register(
     "\"%1$s\" has been canceled" : "\"%1$s\" foi cancelado",
     "Re: %1$s" : "Remetente: %1$s",
     "%1$s has responded to your invitation" : "%1$s respondeu ao seu convite",
+    "Invitation updated: %1$s" : "Invitation updated: %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s updated the event \"%2$s\"",
     "Invitation: %1$s" : "Convite: %1$s",
     "%1$s would like to invite you to \"%2$s\"" : "%1$s gostaria de convidá-lo para \"%2$s\"",
     "Organizer:" : "Organizador:",
