@@ -55,6 +55,7 @@ OC.L10N.register(
     "A calendar <strong>to-do</strong> was modified" : "En kalender <strong>uppgift</strong> modifierades",
     "Contact birthdays" : "Födelsedagar",
     "Death of %s" : "Död av %s",
+    "Untitled calendar" : "Namnlös kalender",
     "Calendar:" : "Kalender:",
     "Date:" : "Datum:",
     "Where:" : "Var:",
@@ -74,6 +75,9 @@ OC.L10N.register(
     "Cancelled: %1$s" : "Avbruten: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" har avbrutits",
     "Re: %1$s" : "Sv: %1$s",
+    "%1$s has accepted your invitation" : "%1$s har accepterat din inbjudan",
+    "%1$s has tentatively accepted your invitation" : "%1$s har preliminärt accepterat din inbjudan",
+    "%1$s has declined your invitation" : "%1$s har tackat nej till din inbjudan",
     "%1$s has responded to your invitation" : "%1$s har svarat på din inbjudan",
     "Invitation updated: %1$s" : "Inbjudan uppdaterad: %1$s",
     "%1$s updated the event \"%2$s\"" : "%1$s uppdaterade händelse \"%2$s\"",
