@@ -32,6 +32,7 @@ use OCP\App\IAppManager;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IUser;
+use OCP\IUserManager;
 use OCP\IUserSession;
 use Sabre\CardDAV\Plugin;
 use Sabre\VObject\Reader;
@@ -50,14 +51,19 @@ class Backend {
 	/** @var IAppManager */
 	protected $appManager;
 
+	/** @var IUserManager */
+	protected $userManager;
+
 	public function __construct(IActivityManager $activityManager,
 								IGroupManager $groupManager,
 								IUserSession $userSession,
-								IAppManager $appManager) {
+								IAppManager $appManager,
+								IUserManager $userManager) {
 		$this->activityManager = $activityManager;
 		$this->groupManager = $groupManager;
 		$this->userSession = $userSession;
 		$this->appManager = $appManager;
+		$this->userManager = $userManager;
 	}
 
 	/**
@@ -103,7 +109,14 @@ class Backend {
 			return;
 		}
 
-		$principal = explode('/', $addressbookData['principaluri']);
+		$principalUri = $addressbookData['principaluri'];
+
+		// We are not interested in changes from the system addressbook
+		if ($principalUri === 'principals/system/system') {
+			return;
+		}
+
+		$principal = explode('/', $principalUri);
 		$owner = array_pop($principal);
 
 		$currentUser = $this->userSession->getUser();
@@ -132,6 +145,11 @@ class Backend {
 		}
 
 		foreach ($users as $user) {
+			if ($action === Addressbook::SUBJECT_DELETE && !$this->userManager->userExists($user)) {
+				// Avoid creating addressbook_delete activities for deleted users
+				continue;
+			}
+
 			$event->setAffectedUser($user)
 				->setSubject(
 					$user === $currentUser ? $action . '_self' : $action,
@@ -393,7 +411,14 @@ class Backend {
 			return;
 		}
 
-		$principal = explode('/', $addressbookData['principaluri']);
+		$principalUri = $addressbookData['principaluri'];
+
+		// We are not interested in changes from the system addressbook
+		if ($principalUri === 'principals/system/system') {
+			return;
+		}
+
+		$principal = explode('/', $principalUri);
 		$owner = array_pop($principal);
 
 		$currentUser = $this->userSession->getUser();
