@@ -11,6 +11,7 @@ OC.L10N.register(
     "Couldn't establish a federated share." : "Kunne ikke etablere en sammenknyttet ressurs",
     "Couldn't establish a federated share, maybe the password was wrong." : "Kunne ikke etablere en sammenknyttet ressurs, kanskje passordet var feil.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Sammenknyttet ressurs forespurt, du vil motta en invitasjon. Sjekk varslene dine.",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling av %1$s mislyktes, fordi dette elementet allerede er delt med bruker %2$s",
     "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en sammenknyttet skydeling med den samme brukeren",
     "File is already shared with %s" : "Filen er allerede delt med %s",
     "Could not find share" : "Kunne ikke finne ressurs",
@@ -22,7 +23,10 @@ OC.L10N.register(
     "Federated Cloud Sharing" : "Sammenknyttet skydeling",
     "Sharing" : "Deling",
     "Federated file sharing" : "Sammenknyttet fildeling",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillat brukere på denne serveren å sende delinger til andre servere (dette alternativet gir også WebDAV-tilgang til offentlige delinger)",
     "Allow users on this server to receive shares from other servers" : "Tillat at brukere på denne serveren mottar delinger fra andre servere",
+    "Allow users on this server to send shares to groups on other servers" : "Tillat brukere på denne serveren å sende delinger til grupper på andre servere",
+    "Allow users on this server to receive group shares from other servers" : "Tillat brukere på denne serveren å motta gruppedelinger fra andre servere",
     "Search global and public address book for users" : "Søk global og offentlige adressebøker etter brukere",
     "Allow users to publish their data to a global and public address book" : "Tillat brukere å offentliggjøre deres data til en verdensomspennende og offentlig adressebok",
     "Federated Cloud" : "Sammenknyttet sky",
