@@ -29,11 +29,11 @@ OC.L10N.register(
     "Federated file sharing" : "Birleşik dosya paylaşımı",
     "Provide federated file sharing across servers" : "Sunucular arasında birleşik dosya paylaşımı yapılmasını sağlar",
     "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Kullanıcıların sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kullanıcılar arasındaki paylaşımları da belirler.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilir (bu seçenek ayrıca herkese açık paylaşımlara WebDAV erişimi de sağlar)",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
     "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
     "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
     "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
-    "Search global and public address book for users" : "Genel ve herkese açık adres defterinde kullanıcı ara",
+    "Search global and public address book for users" : "Genel ve herkese açık adres defterindeki kullanıcılar aranabilsin",
     "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
     "Unable to update federated files sharing config" : "Birleşik dosya paylaşımı yapılandırması güncellenemedi",
     "Federated Cloud" : "Birleşik bulut",
@@ -43,7 +43,7 @@ OC.L10N.register(
     "Facebook" : "Facebook",
     "Twitter" : "Twitter",
     "Diaspora" : "Diaspora",
-    "Add to your website" : "Web sitenize ekleyin",
+    "Add to your website" : "Sitenize ekleyin",
     "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
     "HTML Code:" : "HTML kodu:",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "#Nextcloud Birleşik Bulut Kodum ile paylaş,  {url} adresine bakın",
