@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Прехвърлянето на собственост на {path} към {user} е завършено.",
     "in %s" : "в %s",
     "File Management" : "Управление на файлове",
+    "Reload current directory" : "Презареждане на текущата директория",
+    "Go to the \"{dir}\" directory" : "Отидете в директорията \"{dir}\"",
+    "Select the row for {displayName}" : "Избиране на реда за {displayName}",
+    "Open folder {name}" : "Отваряне на папка {name}",
+    "Download file {name}" : "Изтегляне на файл {name}",
+    "\"{displayName}\" action executed successfully" : "Действието „{displayName}“ е изпълнено успешно",
+    "\"{displayName}\" action failed" : "Действието „{displayName}“ е неуспешно",
+    "Total rows summary" : "Обобщение на общия брой редове",
+    "Select all" : "Избери всички",
+    "Unselect all" : "Отмяна на избора на всички",
+    "\"{displayName}\" failed on some elements " : "„{displayName}“ не успя да се изпълни за някои елементи ",
+    "\"{displayName}\" batch action executed successfully" : " Пакетното действие „{displayName}“ е изпълнено успешно",
+    "ascending" : "възходящо",
+    "descending" : "низходящо",
+    "Sort list by {column} ({direction})" : "Сортиране на списъка по  {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Този списък не е напълно рендиран поради причини, свързани с производителността. Файловете ще бъдат рендирани, докато навигирате из списъка.",
     "Storage informations" : "Хранилище на  информация",
     "{usedQuotaByte} used" : "{usedQuotaByte} използвано",
     "{relative}% used" : "{relative}% използвано",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Избор на файл или папка за прехвърляне",
     "Change" : "Промени",
     "New owner" : "Нов собственик",
-    "Search users" : "Търсене за потребители",
     "Choose a file or folder to transfer" : "Избор на файл или папка за прехвърляне",
     "Transfer" : "Прехвърли",
     "Transfer {path} to {userid}" : "Прехвърляне на  {path} към {userid}",
@@ -183,6 +198,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Изпратена заявка за прехвърляне на собствеността",
     "Cannot transfer ownership of a file or folder you do not own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
     "Select file or folder to link to" : "Избор на файл или папка, към които да поставите връзка",
+    "Loading current folder" : "Зареждане на текущата папка",
+    "No files in here" : "Няма файлове",
+    "No files or folders have been deleted yet" : "Все още няма изтрити файлове или папки",
+    "Go to the previous folder" : "Връщане към предишната папка",
+    "Go back" : "Назад",
     "Open the files app settings" : "Отваряне на настройките на приложението за файлове",
     "Files settings" : "Настройки на файловете",
     "File cannot be accessed" : "Файлът не е достъпен",
@@ -205,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Създаване на файл ",
     "Blank" : "Празен",
     "Unable to create new file from template" : "Не може да се създаде нов файл от шаблон",
+    "Delete permanently" : "Изтрий завинаги",
     "Set up templates folder" : "Настройка на папка за шаблони",
     "Templates" : "Шаблони",
     "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
     "Toggle %1$s sublist" : "Превключване на %1$s подсписък ",
     "Toggle grid view" : "Превключи решетъчния изглед",
-    "No files in here" : "Няма файлове",
     "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
     "No entries found in this folder" : "Няма намерени записи в тази папка",
-    "Select all" : "Избери всички",
     "Upload too large" : "Прекалено голям файл за качване",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
     "No favorites yet" : "Няма любими",
     "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
-    "Deleted files" : "Изтрити файлове",
     "Shares" : "Споделени",
     "Shared with others" : "Споделени с други",
     "Shared with you" : "Споделени с вас",
@@ -233,10 +251,12 @@ OC.L10N.register(
     "New" : "Създай",
     "Copied!" : "Копирано!",
     "Unlimited" : "Неограничено",
+    "Search users" : "Търсене за потребители",
     "Cannot transfer ownership of a file or folder you don't own" : "Не можете да прехвърляте собственост върху файл или папка, които не притежавате",
     "%s used" : "%s използвани",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s от %2$s използвани",
-    "Settings" : "Настройки"
+    "Settings" : "Настройки",
+    "Deleted files" : "Изтрити файлове"
 },
 "nplurals=2; plural=(n != 1);");
