@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Die Besitzübertragung von {path} durch {user} wurde fertiggestellt.",
     "in %s" : "in %s",
     "File Management" : "Dateiverwaltung",
+    "Reload current directory" : "Aktuelles Verzeichnis neu laden",
+    "Go to the \"{dir}\" directory" : "In das Verzeichnis \"{dir}“ wechseln",
+    "Select the row for {displayName}" : "Zeile für {displayName} auswählen",
+    "Open folder {name}" : "Ordner {name} öffnen",
+    "Download file {name}" : "Datei {name} herunterladen",
+    "\"{displayName}\" action executed successfully" : "Aktion \"{displayName}\" erfolgreich ausgeführt",
+    "\"{displayName}\" action failed" : "Aktion \"{displayName}\" fehlgeschlagen",
+    "Total rows summary" : "Zusammenfassung aller Zeilen",
+    "Select all" : "Alle auswählen",
+    "Unselect all" : "Auswahl aufheben",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" ist bei einigen Elementen fehlgeschlagen",
+    "\"{displayName}\" batch action executed successfully" : "Stapelaktion \"{displayName}\" erfolgreich ausgeführt",
+    "ascending" : "Aufsteigend",
+    "descending" : "Absteigend",
+    "Sort list by {column} ({direction})" : "Liste sortieren nach {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Diese Liste ist aus Performance-Gründen nicht vollständig gerendert. Die Dateien werden gerendert, wenn Sie durch die Liste navigieren.",
     "Storage informations" : "Speicherinformationen",
     "{usedQuotaByte} used" : "{usedQuotaByte} verwendet",
     "{relative}% used" : "{relative}% verwendet",
@@ -174,7 +190,7 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Change" : "Ändern",
     "New owner" : "Neuer Besitzer",
-    "Search users" : "Suche Benutzer",
+    "Search for an account" : "Nach einem Konto suchen",
     "Choose a file or folder to transfer" : "Datei oder Ordner zur Übertragung auswählen",
     "Transfer" : "Übertragen",
     "Transfer {path} to {userid}" : "Übertrage {path} an {userid}",
@@ -183,6 +199,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Anforderung für die Besitzübertragung versendet",
     "Cannot transfer ownership of a file or folder you do not own" : "Sie können den Besitz von Dateien oder Ordnern, die Sie nicht besitzen, nicht übertragen",
     "Select file or folder to link to" : "Datei oder Ordner zum Verknüpfen auswählen",
+    "Loading current folder" : "Lade aktuellen Ordner",
+    "No files in here" : "Keine Dateien vorhanden",
+    "No files or folders have been deleted yet" : "Es wurden noch keine Dateien oder Ordner gelöscht",
+    "Go to the previous folder" : "Zum vorherigen Ordner wechseln",
+    "Go back" : "Zurückgehen",
     "Open the files app settings" : "Einstellungen der Dateien-App öffnen",
     "Files settings" : "Dateien-Einstellungen",
     "File cannot be accessed" : "Auf die Datei kann nicht zugegriffen werden",
@@ -205,20 +226,18 @@ OC.L10N.register(
     "Creating file" : "Datei erstellen",
     "Blank" : "Leer",
     "Unable to create new file from template" : "Neue Datei kann nicht aus Vorlage erstellt werden",
+    "Delete permanently" : "Endgültig löschen",
     "Set up templates folder" : "Vorlagenordner einrichten",
     "Templates" : "Vorlagen",
     "Unable to initialize the templates directory" : "Der Vorlagenordner kann nicht initialisiert werden",
     "Toggle %1$s sublist" : "Unterliste %1$s umschalten",
     "Toggle grid view" : "Rasteransicht umschalten",
-    "No files in here" : "Keine Dateien vorhanden",
     "Upload some content or sync with your devices!" : "Laden Sie Inhalte hoch oder mit Ihren Geräten synchronisieren!",
     "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden",
-    "Select all" : "Alle auswählen",
     "Upload too large" : "Der Upload ist zu groß",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Die Datei überschreitet die Maximalgröße für Uploads auf diesem Server.",
     "No favorites yet" : "Noch keine Favoriten vorhanden",
     "Files and folders you mark as favorite will show up here" : "Dateien und Ordner, die Sie als Favoriten kennzeichnen, werden hier erscheinen",
-    "Deleted files" : "Gelöschte Dateien",
     "Shares" : "Freigaben",
     "Shared with others" : "Mit anderen geteilt",
     "Shared with you" : "Mit Ihnen geteilt",
@@ -233,10 +252,12 @@ OC.L10N.register(
     "New" : "Neu",
     "Copied!" : "Kopiert!",
     "Unlimited" : "Unbegrenzt",
+    "Search users" : "Suche Benutzer",
     "Cannot transfer ownership of a file or folder you don't own" : "Der Besitz einer Datei oder eines Ordners, den Sie nicht besitzen, kann nicht übertragen werden",
     "%s used" : "%s verwendet",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s von %2$s verwendet",
-    "Settings" : "Einstellungen"
+    "Settings" : "Einstellungen",
+    "Deleted files" : "Gelöschte Dateien"
 },
 "nplurals=2; plural=(n != 1);");
