@@ -152,7 +152,6 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Ένα αρχείο ή κατάλογος έχουν <strong>αλλάξει</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "Ένα αγαπημένο αρχείο ή φάκελός σας έχει <strong>τροποποιηθεί</strong>.",
     "All files" : "Όλα τα αρχεία",
-    "Unlimited" : "Απεριόριστο",
     "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
     "Accept" : "Αποδοχή",
     "Reject" : "Απόρριψη",
@@ -166,11 +165,11 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Η μεταφορά κυριότητας του {path} στον {user} ολοκληρώθηκε.",
     "in %s" : "σε %s",
     "File Management" : "Διαχείριση αρχείων",
+    "Select all" : "Επιλογή όλων",
     "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
     "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Change" : "Αλλαγή",
     "New owner" : "Νέος κάτοχος",
-    "Search users" : "Αναζήτηση χρηστών",
     "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Transfer" : "Μεταφορά",
     "Transfer {path} to {userid}" : "Μεταφορά {path} στον {userid}",
@@ -178,10 +177,13 @@ OC.L10N.register(
     "Unknown error" : "Άγνωστο σφάλμα",
     "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
     "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
+    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
+    "Go back" : "Επιστροφή",
     "Files settings" : "Ρυθμίσεις αρχείων",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
     "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
     "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
     "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
@@ -194,24 +196,18 @@ OC.L10N.register(
     "Creating file" : "Δημιουργία αρχείου",
     "Blank" : "Κενό",
     "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
+    "Delete permanently" : "Διαγραφή οριστικά",
     "Set up templates folder" : "Ρύθμιση φακέλου προτύπων",
     "Templates" : "Πρότυπα",
     "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
-    "%s used" : "%s σε χρήση",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
-    "WebDAV" : "WebDAV",
     "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
     "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
-    "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
     "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
     "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
-    "Select all" : "Επιλογή όλων",
     "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
     "No favorites yet" : "Κανένα αγαπημένο ακόμα",
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
-    "Deleted files" : "Διαγραμμένα αρχεία",
     "Shares" : "Κοινόχρηστα",
     "Shared with others" : "Διαμοιρασμένα με άλλους",
     "Shared with you" : "Διαμοιρασμένα με εσάς",
@@ -225,7 +221,13 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
     "New" : "Νέο",
     "Copied!" : "Αντιγράφηκε!",
+    "Unlimited" : "Απεριόριστο",
+    "Search users" : "Αναζήτηση χρηστών",
     "Cannot transfer ownership of a file or folder you don't own" : "Δεν μπορεί να μεταβιβαστεί η κυριότητα αρχείου ή φακέλου που δεν σας ανήκει",
-    "Settings" : "Ρυθμίσεις"
+    "%s used" : "%s σε χρήση",
+    "%s%%" : "%s%%",
+    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
+    "Settings" : "Ρυθμίσεις",
+    "Deleted files" : "Διαγραμμένα αρχεία"
 },
 "nplurals=2; plural=(n != 1);");
