@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "The ownership transfer of {path} from {user} has completed.",
     "in %s" : "in %s",
     "File Management" : "File Management",
+    "Reload current directory" : "Reload current directory",
+    "Go to the \"{dir}\" directory" : "Go to the \"{dir}\" directory",
+    "Select the row for {displayName}" : "Select the row for {displayName}",
+    "Open folder {name}" : "Open folder {name}",
+    "Download file {name}" : "Download file {name}",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
+    "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
+    "Total rows summary" : "Total rows summary",
+    "Select all" : "Select all",
+    "Unselect all" : "Unselect all",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" failed on some elements ",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
+    "ascending" : "ascending",
+    "descending" : "descending",
+    "Sort list by {column} ({direction})" : "Sort list by {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list.",
     "Storage informations" : "Storage informations",
     "{usedQuotaByte} used" : "{usedQuotaByte} used",
     "{relative}% used" : "{relative}% used",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Choose file or folder to transfer",
     "Change" : "Change",
     "New owner" : "New owner",
-    "Search users" : "Search users",
     "Choose a file or folder to transfer" : "Choose a file or folder to transfer",
     "Transfer" : "Transfer",
     "Transfer {path} to {userid}" : "Transfer {path} to {userid}",
@@ -183,6 +198,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Ownership transfer request sent",
     "Cannot transfer ownership of a file or folder you do not own" : "Cannot transfer ownership of a file or folder you do not own",
     "Select file or folder to link to" : "Select file or folder to link to",
+    "Loading current folder" : "Loading current folder",
+    "No files in here" : "No files in here",
+    "No files or folders have been deleted yet" : "No files or folders have been deleted yet",
+    "Go to the previous folder" : "Go to the previous folder",
+    "Go back" : "Go back",
     "Open the files app settings" : "Open the files app settings",
     "Files settings" : "Files settings",
     "File cannot be accessed" : "File cannot be accessed",
@@ -205,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Creating file",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
+    "Delete permanently" : "Delete permanently",
     "Set up templates folder" : "Set up templates folder",
     "Templates" : "Templates",
     "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Toggle %1$s sublist" : "Toggle %1$s sublist",
     "Toggle grid view" : "Toggle grid view",
-    "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
     "No entries found in this folder" : "No entries found in this folder",
-    "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "No favorites yet" : "No favourites yet",
     "Files and folders you mark as favorite will show up here" : "Files and folders you mark as favourite will show up here",
-    "Deleted files" : "Deleted files",
     "Shares" : "Shares",
     "Shared with others" : "Shared with others",
     "Shared with you" : "Shared with you",
@@ -233,10 +251,12 @@ OC.L10N.register(
     "New" : "New",
     "Copied!" : "Copied!",
     "Unlimited" : "Unlimited",
+    "Search users" : "Search users",
     "Cannot transfer ownership of a file or folder you don't own" : "Cannot transfer ownership of a file or folder you don't own",
     "%s used" : "%s used",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s of %2$s used",
-    "Settings" : "Settings"
+    "Settings" : "Settings",
+    "Deleted files" : "Deleted files"
 },
 "nplurals=2; plural=(n != 1);");
