@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "in %s" : "en %s",
     "File Management" : "Gestión de archivos",
+    "Reload current directory" : "Recargar directorio actual",
+    "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\"",
+    "Select the row for {displayName}" : "Seleccione la fila para {displayName}",
+    "Open folder {name}" : "Abrir carpeta {name}",
+    "Download file {name}" : "Descargar archivo {name}",
+    "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitósamente",
+    "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
+    "Total rows summary" : "Resumen de filas totales",
+    "Select all" : "Seleccionar todo",
+    "Unselect all" : "Deseleccionar todos",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" fallo en algunos elementos",
+    "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitósamente",
+    "ascending" : "ascendente",
+    "descending" : "descendente",
+    "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se renderiza completa por razones de rendimiento. Los archivos serán renderizados mientras ud. navegue por la lista.",
     "Storage informations" : "Informaciones de almacenamiento",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{relative}% used" : "{relative}% utilizado",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
     "Change" : "Cambiar",
     "New owner" : "Nuevo propietario",
-    "Search users" : "Buscar usuarios",
     "Choose a file or folder to transfer" : "Elegir un archivo o carpeta para transferir",
     "Transfer" : "Transferir",
     "Transfer {path} to {userid}" : "Transferir {path} a {userid}",
@@ -183,6 +198,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
     "Cannot transfer ownership of a file or folder you do not own" : "No puedes transferir la propiedad de un archivo o directorio del cual no eres propietario",
     "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
+    "Loading current folder" : "Cargando carpeta actual",
+    "No files in here" : "Aquí no hay archivos",
+    "No files or folders have been deleted yet" : "No se han borrado archivos o carpetas todavía",
+    "Go to the previous folder" : "Ir a la carpeta anterior",
+    "Go back" : "Ir atrás",
     "Open the files app settings" : "Abrir la configuración de la app Archivos",
     "Files settings" : "Configuración de archivos",
     "File cannot be accessed" : "El archivo no puede ser accesado",
@@ -205,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Creando el archivo",
     "Blank" : "Vacío",
     "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
+    "Delete permanently" : "Eliminar de forma definitiva",
     "Set up templates folder" : "Configura una carpeta para plantillas",
     "Templates" : "Plantillas",
     "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "Toggle grid view" : "Alternar vista de cuadrícula",
-    "No files in here" : "Aquí no hay archivos",
     "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
     "No entries found in this folder" : "No hay entradas en esta carpeta",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "Subida demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
-    "Deleted files" : "Archivos eliminados",
     "Shares" : "Archivos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido conmigo",
@@ -233,10 +251,12 @@ OC.L10N.register(
     "New" : "Nuevo",
     "Copied!" : "¡Copiado!",
     "Unlimited" : "Ilimitado",
+    "Search users" : "Buscar usuarios",
     "Cannot transfer ownership of a file or folder you don't own" : "No se puede transferir la propiedad de un archivo o carpeta que no te pertenece",
     "%s used" : "usado %s",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s de %2$s usados",
-    "Settings" : "Ajustes"
+    "Settings" : "Ajustes",
+    "Deleted files" : "Archivos eliminados"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
