@@ -114,23 +114,24 @@ OC.L10N.register(
     "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "in %s" : "en %s",
+    "Select all" : "Seleccionar todo",
     "Change" : "Cambiar",
     "Unknown error" : "Se presentó un error desconocido",
+    "No files in here" : "No hay archivos aquí",
+    "Go back" : "Regresar",
     "Show hidden files" : "Mostrar archivos ocultos",
     "Additional settings" : "Configuraciones adicionales",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Cancel" : "Cancelar",
     "Create" : "Crear",
-    "No files in here" : "No hay archivos aquí",
+    "Delete permanently" : "Borrar permanentemente",
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "Deleted files" : "Papelera",
     "Shares" : "Elementos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
@@ -145,6 +146,7 @@ OC.L10N.register(
     "Unlimited" : "Ilimitado",
     "%s used" : "%s usado",
     "%1$s of %2$s used" : "%1$s de %2$s usados",
-    "Settings" : "Configuraciones "
+    "Settings" : "Configuraciones ",
+    "Deleted files" : "Papelera"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
