@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
-    "Storage invalid" : "El almacenamiento es inválido",
-    "Unknown error" : "Se presentó un error desconocido",
     "File could not be found" : "No fue posible encontrar el archivo",
     "Move or copy" : "Mover o copiar",
     "Download" : "Descargar",
@@ -44,6 +41,7 @@ OC.L10N.register(
     "Unable to determine date" : "No fue posible determinar la fecha",
     "This operation is forbidden" : "Esta operación está prohibida",
     "This directory is unavailable, please check the logs or contact the administrator" : "Esta carpeta no está disponible, por favor verfica las bitácoras o contacta al administrador",
+    "Storage is temporarily not available" : "El almacenamiento no está disponible temporalmente ",
     "Could not move \"{file}\", target exists" : "No fue posible mover \"{file}\", el destino ya existe",
     "Could not move \"{file}\"" : "No fue posible mover \"{file}\"",
     "copy" : "copiar",
@@ -79,12 +77,11 @@ OC.L10N.register(
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "El espacio de {owner} está casi lleno ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Tu espacio está casi lleno ({usedSpacePercent}%).",
     "View in folder" : "Ver en la carpeta",
-    "Copied!" : "¡Copiado!",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Marcado como favorito",
     "Favorite" : "Favorito",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "New folder" : "Carpeta nueva",
     "Upload file" : "Cargar archivo",
     "Recent" : "Reciente",
@@ -119,35 +116,42 @@ OC.L10N.register(
     "{user} moved {oldfile} to {newfile}" : "{user} movió {oldfile} a {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "Un archivo ha sido agregado o eliminado de tus <strong>favoritos</strong>",
     "All files" : "Todos los archivos",
-    "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Cargar (max. %s)",
     "Accept" : "Aceptar",
     "in %s" : "en %s",
+    "Select all" : "Seleccionar todo",
     "Change" : "Cambiar",
+    "Unknown error" : "Se presentó un error desconocido",
+    "No files in here" : "No hay archivos aquí",
+    "Go back" : "Regresar",
+    "Show hidden files" : "Mostrar archivos ocultos",
+    "Additional settings" : "Configuraciones adicionales",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "Copiar al portapapeles",
     "Cancel" : "Cancelar",
     "Create" : "Crear",
-    "%s used" : "%s usado",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
-    "Show hidden files" : "Mostrar archivos ocultos",
-    "WebDAV" : "WebDAV",
-    "No files in here" : "No hay archivos aquí",
+    "Delete permanently" : "Borrar permanentemente",
     "Upload some content or sync with your devices!" : "¡Carga algún contenido o sincroniza con tus dispositivos!",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
-    "Deleted files" : "Archivos borrados",
     "Shares" : "Elementos compartidos",
     "Shared with others" : "Compartido con otros",
     "Shared with you" : "Compartido con usted",
     "Shared by link" : "Compartido por liga",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
+    "Storage invalid" : "El almacenamiento es inválido",
     "Select" : "Seleccionar",
     "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
     "New" : "Nuevo",
-    "Settings" : "Configuraciones "
+    "Copied!" : "¡Copiado!",
+    "Unlimited" : "Ilimitado",
+    "%s used" : "%s usado",
+    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Settings" : "Configuraciones ",
+    "Deleted files" : "Archivos borrados"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
