@@ -110,24 +110,25 @@ OC.L10N.register(
     "Accept" : "Nõustu",
     "Reject" : "Keeldu",
     "in %s" : "kaustas %s",
+    "Select all" : "Vali kõik",
     "Change" : "Muuda",
     "Unknown error" : "Tundmatu viga",
+    "No files in here" : "Siin ei ole faile",
+    "Go back" : "Mine tagasi",
     "Show hidden files" : "Näita peidetud faile",
     "Additional settings" : "Lisaseaded",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Cancel" : "Loobu",
     "Create" : "Loo",
+    "Delete permanently" : "Kustuta jäädavalt",
     "Templates" : "Mallid",
-    "No files in here" : "Siin ei ole faile",
     "Upload some content or sync with your devices!" : "Laadi sisu üles või süngi oma seadmetega!",
     "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
-    "Select all" : "Vali kõik",
     "Upload too large" : "Üleslaadimine on liiga suur",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületab serveri poolt üleslaetavatele failidele määratud maksimaalse suuruse.",
     "No favorites yet" : "Lemmikuid veel pole",
     "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
-    "Deleted files" : "Kustutatud failid",
     "Shares" : "Jagamisi",
     "Shared with others" : "Teistega jagatud",
     "Shared with you" : "Sinuga jagatud",
@@ -144,6 +145,7 @@ OC.L10N.register(
     "Unlimited" : "Piiramatult",
     "%s used" : "Kasutatud %s",
     "%1$s of %2$s used" : "Kasutatud %1$s/%2$s",
-    "Settings" : "Seaded"
+    "Settings" : "Seaded",
+    "Deleted files" : "Kustutatud failid"
 },
 "nplurals=2; plural=(n != 1);");
