@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{path}(r)en jabetza {user} erabiltzailetik transferitzea osatu da.",
     "in %s" : "%s(e)n",
     "File Management" : "Fitxategi-kudeaketa",
+    "Reload current directory" : "Birkargatu uneko direktorioa",
+    "Go to the \"{dir}\" directory" : "Joan \"{dir}\" direktoriora",
+    "Select the row for {displayName}" : "Hautatu {displayName} errenkada",
+    "Open folder {name}" : "Ireki {name} karpeta",
+    "Download file {name}" : "Deskargatu {name} fitxategia ",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" ekintza behar bezala exekutatu da",
+    "\"{displayName}\" action failed" : "\"{displayName}\" ekintzak huts egin du",
+    "Total rows summary" : "Errenkaden guztirako laburpena",
+    "Select all" : "Hautatu dena",
+    "Unselect all" : "Desautatu dena",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\"-k huts egin du elementu batzuetan",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" multzoko ekintza behar bezala exekutatu da",
+    "ascending" : "goranzkoa",
+    "descending" : "beheranzkoa",
+    "Sort list by {column} ({direction})" : "Ordenatu zerrenda {zutabea} ({norabidea}) arabera",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "Storage informations" : "Biltegiaren informazioak",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
     "{relative}% used" : "%{relative} erabilita",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Aukeratu fitxategia edo karpeta transferitzeko",
     "Change" : "Aldatu",
     "New owner" : "Jabe berria",
-    "Search users" : "Bilatu erabiltzaileak",
     "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
     "Transfer" : "Transferitu",
     "Transfer {path} to {userid}" : "Transfereritu {path}  {userid} erabiltzaileari",
@@ -183,15 +198,24 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Jabetza transferentzia eskaera bidalita",
     "Cannot transfer ownership of a file or folder you do not own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
+    "Loading current folder" : "Uneko karpeta kargatzen",
+    "No files in here" : "Ez dago fitxategirik hemen",
+    "No files or folders have been deleted yet" : "Oraindik ez da ezabatu fitxategirik edo karpetarik",
+    "Go to the previous folder" : "Joan aurreko karpetara",
+    "Go back" : "Atzera",
     "Open the files app settings" : "Ireki Fitxategiak aplikazioaren ezarpenak",
     "Files settings" : "FItxategien ezarpenak",
+    "File cannot be accessed" : "Ezin da fitxategia atzitu",
+    "You might not have have permissions to view it, ask the sender to share it" : "Baliteke hura ikusteko baimenik ez izatea; eskatu igorleari partekatzeko",
     "Show hidden files" : "Erakutsi ezkutuko fitxategiak",
     "Crop image previews" : "Moztu irudien aurrebistak",
     "Additional settings" : "Ezarpen gehiago",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiatu arbelera",
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
+    "WebDAV URL copied to clipboard" : "WebDAV URLa arbelean kopiatu da",
     "Unable to change the favourite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
     "Error while loading the file data" : "Errorea fitxategiaren datuak kargatzerakoan",
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
@@ -201,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Fitxategia sortzen",
     "Blank" : "Hutsik",
     "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
+    "Delete permanently" : "Ezabatu betirako",
     "Set up templates folder" : "Konfiguratu txantiloien karpeta",
     "Templates" : "Txantiloiak",
     "Unable to initialize the templates directory" : "Ezin da txantiloien direktorioa hasieratu",
     "Toggle %1$s sublist" : "Txandakatu %1$sazpizerrenda",
     "Toggle grid view" : "Txandakatu sareta ikuspegia",
-    "No files in here" : "Ez dago fitxategirik hemen",
     "Upload some content or sync with your devices!" : "Kargatu edukiren bat edo sinkronizatu zure gailuekin!",
     "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
-    "Select all" : "Hautatu dena",
     "Upload too large" : "Kargatzea handiegia da",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kargatzen saiatzen ari zaren fitxategiek zerbitzari honek onartzen duen gehienezko tamaina gainditzen dute.",
     "No favorites yet" : "Gogokorik ez oraindik",
     "Files and folders you mark as favorite will show up here" : "Gogokotzat markatutako fitxategi eta karpetak hemen agertuko dira",
-    "Deleted files" : "Ezabatutako fitxategiak",
     "Shares" : "Partekatzeak",
     "Shared with others" : "Besteekin partekatuta",
     "Shared with you" : "Zurekin partekatuta",
@@ -229,10 +251,12 @@ OC.L10N.register(
     "New" : "Berria",
     "Copied!" : "Kopiatua!",
     "Unlimited" : "Mugarik gabe",
+    "Search users" : "Bilatu erabiltzaileak",
     "Cannot transfer ownership of a file or folder you don't own" : "Ezin da zurea ez den fitxategi edo karpeta baten jabetza transferitu",
     "%s used" : "%s erabilita",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s / %2$s erabilita",
-    "Settings" : "Ezarpenak"
+    "Settings" : "Ezarpenak",
+    "Deleted files" : "Ezabatutako fitxategiak"
 },
 "nplurals=2; plural=(n != 1);");
