@@ -166,6 +166,11 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
     "in %s" : "polussa %s",
     "File Management" : "Tiedostohallinta",
+    "Reload current directory" : "Lataa nykyinen kansio uudelleen",
+    "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
+    "Open folder {name}" : "Avaa kansio {name}",
+    "Download file {name}" : "Lataa tiedosto {name}",
+    "Select all" : "Valitse kaikki",
     "Storage informations" : "Tallennustilan tietoja",
     "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
     "{relative}% used" : "{relative} % käytetty",
@@ -174,7 +179,7 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Change" : "Muuta",
     "New owner" : "Uusi omistaja",
-    "Search users" : "Etsi käyttäjistä",
+    "Search for an account" : "Etsi tiliä",
     "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
     "Transfer" : "Siirrä",
     "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
@@ -183,6 +188,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
     "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
     "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
+    "Loading current folder" : "Ladataan nykyistä kansiota",
+    "No files in here" : "Täällä ei ole tiedostoja",
+    "No files or folders have been deleted yet" : "Tiedostoja tai kansioita ei ole vielä poistettu",
+    "Go to the previous folder" : "Siirry edelliseen kansioon",
+    "Go back" : "Mene takaisin",
     "Open the files app settings" : "Avaa tiedostosovelluksen asetukset",
     "Files settings" : "Tiedostojen asetukset",
     "File cannot be accessed" : "Tiedostoa ei voi käyttää",
@@ -205,19 +215,17 @@ OC.L10N.register(
     "Creating file" : "Luodaan tiedostoa",
     "Blank" : "Tyhjä",
     "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
+    "Delete permanently" : "Poista pysyvästi",
     "Set up templates folder" : "Aseta mallipohjien kansio",
     "Templates" : "Mallipohjat",
     "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
     "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
-    "No files in here" : "Täällä ei ole tiedostoja",
     "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
-    "Select all" : "Valitse kaikki",
     "Upload too large" : "Lähetettävä tiedosto on liian suuri",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
     "No favorites yet" : "Ei vielä suosikkeja",
     "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
-    "Deleted files" : "Poistetut tiedostot",
     "Shares" : "Jaot",
     "Shared with others" : "Jaettu muille",
     "Shared with you" : "Jaettu kanssasi",
@@ -232,10 +240,12 @@ OC.L10N.register(
     "New" : "Uusi",
     "Copied!" : "Kopioitu!",
     "Unlimited" : "Rajoittamaton",
+    "Search users" : "Etsi käyttäjistä",
     "Cannot transfer ownership of a file or folder you don't own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
     "%s used" : "%s käytetty",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s/%2$s käytetty",
-    "Settings" : "Asetukset"
+    "Settings" : "Asetukset",
+    "Deleted files" : "Poistetut tiedostot"
 },
 "nplurals=2; plural=(n != 1);");
