@@ -96,7 +96,9 @@ OC.L10N.register(
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O cartafol de grupo «{mountPoint}» está case cheo ({usedSpacePercent}%).",
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "O almacenamento externo «{mountPoint}» está case cheo ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%).",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden con \"{filter}\"","coinciden con \"{filter}\""],
     "View in folder" : "Ver no cartafol",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Copiouse a ligazón directa (só funciona para os usuarios que teñen acceso a este ficheiro/cartafol)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Marcado como favorito",
@@ -164,11 +166,30 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Completouse a transferencia da propiedade de {path} cara a {user}.",
     "in %s" : "en %s",
     "File Management" : "Xestión de ficheiros",
+    "Reload current directory" : "Recarga o directorio actual",
+    "Go to the \"{dir}\" directory" : "Vaia ao directorio \"{dir}\".",
+    "Select the row for {displayName}" : "Selecciona a fila para {displayName}",
+    "Open folder {name}" : "Abrir cartafol {name}",
+    "Download file {name}" : "Descargar ficheiro {name}",
+    "\"{displayName}\" action executed successfully" : "A acción \"{displayName}\" executouse correctamente",
+    "\"{displayName}\" action failed" : "A acción \"{displayName}\" fallou",
+    "Total rows summary" : "Resumo total de filas",
+    "Select all" : "Seleccionar todo",
+    "Unselect all" : "Deselecciona todo",
+    "\"{displayName}\" failed on some elements " : "Fallou \"{displayName}\" nalgúns elementos",
+    "\"{displayName}\" batch action executed successfully" : "A acción por lotes \"{displayName}\" executouse correctamente",
+    "ascending" : "ascendente",
+    "descending" : "descendente",
+    "Sort list by {column} ({direction})" : "Ordenar a lista por {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista non se presenta completamente por motivos de rendemento. Os ficheiros mostraranse mentres navegues pola lista.",
+    "Storage informations" : "Información de almacenamento",
+    "{usedQuotaByte} used" : "{usedQuotaByte} usado",
+    "{relative}% used" : "{relative}% usado",
+    "Could not refresh storage stats" : "Non se puideron actualizar as estatísticas de almacenamento",
     "Transfer ownership of a file or folder" : "Transferencia da propiedade dun ficheiro ou cartafol",
     "Choose file or folder to transfer" : "Escolla o ficheiro ou cartafol para transferir",
     "Change" : "Cambiar",
     "New owner" : "Novo propietario",
-    "Search users" : "Buscar usuarios",
     "Choose a file or folder to transfer" : "Escolla un ficheiro ou cartafol para transferir",
     "Transfer" : "Transferencia",
     "Transfer {path} to {userid}" : "Transferir {path} cara a {userid}",
@@ -176,13 +197,25 @@ OC.L10N.register(
     "Unknown error" : "Erro descoñecido",
     "Ownership transfer request sent" : "Enviouse solicitude de transferencia da propiedade",
     "Cannot transfer ownership of a file or folder you do not own" : "Non se pode transferir a propiedade dun ficheiro ou cartafol do que non eres propietario",
+    "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que quere enlazar",
+    "Loading current folder" : "Cargando cartafol actual",
+    "No files in here" : "Aquí non hai ficheiros",
+    "No files or folders have been deleted yet" : "Aínda non se eliminou ningún ficheiro nin cartafol",
+    "Go to the previous folder" : "Vaia ao cartafol anterior",
+    "Go back" : "Volver",
+    "Open the files app settings" : "Abre a configuración da aplicación de ficheiros",
     "Files settings" : "Axustes de ficheiros",
+    "File cannot be accessed" : "Non se pode acceder ao ficheiro",
+    "You might not have have permissions to view it, ask the sender to share it" : "É posible que non teñas permisos para velo, pídelle ao remitente que o comparta",
     "Show hidden files" : "Amosar os ficheiros agochados",
     "Crop image previews" : "Recortar a vista previa das imaxes",
     "Additional settings" : "Axustes adicionais",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar no portapapeis.",
     "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activaches 2FA, debes crear e utilizar un novo contrasinal da aplicación facendo clic aquí.",
+    "Clipboard is not available" : "O portapapeis non está dispoñible",
+    "WebDAV URL copied to clipboard" : "A URL de WebDAV copiouse no portapapeis",
     "Unable to change the favourite state of the file" : "Non é posíbel cambiar o estado favorito do ficheiro",
     "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
     "Pick a template for {name}" : "Escolla un modelo para {name}",
@@ -192,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Creando o ficheiro",
     "Blank" : "Baleiro",
     "Unable to create new file from template" : "Non é posíbel crear un novo ficheiro a partir do modelo",
+    "Delete permanently" : "Eliminar de xeito permanente",
     "Set up templates folder" : "Estabelecer un cartafol de modelos",
     "Templates" : "Modelos",
     "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
     "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "Toggle grid view" : "Alternar a vista como grella",
-    "No files in here" : "Aquí non hai ficheiros",
     "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
     "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
-    "Select all" : "Seleccionar todo",
     "Upload too large" : "Envío grande de máis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
     "No favorites yet" : "Aínda non hai favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
-    "Deleted files" : "Ficheiros eliminados",
     "Shares" : "Comparticións",
     "Shared with others" : "Compartido con outros",
     "Shared with you" : "Compartido con vostede",
@@ -220,10 +251,12 @@ OC.L10N.register(
     "New" : "Novo",
     "Copied!" : "Copiado!",
     "Unlimited" : "Sen límites",
+    "Search users" : "Buscar usuarios",
     "Cannot transfer ownership of a file or folder you don't own" : "Non é posíbel transferir a propiedade dun ficheiro ou cartafol que non é de seu",
     "%s used" : "%s utilizado",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%s de %s utilizado",
-    "Settings" : "Axustes"
+    "Settings" : "Axustes",
+    "Deleted files" : "Ficheiros eliminados"
 },
 "nplurals=2; plural=(n != 1);");
