@@ -153,17 +153,19 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Prijenos vlasništva {path} od {user} je završen.",
     "in %s" : "za %s",
     "File Management" : "Upravljanje datotekama",
+    "Select all" : "Odaberi sve",
     "Transfer ownership of a file or folder" : "Prenesi vlasništvo nad datotekom ili mapom",
     "Choose file or folder to transfer" : "Odaberite datoteku ili mapu za prijenos",
     "Change" : "Promijeni",
     "New owner" : "Novi vlasnik",
-    "Search users" : "Pretraži korisnike",
     "Choose a file or folder to transfer" : "Odaberite datoteku ili mapu za prijenos",
     "Transfer" : "Prijenos",
     "Transfer {path} to {userid}" : "Prijenos {path} na {userid}",
     "Invalid path selected" : "Odabran nevažeći put",
     "Unknown error" : "Nepoznata pogreška",
     "Ownership transfer request sent" : "Zahtjev za prijenos vlasništva je poslan",
+    "No files in here" : "Nema datoteka",
+    "Go back" : "Natrag",
     "Show hidden files" : "Prikaz skrivenih datoteka",
     "Crop image previews" : "Obreži pretpreglede slika",
     "Additional settings" : "Dodatne postavke",
@@ -179,20 +181,18 @@ OC.L10N.register(
     "Creating file" : "Stvaranje datoteke",
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nije moguće stvoriti novu datoteku iz predloška",
+    "Delete permanently" : "Trajno izbrišite",
     "Set up templates folder" : "Postavi mapu predložaka",
     "Templates" : "Predlošci",
     "Unable to initialize the templates directory" : "Nije moguće inicijalizirati direktorij predložaka",
     "Toggle %1$s sublist" : "Uključivanje/isključivanje potpopisa %1$s",
     "Toggle grid view" : "Uključi/isključi prikaz rešetke",
-    "No files in here" : "Nema datoteka",
     "Upload some content or sync with your devices!" : "Otpremite neki sadržaj ili sinkronizirajte sa svojim uređajima!",
     "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
-    "Select all" : "Odaberi sve",
     "Upload too large" : "Otprema je prevelika",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate otpremiti premašuju maksimalnu veličinu za otpremu datoteka na ovom poslužitelju.",
     "No favorites yet" : "Još nema favorita",
     "Files and folders you mark as favorite will show up here" : "Ovdje će se prikazati datoteke i mape koje označite kao favorite",
-    "Deleted files" : "Izbrisane datoteke",
     "Shares" : "Dijeljenja",
     "Shared with others" : "Podijeljeno s ostalima",
     "Shared with you" : "Podijeljeno s vama",
@@ -207,9 +207,11 @@ OC.L10N.register(
     "New" : "Novo",
     "Copied!" : "Kopirano!",
     "Unlimited" : "Neograničeno",
+    "Search users" : "Pretraži korisnike",
     "Cannot transfer ownership of a file or folder you don't own" : "Ne možete prenijeti vlasništvo nad datotekom ili mapom koja nije u vašem vlasništvu",
     "%s used" : "Iskorišteno %s",
     "%1$s of %2$s used" : "Iskorišteno %1$s od %2$s",
-    "Settings" : "Postavke"
+    "Settings" : "Postavke",
+    "Deleted files" : "Izbrisane datoteke"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
