@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "A(z) {path} tulajdonjogának átruházása {user} részéről sikeres.",
     "in %s" : "itt:  %s",
     "File Management" : "Fájlkezelés",
+    "Reload current directory" : "Jelenlegi könyvtár újratöltése",
+    "Go to the \"{dir}\" directory" : "Ugrás a(z) „{dir}” könyvtárhoz",
+    "Select the row for {displayName}" : "A(z) {displayName} sorának kiválasztása",
+    "Open folder {name}" : "A(z) {name} mappa megnyitása",
+    "Download file {name}" : "A(z) {name} fájl letöltése",
+    "\"{displayName}\" action executed successfully" : "A(z) „{displayName}” művelet sikeresen végrehajtva",
+    "\"{displayName}\" action failed" : "A(z) „{displayName}” művelet sikertelen",
+    "Total rows summary" : "Összes sor összegzése",
+    "Select all" : "Összes kijelölése",
+    "Unselect all" : "Kijelölés megszüntetése",
+    "\"{displayName}\" failed on some elements " : "A(z) „{displayName}” sikertelen volt néhány elemen",
+    "\"{displayName}\" batch action executed successfully" : "A(z) „{displayName}” tömeges művelet sikeresen végrehajtva",
+    "ascending" : "növekvő",
+    "descending" : "csökkenő",
+    "Sort list by {column} ({direction})" : "Lista rendezése {column} alapján ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ez a lista teljesítménybeli okokból nincs teljes egészében megjelenítve. A fájlok a listában navigálás során jelennek meg, ",
     "Storage informations" : "Tárhely-információk",
     "{usedQuotaByte} used" : "{usedQuotaByte} felhasználva",
     "{relative}% used" : "{relative}% felhasználva",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Válasszon egy fájlt vagy mappát az átruházáshoz",
     "Change" : "Módosítás",
     "New owner" : "Új tulajdonos",
-    "Search users" : "Fehasználók keresése",
     "Choose a file or folder to transfer" : "Válassz egy átruházandó fájlt vagy mappát",
     "Transfer" : "Átruházás",
     "Transfer {path} to {userid}" : "{path} átruházása {userid} számára",
@@ -183,15 +198,24 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Tulajdonjog átruházási kérés elküldve",
     "Cannot transfer ownership of a file or folder you do not own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
     "Select file or folder to link to" : "Válassza ki a hivatkozandó fájlt vagy mappát",
+    "Loading current folder" : "Jelenlegi mappa betöltése",
+    "No files in here" : "Itt nincsenek fájlok",
+    "No files or folders have been deleted yet" : "Még nem lettek fájlok vagy mappák törölve",
+    "Go to the previous folder" : "Ugrás az előző mappához",
+    "Go back" : "Visszalépés",
     "Open the files app settings" : "Nyissa meg a Fájlok lalkalmazás beállításait",
     "Files settings" : "Fájlok beállításai",
+    "File cannot be accessed" : "A fájl nem érhető el",
+    "You might not have have permissions to view it, ask the sender to share it" : "Lehet, hogy nincs jogosultsága, hogy megtekintse, kérje meg a küldőt, hogy ossza meg",
     "Show hidden files" : "Rejtett fájlok megjelenítése",
     "Crop image previews" : "Kép előnézetek vágása",
     "Additional settings" : "További beállítások",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Másolás a vágólapra",
     "Use this address to access your Files via WebDAV" : "Ezzel a címmel férhet hozzá a Fájlokhoz a WebDAV-on keresztül",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ha engedélyezte a kétfaktoros hitelesítést, akkor kattintson ide, hogy létrehozzon egy új alkalmazásjelszót, és azt használja.",
     "Clipboard is not available" : "A vágólap nem érhető el",
+    "WebDAV URL copied to clipboard" : "A WebDAV-cím a vágólapra másolva",
     "Unable to change the favourite state of the file" : "Nem lehet megváltoztatni a fájl kedvenc állapotát",
     "Error while loading the file data" : "Hiba történt a fájladatok betöltése közben",
     "Pick a template for {name}" : "Válassz sablont a(z) {name} fájlnak",
@@ -201,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Fájl létrehozása",
     "Blank" : "Üres",
     "Unable to create new file from template" : "Nem lehet új fájlt létrehozni a sablonból",
+    "Delete permanently" : "Végleges törlés",
     "Set up templates folder" : "Személyes sablonmappa beállítása",
     "Templates" : "Sablonok",
     "Unable to initialize the templates directory" : "A sablonkönyvtár előkészítése sikertelen",
     "Toggle %1$s sublist" : "%1$s allista be/ki",
     "Toggle grid view" : "Rácsnézet be/ki",
-    "No files in here" : "Itt nincsenek fájlok",
     "Upload some content or sync with your devices!" : "Töltsön fel néhány tartalmat, vagy szinkronizáljon az eszközeivel.",
     "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
-    "Select all" : "Összes kijelölése",
     "Upload too large" : "A feltöltés túl nagy",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "A feltölteni próbált fájlok mérete meghaladja a kiszolgálón megengedett legnagyobb méretet.",
     "No favorites yet" : "Még nincsenek kedvencek",
     "Files and folders you mark as favorite will show up here" : "A kedvencnek jelölt fájlokat és mappákat itt találja meg",
-    "Deleted files" : "Törölt fájlok",
     "Shares" : "Megosztások",
     "Shared with others" : "Megosztva másokkal",
     "Shared with you" : "Megosztva Önnel",
@@ -229,10 +251,12 @@ OC.L10N.register(
     "New" : "Új",
     "Copied!" : "Másolva!",
     "Unlimited" : "Korlátlan",
+    "Search users" : "Fehasználók keresése",
     "Cannot transfer ownership of a file or folder you don't own" : "Nem ruházható át olyan fájl vagy mappa tulajdonjoga, amely nem Öné",
     "%s used" : "%s használt",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s / %2$s felhasználva",
-    "Settings" : "Beállítások"
+    "Settings" : "Beállítások",
+    "Deleted files" : "Törölt fájlok"
 },
 "nplurals=2; plural=(n != 1);");
