@@ -132,17 +132,19 @@ OC.L10N.register(
     "Ownership transfer done" : "Millifærslu eignarhalds er lokið",
     "in %s" : "í %s",
     "File Management" : "Skráastjórnun",
+    "Select all" : "Velja allt",
     "Transfer ownership of a file or folder" : "Millifæra eignarhald skráar eða möppu",
     "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Change" : "Breyta",
     "New owner" : "Nýr eigandi",
-    "Search users" : "Leita að notendum",
     "Choose a file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Transfer" : "Færa",
     "Transfer {path} to {userid}" : "Færa {path} til {userid}",
     "Invalid path selected" : "Ógild slóð valin",
     "Unknown error" : "Óþekkt villa",
     "Ownership transfer request sent" : "Beiðni um millifærslu eignarhalds send",
+    "No files in here" : "Engar skrár hér",
+    "Go back" : "Fara til baka",
     "Show hidden files" : "Sýna faldar skrár",
     "Crop image previews" : "Skera utan af forskoðun mynda",
     "Additional settings" : "Valfrjálsar stillingar",
@@ -156,19 +158,17 @@ OC.L10N.register(
     "Creating file" : "Bý til skrá",
     "Blank" : "Tóm",
     "Unable to create new file from template" : "Tekst ekki að búa til nýja skrá út frá sniðmáti",
+    "Delete permanently" : "Eyða varanlega",
     "Set up templates folder" : "Setja upp sniðmátamöppu",
     "Templates" : "Sniðmát",
     "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
     "Toggle grid view" : "Víxla reitasýn af/á",
-    "No files in here" : "Engar skrár hér",
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
     "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
-    "Select all" : "Velja allt",
     "Upload too large" : "Innsend skrá er of stór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
     "No favorites yet" : "Engin eftirlæti ennþá",
     "Files and folders you mark as favorite will show up here" : "Skrár og möppur sem þú merkir sem eftirlæti birtast hér",
-    "Deleted files" : "Eyddar skrár",
     "Shares" : "Sameignir",
     "Shared with others" : "Deilt með öðrum",
     "Shared with you" : "Deilt með þér",
@@ -183,9 +183,11 @@ OC.L10N.register(
     "New" : "Nýtt",
     "Copied!" : "Afritað!",
     "Unlimited" : "Ótakmarkað",
+    "Search users" : "Leita að notendum",
     "Cannot transfer ownership of a file or folder you don't own" : "Ekki er hægt að millifæra eignarhald á skrá eða möppu sem þú átt ekki",
     "%s used" : "%s notað",
     "%1$s of %2$s used" : "%1$s af %2$s notað",
-    "Settings" : "Stillingar"
+    "Settings" : "Stillingar",
+    "Deleted files" : "Eyddar skrár"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
