@@ -106,8 +106,11 @@ OC.L10N.register(
     "Accept" : "Akceptēt",
     "Reject" : "Noraidīt",
     "in %s" : "iekš %s",
+    "Select all" : "Atzīmēt visu",
     "Change" : "Mainīt",
     "Unknown error" : "Nezināma kļūda",
+    "No files in here" : "Šeit nav datņu",
+    "Go back" : "Atpakaļ",
     "Files settings" : "Failu iestatījumi",
     "Show hidden files" : "Rādīt slēptās datnes",
     "Crop image previews" : "Apgriezt attēlu priekšskatījumus",
@@ -117,15 +120,13 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Izmantojiet šo adresi, lai piekļūtu savām datnēm, izmantojot WebDAV",
     "Cancel" : "Atcelt",
     "Create" : "Izveidot",
+    "Delete permanently" : "Dzēst pavisam",
     "Toggle grid view" : "Pārslēgt režģa skatu",
-    "No files in here" : "Šeit nav datņu",
     "Upload some content or sync with your devices!" : "Augšupielādē kaut ko vai sinhronizē saturu ar savām ierīcēm!",
     "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
-    "Select all" : "Atzīmēt visu",
     "Upload too large" : "Datne ir par lielu, lai to augšupielādētu",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Augšupielādējamās datnes pārsniedz servera pieļaujamo datņu augšupielādes apjomu",
     "Files and folders you mark as favorite will show up here" : "Datnes un mapes, ko atzīmēsiet kā favorītus, tiks rādīti šeit",
-    "Deleted files" : "Dzēstās datnes",
     "Shares" : "Koplietots",
     "Shared with others" : "Koplietots ar citiem",
     "Shared with you" : "Koplietots ar tevi",
@@ -142,6 +143,7 @@ OC.L10N.register(
     "Unlimited" : "Neierobežota",
     "%s used" : "%s izmantoti",
     "%1$s of %2$s used" : "%1$s no %2$s lietoti",
-    "Settings" : "Iestatījumi"
+    "Settings" : "Iestatījumi",
+    "Deleted files" : "Dzēstās datnes"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
