@@ -6,6 +6,7 @@ OC.L10N.register(
     "Download" : "Татаж авах ",
     "Delete" : "Устгах",
     "Tags" : "Тэгүүд",
+    "Show list view" : "Жагсаалтаар харуул",
     "Home" : "Нүүр хуудас",
     "Close" : "Хаах",
     "Favorites" : "Онцолсон",
@@ -18,6 +19,7 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "{dir} гэх байршуулах хавтас олдсонгүй",
     "Not enough free space" : "Сул зай хүрэлцэхгүй байна",
     "An unknown error has occurred" : "Үл мэдэгдэх алдаа гарлаа ",
+    "File could not be uploaded" : "Файлыг байршуулах боломжгүй байна",
     "Uploading …" : "Байршуулж байна...",
     "Uploading that item is not supported" : "Энэ төрлийн файл байршуулах боломжгүй",
     "Target folder does not exist any more" : "Байршуулах хавтас олдсонгүй",
@@ -27,13 +29,15 @@ OC.L10N.register(
     "Rename" : "Нэр өөрчлөх",
     "Move" : "Зөөх",
     "Copy" : "Хуулах",
-    "Open" : "Онгойлгох",
+    "Choose target folder" : "Зорилтот хавтасыг сонгох",
+    "Open" : "Нээх",
     "Delete file" : "Файл устгах",
     "Delete folder" : "Хавтсыг устгах",
     "Disconnect storage" : "Хадгалах төхөөрөмж салгах",
     "Could not load info for file \"{file}\"" : "\"{file}\" файлын мэдээллийг уншиж чадсангүй",
     "Files" : "Файлууд",
     "Details" : "Дэлгэрэнгүй",
+    "Select file \"{fileName}\"" : "\"{fileName}\" файлыг сонгох",
     "Pending" : "Хүлээгдэж байгаа",
     "Unable to determine date" : "Огноог тодорхойлох боломжгүй",
     "This operation is forbidden" : "Энэ үйлдэл хориотой",
@@ -54,6 +58,7 @@ OC.L10N.register(
     "Could not create folder \"{dir}\" because it already exists" : " \"{dir}\" хавтасыг үүсгэх боломжгүй, нэр нь давцаж байна",
     "Error deleting file \"{fileName}\"." : "\"{fileName}\" файлыг устгахад алдаа гарлаа.",
     "No search results in other folders for {tag}{filter}{endtag}" : "{tag}{filter}{endtag} хайлтад тохирох үр дүн бусад хавтасаас олсонгүй",
+    "Enter more than two characters to search in other folders" : "Бусад хавтаснаас хайхын тулд хоёроос илүү тэмдэгт оруулна уу",
     "Name" : "Нэр",
     "Size" : "Хэмжээ",
     "Modified" : "Өөрчлөгдсөн",
@@ -61,12 +66,14 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["файл","файлууд"],
     "{dirs} and {files}" : "{dirs} болон {files}",
     "_including %n hidden_::_including %n hidden_" : ["нуугдсан %n хамруулан","нуугдсан %n хамруулан"],
+    "You do not have permission to upload or create files here" : "Та энд файл үүсгэх эсвэл байршуулах эрхгүй байна.",
     "_Uploading %n file_::_Uploading %n files_" : ["Файлыг байршуулж байна","%n файлыг байршуулж байна"],
     "{used} of {quota} used" : "{quota} оноосноос {used} хэрэглэсэн",
     "{used} used" : "{user} хэрэглэсэн",
     "\"{name}\" is an invalid file name." : "\"{name}\" нь хүчин төгөлдөр бус файлын нэр",
     "File name cannot be empty." : "Файлын нэр хоосон байж болохгүй.",
     "\"/\" is not allowed inside a file name." : "файлын нэр \"/\" агуулж болохгүй",
+    "\"{name}\" is not an allowed filetype" : "\"{name}\" файлын төрөл буруу байна",
     "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner}-ий багтаамж удахгүй дүүрэх гэж байна. ({usedSpacePercent}%)",
     "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Хамт-ийн фолдер \"{mountPoint}\" удахгүй дүйрэх гэж байна {usedSpacePercent}%)",
     "Your storage is almost full ({usedSpacePercent}%)." : "Таны багтаамж дүүрэх дөхөж байна! ({usedSpacePercent}%)",
@@ -109,16 +116,18 @@ OC.L10N.register(
     "A file or folder has been <strong>changed</strong>" : "Файл эсвэл хавтас амжилттай <strong>солигдлоо</strong>",
     "All files" : "Бүх файлууд",
     "Accept" : "Хүлээн зөвшөөрөх",
+    "File Management" : "Файлын удирдлага",
+    "Select all" : "бүгдийг сонгох",
     "Unknown error" : "Үл мэдэгдэх алдаа",
+    "No files in here" : "Энд файл байхгүй байна",
+    "Go back" : "Буцах",
     "Show hidden files" : "Нууцлагдсан файлыг харах",
     "Cancel" : "болиулах",
     "Create" : "Үүсгэх",
-    "No files in here" : "Энд файл байхгүй байна",
+    "Delete permanently" : "бүр мөсөн устгах",
     "No entries found in this folder" : "энэ хавтсан олдсон ч ямарч мэдээлэл олдохгүй байна",
-    "Select all" : "бүгдийг сонгох",
     "Upload too large" : "маш том байршуулалт",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Таны байршуулах гэж оролдсон файлууд нь энэ сервер дээр файл байршуулах дээд хэмжээнээс хэтэрч.",
-    "Deleted files" : "Устгасан файлууд",
     "Shares" : "Түгээлтүүд",
     "Shared with others" : "Бусдад түгээсэн",
     "Shared with you" : "тантай хуваалцсан",
@@ -131,6 +140,7 @@ OC.L10N.register(
     "New" : "Шинэ",
     "Copied!" : "Хуулсан!",
     "%1$s of %2$s used" : "%1$s-с %2$s хэрэглэсэн",
-    "Settings" : "Тохиргоо"
+    "Settings" : "Тохиргоо",
+    "Deleted files" : "Устгасан файлууд"
 },
 "nplurals=2; plural=(n != 1);");
