@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Przeniesienie własności {path} z {user} zostało zakończone.",
     "in %s" : "w %s",
     "File Management" : "Zarządzanie plikami",
+    "Reload current directory" : "Przeładuj bieżący katalog",
+    "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
+    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
+    "Open folder {name}" : "Otwórz katalog {name}",
+    "Download file {name}" : "Pobierz plik {name}",
+    "\"{displayName}\" action executed successfully" : "Akcja \"{displayName}\" została wykonana pomyślnie",
+    "\"{displayName}\" action failed" : "Akcja \"{displayName}\" nie powiodła się",
+    "Total rows summary" : "Podsumowanie wszystkich wierszy",
+    "Select all" : "Wybierz wszystko",
+    "Unselect all" : "Odznacz wszystko",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" nie powiodło się w przypadku niektórych elementów",
+    "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
+    "ascending" : "rosnąco",
+    "descending" : "malejąco",
+    "Sort list by {column} ({direction})" : "Sortuj listę według {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
     "Storage informations" : "Informacje o przechowywaniu",
     "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
     "{relative}% used" : "Wykorzystano {relative}%",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Change" : "Zmień",
     "New owner" : "Nowy właściciel",
-    "Search users" : "Wyszukaj użytkowników",
     "Choose a file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Transfer" : "Przenieś",
     "Transfer {path} to {userid}" : "Przenieś {path} do {userid}",
@@ -183,15 +198,24 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Wysłano żądanie przeniesienia własności",
     "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
     "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
+    "Loading current folder" : "Ładowanie bieżącego katalogu",
+    "No files in here" : "Brak plików",
+    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte",
+    "Go to the previous folder" : "Przejdź do poprzedniego katalogu",
+    "Go back" : "Wstecz",
     "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
     "Files settings" : "Ustawienia Plików",
+    "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
+    "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
     "Show hidden files" : "Pokaż ukryte pliki",
     "Crop image previews" : "Przytnij podglądy obrazów",
     "Additional settings" : "Ustawienia dodatkowe",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiuj do schowka",
     "Use this address to access your Files via WebDAV" : "Użyj tego adresu, aby uzyskać dostęp do plików poprzez WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jeśli włączyłeś 2FA, musisz utworzyć i używać nowego hasła do aplikacji, klikając tutaj.",
     "Clipboard is not available" : "Schowek jest niedostępny",
+    "WebDAV URL copied to clipboard" : "Adres URL WebDAV skopiowany do schowka",
     "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
     "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
     "Pick a template for {name}" : "Wybierz szablon dla {name}",
@@ -201,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Tworzenie pliku",
     "Blank" : "Pusty",
     "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
+    "Delete permanently" : "Usuń bezpowrotnie",
     "Set up templates folder" : "Skonfiguruj katalog szablonów",
     "Templates" : "Szablony",
     "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
     "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
     "Toggle grid view" : "Przełącz widok siatki",
-    "No files in here" : "Brak plików",
     "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
     "No entries found in this folder" : "Brak wpisów w tym katalogu",
-    "Select all" : "Wybierz wszystko",
     "Upload too large" : "Wysyłany plik jest za duży",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
     "No favorites yet" : "Brak ulubionych",
     "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
-    "Deleted files" : "Usunięte pliki",
     "Shares" : "Udostępnione",
     "Shared with others" : "Udostępnione innym",
     "Shared with you" : "Udostępnione dla Ciebie",
@@ -229,10 +251,12 @@ OC.L10N.register(
     "New" : "Nowy",
     "Copied!" : "Skopiowano!",
     "Unlimited" : "Brak limitu",
+    "Search users" : "Wyszukaj użytkowników",
     "Cannot transfer ownership of a file or folder you don't own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
     "%s used" : "Wykorzystane: %s",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "Wykorzystane: %1$s z %2$s",
-    "Settings" : "Ustawienia"
+    "Settings" : "Ustawienia",
+    "Deleted files" : "Usunięte pliki"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
