@@ -166,6 +166,7 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "A transferência da propriedade de {path} de {user} foi concluída.",
     "in %s" : "em %s",
     "File Management" : "Gerenciamento de Arquivos",
+    "Select all" : "Selecionar tudo",
     "Storage informations" : "Informações de armazenamento",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{relative}% used" : "{relative}% usado",
@@ -174,7 +175,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
     "Change" : "Mudar",
     "New owner" : "Novo proprietário",
-    "Search users" : "Procurar usuários",
     "Choose a file or folder to transfer" : "Escolha o arquivo ou pasta a transferir",
     "Transfer" : "Transferir",
     "Transfer {path} to {userid}" : "Transferir {path} para {userid}",
@@ -183,14 +183,19 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Solicitação de transferência de propriedade enviada",
     "Cannot transfer ownership of a file or folder you do not own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
     "Select file or folder to link to" : "Selecione o arquivo ou pasta para vincular",
+    "No files in here" : "Nenhum arquivo aqui",
+    "Go back" : "Voltar",
     "Open the files app settings" : "Abra as configurações do aplicativo de arquivos",
     "Files settings" : "Configurações de arquivos",
+    "File cannot be accessed" : "File cannot be accessed",
+    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
     "Show hidden files" : "Mostrar arquivos ocultos",
     "Crop image previews" : "Cortar visualizações de imagem",
     "Additional settings" : "Configurações adicionais",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar para área de transferência",
     "Use this address to access your Files via WebDAV" : "Use este endereço para acessar seus Arquivos via WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "If you have enabled 2FA, you must create and use a new app password by clicking here.",
     "Clipboard is not available" : "A área de transferência não está disponível",
     "WebDAV URL copied to clipboard" : "URL do WebDAV copiado para a área de transferência",
     "Unable to change the favourite state of the file" : "Não foi possível alterar o estado favorito do arquivo",
@@ -202,20 +207,18 @@ OC.L10N.register(
     "Creating file" : "Criando arquivo ",
     "Blank" : "Em branco ",
     "Unable to create new file from template" : "Incapaz de criar novo arquivo a partir do modelo ",
+    "Delete permanently" : "Remover permanentemente",
     "Set up templates folder" : "Configurar pasta de modelos ",
     "Templates" : "Modelos ",
     "Unable to initialize the templates directory" : "Não foi possível inicializar o diretório de modelos ",
     "Toggle %1$s sublist" : "Alternar a sublista %1$s",
     "Toggle grid view" : "Alternar a visão em grade",
-    "No files in here" : "Nenhum arquivo aqui",
     "Upload some content or sync with your devices!" : "Envie um arquivo ou sincronize com seus dispositivos!",
     "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
-    "Select all" : "Selecionar tudo",
     "Upload too large" : "Arquivo muito grande para envio",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os arquivos que você está tentando enviar excederam o tamanho máximo para arquivos no servidor.",
     "No favorites yet" : "Você não possui favoritos!",
     "Files and folders you mark as favorite will show up here" : "Suas pastas e arquivos favoritos serão exibidos aqui.",
-    "Deleted files" : "Arquivos apagados",
     "Shares" : "Compartilhamentos",
     "Shared with others" : "Compartilhado com os outros",
     "Shared with you" : "Compartilhado com você",
@@ -230,10 +233,12 @@ OC.L10N.register(
     "New" : "Novo",
     "Copied!" : "Copiado!",
     "Unlimited" : "Ilimitado",
+    "Search users" : "Procurar usuários",
     "Cannot transfer ownership of a file or folder you don't own" : "Não é possível transferir a propriedade de um arquivo ou pasta que você não possui",
     "%s used" : "%s usado",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s usados de %2$s",
-    "Settings" : "Configurações"
+    "Settings" : "Configurações",
+    "Deleted files" : "Arquivos apagados"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
