@@ -6,6 +6,8 @@ OC.L10N.register(
     "Download" : "Transferir",
     "Delete" : "Apagar",
     "Tags" : "Etiquetas",
+    "Show list view" : "Mostrar visualização em lista",
+    "Show grid view" : "Mostrar visualização em grelha",
     "Home" : "Início",
     "Close" : "Fechar",
     "Favorites" : "Favoritos",
@@ -19,6 +21,7 @@ OC.L10N.register(
     "Target folder \"{dir}\" does not exist any more" : "A pasta de destino \"{dir}\" já não existe",
     "Not enough free space" : "Espaço insuficiente",
     "An unknown error has occurred" : "Ocorreu um erro desconhecido",
+    "File could not be uploaded" : "O ficheiro não foi carregado",
     "Uploading …" : "A carregar ...",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "O carregamento do item não é suportado",
@@ -30,13 +33,19 @@ OC.L10N.register(
     "Move" : "Mover",
     "Copy" : "Copiar",
     "Choose target folder" : "Escolher pasta de destino",
+    "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
     "Delete file" : "Apagar ficheiro",
     "Delete folder" : "Apagar pasta",
     "Disconnect storage" : "Desligue o armazenamento",
+    "Leave this share" : "Sair desta partilha",
     "Could not load info for file \"{file}\"" : "Não foi possível carregar informações do ficheiro \"{file}\"",
     "Files" : "Ficheiros",
     "Details" : "Detalhes",
+    "Please select tag(s) to add to the selection" : "Selecione a(s) etiquetas(s) para adicionar à seleção ",
+    "Apply tag(s) to selection" : "Aplicar etiqueta(s) à seleção",
+    "Select directory \"{dirName}\"" : "Selecionar o diretório \"{dirName}\"",
+    "Select file \"{fileName}\"" : "Selecionar o ficheiro \"{fileName}\"",
     "Pending" : "Pendente",
     "Unable to determine date" : "Não é possível determinar a data",
     "This operation is forbidden" : "Esta operação é proibida",
@@ -49,6 +58,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "Impossível copiar \"{file}\"",
     "Copied {origin} inside {destination}" : "Copiado {origin} para {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} outros ficheiros para dentro de {destination}",
+    "Failed to redirect to client" : "Erro ao redirecionar para o cliente",
     "{newName} already exists" : "{newName} já existe",
     "Could not rename \"{fileName}\", it does not exist any more" : "Não foi possível renomear \"{fileName}\", este já não existe",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome \"{targetName}\" já está em utilização na pasta \"{dir}\". Por favor, escolha um nome diferente.",
@@ -67,8 +77,11 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros","%n ficheiros"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluindo %n ocultos","incluindo %n ocultos","incluindo %n ocultos"],
+    "You do not have permission to upload or create files here" : "Não tem permissão para carregar ou criar ficheiros aqui",
     "_Uploading %n file_::_Uploading %n files_" : ["A enviar %n ficheiro","A enviar %n ficheiros","A enviar %n ficheiros"],
+    "New file/folder menu" : "Novo menu ficheiro/pasta",
     "Select file range" : "Selecionar o intervalo",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "utilizado {used} de {quota}",
     "{used} used" : "{used} utilizado",
     "\"{name}\" is an invalid file name." : "\"{name}\" é um nome de ficheiro inválido.",
@@ -122,30 +135,29 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "Um ficheiro foi adicionado ou removido dos seus <strong>favoritos</strong>",
     "A file or folder has been <strong>changed</strong>" : "Foi <strong>alterado</strong> um ficheiro ou pasta",
     "All files" : "Todos os ficheiros",
-    "Unlimited" : "Ilimitado",
     "Upload (max. %s)" : "Envio (máx. %s)",
     "Accept" : "Aceitar",
     "in %s" : "em %s",
+    "Select all" : "Selecionar todos",
+    "Change" : "Mudar",
     "Transfer" : "Transfere",
     "Unknown error" : "Erro desconhecido",
+    "No files in here" : "Nenhuns ficheiros aqui",
+    "Go back" : "Voltar",
     "Show hidden files" : "Mostrar ficheiros ocultos",
     "Additional settings" : "Definições adicionais",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Copiar para área de transferência",
     "Cancel" : "Cancelar",
     "Create" : "Criar",
+    "Delete permanently" : "Eliminar permanentemente",
     "Templates" : "Modelos",
-    "%s used" : "%s utilizado",
-    "%1$s of %2$s used" : "Usado %1$s de %2$s",
-    "WebDAV" : "WebDAV",
-    "No files in here" : "Nenhuns ficheiros aqui",
     "Upload some content or sync with your devices!" : "Envie algum conteúdo ou sincronize com os seus dispositivos!",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
-    "Select all" : "Selecionar todos",
     "Upload too large" : "Envio muito grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que está a tentar enviar excedem o tamanho máximo para os envios de ficheiro neste servidor.",
     "No favorites yet" : "Sem favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e pastas que marcou como favoritos serão mostrados aqui",
-    "Deleted files" : "Ficheiros eliminados",
     "Shares" : "Partilhas",
     "Shared with others" : "Partilhado com terceiros",
     "Shared with you" : "Partilhado consigo ",
@@ -157,6 +169,10 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "Não tem permissão para enviar ou criar ficheiros aqui",
     "New" : "Novo",
     "Copied!" : "Copiado!",
-    "Settings" : "Configurações"
+    "Unlimited" : "Ilimitado",
+    "%s used" : "%s utilizado",
+    "%1$s of %2$s used" : "Usado %1$s de %2$s",
+    "Settings" : "Configurações",
+    "Deleted files" : "Ficheiros eliminados"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
