@@ -161,11 +161,11 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Transferul de proprietate de {path} către {user} s-a finalizat.",
     "in %s" : "în %s",
     "File Management" : "Management fișiere",
+    "Select all" : "Selectează tot",
     "Transfer ownership of a file or folder" : "Transferă proprietatea unui fisier sau dosar",
     "Choose file or folder to transfer" : "Alege fișierul sau dosarul de transferat",
     "Change" : "Modificare",
     "New owner" : "Proprietarul nou",
-    "Search users" : "Cauta utilizatori",
     "Choose a file or folder to transfer" : "Alege un fișier sau dosar de transferat",
     "Transfer" : "Transfer",
     "Transfer {path} to {userid}" : "Transferă {path} către {userid}",
@@ -173,6 +173,8 @@ OC.L10N.register(
     "Unknown error" : "Eroare necunoscută",
     "Ownership transfer request sent" : "Cererea de transfer a fost trimisă",
     "Cannot transfer ownership of a file or folder you do not own" : "Nu se poate transfera proprietatea unui fișier sau dosar daca nu le deții",
+    "No files in here" : "Niciun fișier aici",
+    "Go back" : "Înapoi",
     "Show hidden files" : "Arată fișierele ascunse",
     "Crop image previews" : "Previzualizarea imaginii decupate",
     "Additional settings" : "Setări adiționale",
@@ -188,20 +190,18 @@ OC.L10N.register(
     "Creating file" : "Se crează fișierul",
     "Blank" : "Gol",
     "Unable to create new file from template" : "Nu s-a putut creea un fisier nou pentru acest șablon",
+    "Delete permanently" : "Șterge permanent",
     "Set up templates folder" : "Setează un dosar pentru șabloane",
     "Templates" : "Șabloane",
     "Unable to initialize the templates directory" : "Nu s-a putut inițializa dosarul cu șabloane",
     "Toggle %1$s sublist" : "Comută %1$s sublistă",
     "Toggle grid view" : "Comută vizualizarea grilă",
-    "No files in here" : "Niciun fișier aici",
     "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
     "No entries found in this folder" : "Niciun element găsit în acest director",
-    "Select all" : "Selectează tot",
     "Upload too large" : "Fișierul încărcat este prea mare",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
     "No favorites yet" : "Nu aveți favorite încă",
     "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
-    "Deleted files" : "Fișiere șterse",
     "Shares" : "Partajări",
     "Shared with others" : "Partajat cu alții",
     "Shared with you" : "Partajat cu tine",
@@ -216,9 +216,11 @@ OC.L10N.register(
     "New" : "Nou",
     "Copied!" : "S-a copiat!",
     "Unlimited" : "Nelimitată",
+    "Search users" : "Cauta utilizatori",
     "Cannot transfer ownership of a file or folder you don't own" : "Nu se poate transfera proprietatea unui fișier sau dosar ce nu le deții",
     "%s used" : "%s folosiți",
     "%1$s of %2$s used" : "%1$s din %2$s utilizat",
-    "Settings" : "Setări"
+    "Settings" : "Setări",
+    "Deleted files" : "Fișiere șterse"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
