@@ -98,6 +98,7 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
     "View in folder" : "Посмотреть в каталоге",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
     "Path" : "Путь",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
     "Favorited" : "Избранное",
@@ -165,11 +166,15 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
     "in %s" : "в %s",
     "File Management" : "Управление файлами",
+    "Select all" : "Выбрать всё",
+    "Storage informations" : "Сведения о хранилище",
+    "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
+    "{relative}% used" : "Использовано {relative}%",
+    "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
     "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
     "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
     "Change" : "Изменить",
     "New owner" : "Новый владелец",
-    "Search users" : "Поиск пользователей",
     "Choose a file or folder to transfer" : "Выберите файл или папку для передачи",
     "Transfer" : "Передать",
     "Transfer {path} to {userid}" : "Передать {path} пользователю {userid}",
@@ -177,14 +182,22 @@ OC.L10N.register(
     "Unknown error" : "Неизвестная ошибка",
     "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
     "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
+    "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
+    "No files in here" : "Здесь нет файлов",
+    "Go back" : "Назад",
+    "Open the files app settings" : "Открыть параметры приложения «Файлы»",
     "Files settings" : "Настройки файлов",
+    "File cannot be accessed" : "Не удалось получить доступ к файлу",
+    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
     "Show hidden files" : "Показывать скрытые файлы",
     "Crop image previews" : "Обрезать пред. просмотр",
     "Additional settings" : "Дополнительные параметры",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Копировать в буфер",
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы используете двухфакторную аутентификацию, то нажмите здесь чтобы создать пароль приложения.",
     "Clipboard is not available" : "Буфер обмена недоступен",
+    "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
     "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
     "Error while loading the file data" : "Не удалось загрузить данные файла",
     "Pick a template for {name}" : "Выбрать шаблон для {name}",
@@ -194,20 +207,18 @@ OC.L10N.register(
     "Creating file" : "Создание файла",
     "Blank" : "Пустой",
     "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
+    "Delete permanently" : "Удалить навсегда",
     "Set up templates folder" : "Указать папку шаблонов",
     "Templates" : "Шаблоны",
     "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "Toggle %1$s sublist" : "Переключить %1$s подсписок",
     "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
-    "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "No entries found in this folder" : "В этом каталоге ничего не найдено",
-    "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "No favorites yet" : "В избранное ещё ничего не добавлено ",
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
-    "Deleted files" : "Корзина",
     "Shares" : "Общие ресурсы",
     "Shared with others" : "Доступные для других",
     "Shared with you" : "Доступные для вас",
@@ -222,10 +233,12 @@ OC.L10N.register(
     "New" : "Новый",
     "Copied!" : "Скопировано!",
     "Unlimited" : "Неограничено",
+    "Search users" : "Поиск пользователей",
     "Cannot transfer ownership of a file or folder you don't own" : "Изменение владельца возможно только для своих файлов и папок",
     "%s used" : "%s использовано",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "использовано %1$s из %2$s ",
-    "Settings" : "Настройки"
+    "Settings" : "Настройки",
+    "Deleted files" : "Корзина"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
