@@ -155,17 +155,19 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Tràmuda de propriedade de {path} dae {user} cumpletada.",
     "in %s" : "in %s",
     "File Management" : "Gestione archìvios",
+    "Select all" : "Seletziona totu",
     "Transfer ownership of a file or folder" : "Tràmuda propriedade de un'archìviu o una cartella",
     "Choose file or folder to transfer" : "Sèbera archìviu o cartella de tramudare",
     "Change" : "Càmbia",
     "New owner" : "Propriedade noa",
-    "Search users" : "Chirca utentes",
     "Choose a file or folder to transfer" : "Sèbera un'archìviu o una cartella de tramudare",
     "Transfer" : "Tràmuda",
     "Transfer {path} to {userid}" : "Tràmuda {path} a {userid}",
     "Invalid path selected" : "Percursu seletzionadu non vàlidu",
     "Unknown error" : "Errore disconnotu",
     "Ownership transfer request sent" : "Dimanda de tràmuda de propriedade imbiada",
+    "No files in here" : "Perunu archìviu",
+    "Go back" : "In segus",
     "Show hidden files" : "Mustra archìvios cuados",
     "Crop image previews" : "Retàllia anteprimas de s'imàgine",
     "Additional settings" : "Impostatziones in agiunta",
@@ -181,20 +183,18 @@ OC.L10N.register(
     "Creating file" : "Creende s'archìviu",
     "Blank" : "Isbòidu",
     "Unable to create new file from template" : "Non faghet a creare un'archìviu nou dae su modellu",
+    "Delete permanently" : "Cantzella in manera definitiva",
     "Set up templates folder" : "Imposta cartella de is modellos",
     "Templates" : "Modellos",
     "Unable to initialize the templates directory" : "Non faghet a initzializare sa cartella de is modellos",
     "Toggle %1$s sublist" : "Passa a sa sutalista %1$s",
     "Toggle grid view" : "Càmbia a visualizatzione in mosàicu",
-    "No files in here" : "Perunu archìviu",
     "Upload some content or sync with your devices!" : "Càrriga cuntenutos o sincroniza cun is dispositivos tuos!",
     "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
-    "Select all" : "Seletziona totu",
     "Upload too large" : "Carrigamentu tropu mannu",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Is archìvios chi boles carrigare passant sa mannària màssima de carrigamentu de archìvios in custu serbidore.",
     "No favorites yet" : "Ancora perunu preferidu",
     "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
-    "Deleted files" : "Archìvios cantzellados",
     "Shares" : "Cumpartziduras",
     "Shared with others" : "Cumpartzidu cun àtere",
     "Shared with you" : "Cumpartzidu cun tegus",
@@ -209,9 +209,11 @@ OC.L10N.register(
     "New" : "Nou",
     "Copied!" : "Copiadu!",
     "Unlimited" : "Chene lìmites",
+    "Search users" : "Chirca utentes",
     "Cannot transfer ownership of a file or folder you don't own" : "Non faghet a tramudare sa propriedade de un'archìviu o cartella de is chi non ses mere",
     "%s used" : "%s impreadu",
     "%1$s of %2$s used" : "%1$s de %2$s impreadu",
-    "Settings" : "Impostatziones"
+    "Settings" : "Impostatziones",
+    "Deleted files" : "Archìvios cantzellados"
 },
 "nplurals=2; plural=(n != 1);");
