@@ -155,17 +155,19 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva {path} z uporabnika {user} je končan.",
     "in %s" : "v %s",
     "File Management" : "Upravljanje datotek",
+    "Select all" : "izberi vse",
     "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
     "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Change" : "Spremeni",
     "New owner" : "Nov lastnik",
-    "Search users" : "Iskanje uporabnikov",
     "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Transfer" : "Prenos",
     "Transfer {path} to {userid}" : "Prenesi pot {path} k uporabniku {userid}",
     "Invalid path selected" : "Izbrana je neveljavna pot",
     "Unknown error" : "Neznana napaka",
     "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
+    "No files in here" : "V mapi ni datotek",
+    "Go back" : "Skoči nazaj",
     "Show hidden files" : "Pokaži skrite datoteke",
     "Crop image previews" : "Obreži slike predogleda",
     "Additional settings" : "Dodatne nastavitve",
@@ -181,20 +183,18 @@ OC.L10N.register(
     "Creating file" : "Poteka ustvarjanje datoteke",
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
+    "Delete permanently" : "Trajno izbriši",
     "Set up templates folder" : "Nastavitev mape predlog",
     "Templates" : "Predloge",
     "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
     "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
     "Toggle grid view" : "Preklopi mrežni pogled",
-    "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
-    "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
     "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
     "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
-    "Deleted files" : "Izbrisane datoteke",
     "Shares" : "Souporaba",
     "Shared with others" : "V souporabi  z drugimi",
     "Shared with you" : "V skupni rabi z vami",
@@ -209,9 +209,11 @@ OC.L10N.register(
     "New" : "Novo",
     "Copied!" : "Kopirano!",
     "Unlimited" : "Neomejeno",
+    "Search users" : "Iskanje uporabnikov",
     "Cannot transfer ownership of a file or folder you don't own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
     "%s used" : "Uporabljeno %s",
     "%1$s of %2$s used" : "Uporabljeno %1$s od %2$s",
-    "Settings" : "Nastavitve"
+    "Settings" : "Nastavitve",
+    "Deleted files" : "Izbrisane datoteke"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
