@@ -96,23 +96,24 @@ OC.L10N.register(
     "Upload (max. %s)" : "Ngarkim (max. %s)",
     "Accept" : "Prano",
     "in %s" : "në %s",
+    "Select all" : "Përzgjidhe krejt",
     "Change" : "Ndrysho",
     "Unknown error" : "Gabim i panjohur",
+    "No files in here" : "S’ka kartela këtu",
+    "Go back" : "Shko prapa",
     "Show hidden files" : "Shfaq kartela të fshehura",
     "Additional settings" : "Konfigurime shtesë",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopjo në dërrasë ",
     "Cancel" : "Anullo",
     "Create" : "Krijo",
-    "No files in here" : "S’ka kartela këtu",
+    "Delete permanently" : "Fshije përgjithmonë",
     "Upload some content or sync with your devices!" : "Ngarkoni ca lëndë ose bëni njëkohësim me pajisjet tuaja!",
     "No entries found in this folder" : "Në këtë dosje s’u gjetën zëra",
-    "Select all" : "Përzgjidhe krejt",
     "Upload too large" : "Ngarkim shumë i madh",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Kartelat që po rrekeni të ngarkoni e tejkalojnë madhësinë maksimale për ngarkime kartelash në këtë shërbyes.",
     "No favorites yet" : "Asnjë preferencë akoma",
     "Files and folders you mark as favorite will show up here" : "Këtu do të duken kartelat dhe dosjet që i shënoni si të parapëlqyera",
-    "Deleted files" : "Skedar të fshirë",
     "Shares" : "Shpërndarjet",
     "Shared with others" : "E ndarë me të tjerët",
     "Shared with you" : "E ndarë me ju",
@@ -128,6 +129,7 @@ OC.L10N.register(
     "Unlimited" : "E palimituar",
     "%s used" : "%s të përdorura",
     "%1$s of %2$s used" : "%1$s e %2$s përdorur",
-    "Settings" : "Rregullime"
+    "Settings" : "Rregullime",
+    "Deleted files" : "Skedar të fshirë"
 },
 "nplurals=2; plural=(n != 1);");
