@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
     "in %s" : "за %s",
     "File Management" : "Управљање фајловима",
+    "Reload current directory" : "Поново учитај текући директоријум",
+    "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
+    "Select the row for {displayName}" : "Изабери ред за {displayName}",
+    "Open folder {name}" : "Отвори фолдер {name}",
+    "Download file {name}" : "Преузми фајл {name}",
+    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
+    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
+    "Total rows summary" : "Резиме укупног броја редова",
+    "Select all" : "Означи све",
+    "Unselect all" : "Поништи цео избор",
+    "\"{displayName}\" failed on some elements " : "„{displayName}” није успело на неким елементима",
+    "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
+    "ascending" : "растуће",
+    "descending" : "опадајуће",
+    "Sort list by {column} ({direction})" : "Поређај листу по {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
     "Storage informations" : "Информације о складишту`",
     "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
     "{relative}% used" : "{relative}% искоришћено",
@@ -174,7 +190,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
     "Change" : "Измени",
     "New owner" : "Нови власник",
-    "Search users" : "Претражи кориснике",
     "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
     "Transfer" : "Пренеси",
     "Transfer {path} to {userid}" : "Пренеси {path} на корисника {userid}",
@@ -183,6 +198,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Послат захтев за пренос власништва",
     "Cannot transfer ownership of a file or folder you do not own" : "Не можете да пренесете власништво над фајлом или фолдером који не поседујете",
     "Select file or folder to link to" : "Изаберите фајл или фордер на који показује линк",
+    "Loading current folder" : "Учитавање текућег фолдера",
+    "No files in here" : "Овде нема фајлова",
+    "No files or folders have been deleted yet" : "Још увек није обрисан ниједан фајл или фолдер",
+    "Go to the previous folder" : "Иди на претходни фолдер",
+    "Go back" : "Иди назад",
     "Open the files app settings" : "Отвори подешавања апликације фајлови",
     "Files settings" : "Подешавања фајлова",
     "File cannot be accessed" : "Фајлу не може да се приступи",
@@ -205,20 +225,18 @@ OC.L10N.register(
     "Creating file" : "Креирање фајла",
     "Blank" : "Празно",
     "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
+    "Delete permanently" : "Обриши заувек",
     "Set up templates folder" : "Постављање фолдера са шаблонима",
     "Templates" : "Шаблони",
     "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
     "Toggle %1$s sublist" : "Укљ./искљ. %1$s подлисте",
     "Toggle grid view" : "Укључи/искључи приказ мреже",
-    "No files in here" : "Овде нема фајлова",
     "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
     "No entries found in this folder" : "Нема ничега у овој фасцикли",
-    "Select all" : "Означи све",
     "Upload too large" : "Отпремање је превелико",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
     "No favorites yet" : "Још нема омиљених",
     "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
-    "Deleted files" : "Обрисани фајлови",
     "Shares" : "Дељења",
     "Shared with others" : "Дељени са осталима",
     "Shared with you" : "Дељени са вама",
@@ -233,10 +251,12 @@ OC.L10N.register(
     "New" : "Ново",
     "Copied!" : "Копирано!",
     "Unlimited" : "Неограничено",
+    "Search users" : "Претражи кориснике",
     "Cannot transfer ownership of a file or folder you don't own" : "Не можете пренети власништво фајла или фасцикле које нису Ваше",
     "%s used" : "%s искоришћено",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "Заузето %1$s од %2$s",
-    "Settings" : "Поставке"
+    "Settings" : "Поставке",
+    "Deleted files" : "Обрисани фајлови"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
