@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
     "in %s" : "om %s",
     "File Management" : "Filhantering",
+    "Reload current directory" : "Ladda om nuvarande mapp",
+    "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
+    "Select the row for {displayName}" : "Välj raden för {displayName}",
+    "Open folder {name}" : "Öppna mappen {name}",
+    "Download file {name}" : "Ladda ner filen {name}",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
+    "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
+    "Total rows summary" : "Sammanfattning antal rader",
+    "Select all" : "Välj allt",
+    "Unselect all" : "Avmarkera alla",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" misslyckades med vissa element",
+    "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
+    "ascending" : "stigande",
+    "descending" : "fallande",
+    "Sort list by {column} ({direction})" : "Sortera listan efter {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
     "Storage informations" : "Lagringsinformation",
     "{usedQuotaByte} used" : "{usedQuotaByte} använt",
     "{relative}% used" : "{relative}% använt",
@@ -174,7 +190,7 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
     "Change" : "Ändra",
     "New owner" : "Ny ägare",
-    "Search users" : "Sök användare",
+    "Search for an account" : "Sök efter ett konto",
     "Choose a file or folder to transfer" : "Välj en fil eller mapp att överföra",
     "Transfer" : "Överför",
     "Transfer {path} to {userid}" : "Överför {path} till {userid}",
@@ -182,14 +198,23 @@ OC.L10N.register(
     "Unknown error" : "Okänt fel",
     "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
     "Cannot transfer ownership of a file or folder you do not own" : "Det går inte att överföra äganderätten till en fil eller mapp som du inte äger",
+    "Select file or folder to link to" : "Välj fil eller mapp att länka till",
+    "Loading current folder" : "Laddar aktuell mapp",
+    "No files in here" : "Inga filer kunde hittas",
+    "No files or folders have been deleted yet" : "Inga filer eller mappar har tagits bort än",
+    "Go to the previous folder" : "Gå till föregående mapp",
+    "Go back" : "Gå tillbaks",
     "Open the files app settings" : "Öppna filappens inställningar",
     "Files settings" : "Filinställningar",
+    "File cannot be accessed" : "Det går inte att komma åt filen",
+    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
     "Show hidden files" : "Visa dolda filer",
     "Crop image previews" : "Beskär förhandsgranskningar för bilder",
     "Additional settings" : "Övriga inställningar",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Kopiera till urklipp",
     "Use this address to access your Files via WebDAV" : "Använd denna adress för att komma åt dina filer med WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Om du har aktiverat 2FA måste du skapa och använda ett nytt applösenord genom att klicka här.",
     "Clipboard is not available" : "Urklipp är inte tillgängligt",
     "WebDAV URL copied to clipboard" : "WebDAV URL kopierad till urklipp",
     "Unable to change the favourite state of the file" : "Kan inte ändra filens favoritstatus",
@@ -201,20 +226,18 @@ OC.L10N.register(
     "Creating file" : "Skapar fil",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kunde inte skapa fil från mall",
+    "Delete permanently" : "Ta bort permanent",
     "Set up templates folder" : "Skapa en mapp för mallar",
     "Templates" : "Mallar",
     "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
     "Toggle %1$s sublist" : "Växla %1$s sublista",
     "Toggle grid view" : "Växla rutnätsvy",
-    "No files in here" : "Inga filer kunde hittas",
     "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
     "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
-    "Select all" : "Välj allt",
     "Upload too large" : "För stor uppladdning",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
     "No favorites yet" : "Inga favoriter ännu",
     "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
-    "Deleted files" : "Borttagna filer",
     "Shares" : "Delningar",
     "Shared with others" : "Delas med andra",
     "Shared with you" : "Delas med mig",
@@ -229,10 +252,12 @@ OC.L10N.register(
     "New" : "Ny",
     "Copied!" : "Kopierad!",
     "Unlimited" : "Obegränsad",
+    "Search users" : "Sök användare",
     "Cannot transfer ownership of a file or folder you don't own" : "Det går inte att överföra ägarskap av en fil eller mapp som du inte äger",
     "%s used" : "%s använt",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "%1$s av %2$s använt",
-    "Settings" : "Inställningar"
+    "Settings" : "Inställningar",
+    "Deleted files" : "Borttagna filer"
 },
 "nplurals=2; plural=(n != 1);");
