@@ -166,6 +166,7 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "การโอนย้ายความเป็นเจ้าของของ {path} จาก {user} สำเร็จแล้ว",
     "in %s" : "ใน %s",
     "File Management" : "การจัดการไฟล์",
+    "Select all" : "เลือกทั้งหมด",
     "Storage informations" : "ข้อมูลพื้นที่จัดเก็บ",
     "{usedQuotaByte} used" : "ใช้ไป {usedQuotaByte}",
     "{relative}% used" : "ใช้ไป {relative}%",
@@ -174,7 +175,6 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
     "Change" : "เปลี่ยนแปลง",
     "New owner" : "เจ้าของใหม่",
-    "Search users" : "ค้นหาผู้ใช้",
     "Choose a file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
     "Transfer" : "โอนย้าย",
     "Transfer {path} to {userid}" : "โอนย้าย {path} ไปยัง {userid}",
@@ -182,6 +182,8 @@ OC.L10N.register(
     "Unknown error" : "ข้อผิดพลาดที่ไม่รู้จัก",
     "Ownership transfer request sent" : "ส่งคำขอโอนย้ายความเป็นเจ้าของแล้ว",
     "Cannot transfer ownership of a file or folder you do not own" : "ไม่สามารถโอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์ที่คุณไม่ได้เป็นเจ้าของ",
+    "No files in here" : "ไม่มีไฟล์ที่นี่",
+    "Go back" : "กลับไป",
     "Open the files app settings" : "เปิดการตั้งค่าแอปไฟล์",
     "Files settings" : "การตั้งค่าไฟล์",
     "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
@@ -200,20 +202,18 @@ OC.L10N.register(
     "Creating file" : "กำลังสร้างไฟล์",
     "Blank" : "ว่าง",
     "Unable to create new file from template" : "ไม่สามารถสร้างไฟล์ใหม่จากเทมเพลต",
+    "Delete permanently" : "ลบแบบถาวร",
     "Set up templates folder" : "ตั้งค่าโฟลเดอร์เทมเพลต",
     "Templates" : "เทมเพลต",
     "Unable to initialize the templates directory" : "ไม่สามารถเตรียมไดเรกทอรีเทมเพลต",
     "Toggle %1$s sublist" : "สลับรายการย่อย %1$s",
     "Toggle grid view" : "สลับมุมมองตาราง",
-    "No files in here" : "ไม่มีไฟล์ที่นี่",
     "Upload some content or sync with your devices!" : "ลองอัปโหลดเนื้อหาหรือซิงค์กับอุปกรณ์อื่นของคุณ",
     "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
-    "Select all" : "เลือกทั้งหมด",
     "Upload too large" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินไป",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัปโหลดมีขนาดเกินกว่าขนาดสูงสุดที่อัปโหลดได้สำหรับเซิร์ฟเวอร์นี้",
     "No favorites yet" : "ยังไม่มีรายการโปรด",
     "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณระบุเป็นรายการโปรดจะแสดงที่นี่",
-    "Deleted files" : "ไฟล์ที่ถูกลบ",
     "Shares" : "การแชร์",
     "Shared with others" : "แชร์กับผู้อื่น",
     "Shared with you" : "แชร์กับคุณ",
@@ -228,10 +228,12 @@ OC.L10N.register(
     "New" : "สร้างใหม่",
     "Copied!" : "คัดลอกแล้ว",
     "Unlimited" : "ไม่จำกัด",
+    "Search users" : "ค้นหาผู้ใช้",
     "Cannot transfer ownership of a file or folder you don't own" : "ไม่สามารถโอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์ที่คุณไม่ได้เป็นเจ้าของ",
     "%s used" : "ใช้ไป %s",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "ใช้ไป %1$s จาก %2$s",
-    "Settings" : "การตั้งค่า"
+    "Settings" : "การตั้งค่า",
+    "Deleted files" : "ไฟล์ที่ถูกลบ"
 },
 "nplurals=1; plural=0;");
