@@ -155,17 +155,19 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "‎Việc chuyển quyền sở hữu {path} từ {user} đã hoàn tất.‎",
     "in %s" : "trong %s",
     "File Management" : "‎Quản lý tệp‎ tin",
+    "Select all" : "Chọn tất cả",
     "Transfer ownership of a file or folder" : "‎Chuyển quyền sở hữu tệp hoặc thư mục‎",
     "Choose file or folder to transfer" : "‎Chọn tệp hoặc cặp để chuyển‎",
     "Change" : "Chỉnh sửa",
     "New owner" : "‎Chủ sở hữu mới‎",
-    "Search users" : "‎Tìm kiếm người dùng‎",
     "Choose a file or folder to transfer" : "‎Chọn tệp hoặc thư mục cần chuyển‎",
     "Transfer" : "‎Chuyển‎",
     "Transfer {path} to {userid}" : "‎Chuyển {path} sang {userid}‎",
     "Invalid path selected" : "‎Đường dẫn không hợp lệ được chọn‎",
     "Unknown error" : "Lỗi chưa biết",
     "Ownership transfer request sent" : "‎Yêu cầu chuyển quyền sở hữu đã được gửi‎",
+    "No files in here" : "Không có tệp nào",
+    "Go back" : "Quay lại",
     "Show hidden files" : "Hiển thị các file bị ẩn",
     "Crop image previews" : "‎Xén ảnh ‎bản xem trước",
     "Additional settings" : "Cài đặt bổ sung",
@@ -180,19 +182,17 @@ OC.L10N.register(
     "Creating file" : "‎Tạo tệp‎",
     "Blank" : "‎Trống‎",
     "Unable to create new file from template" : "‎Không thể tạo tệp mới từ mẫu‎",
+    "Delete permanently" : "Xoá vĩnh viễn",
     "Set up templates folder" : "‎Thiết lập thư mục mẫu‎",
     "Templates" : "‎Mẫu‎",
     "Unable to initialize the templates directory" : "‎Không thể khởi tạo thư mục mẫu‎",
     "Toggle grid view" : "‎Chuyển đổi dạng xem lưới‎",
-    "No files in here" : "Không có tệp nào",
     "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
     "No entries found in this folder" : "Chưa có mục nào trong thư mục",
-    "Select all" : "Chọn tất cả",
     "Upload too large" : "Tập tin tải lên quá lớn",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
     "No favorites yet" : "‎Chưa có yêu thích nào‎",
     "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
-    "Deleted files" : "Thùng rác",
     "Shares" : "Chia sẻ",
     "Shared with others" : "Chia sẻ với người khác",
     "Shared with you" : "Đã chia sẻ với bạn",
@@ -207,9 +207,11 @@ OC.L10N.register(
     "New" : "Tạo mới",
     "Copied!" : "Đã sao chép!",
     "Unlimited" : "Không giới hạn",
+    "Search users" : "‎Tìm kiếm người dùng‎",
     "Cannot transfer ownership of a file or folder you don't own" : "‎Không thể chuyển quyền sở hữu tệp hoặc thư mục bạn không sở hữu‎",
     "%s used" : "%s ‎đã sử dụng‎",
     "%1$s of %2$s used" : "%1$s trên %2$s đã sử dụng",
-    "Settings" : "Cài đặt"
+    "Settings" : "Cài đặt",
+    "Deleted files" : "Thùng rác"
 },
 "nplurals=1; plural=0;");
