@@ -98,6 +98,7 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["匹配 \"{filter}\""],
     "View in folder" : "在文件夹中查看",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "已复制直链（仅对有权访问此文件/文件夹的人有效）",
     "Path" : "路径",
     "_%n byte_::_%n bytes_" : ["%n 字节"],
     "Favorited" : "已收藏",
@@ -165,11 +166,26 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "来自{user}的{path}的所有权转移已完成。",
     "in %s" : "在 %s",
     "File Management" : "文件管理",
+    "Reload current directory" : "重新载入当前目录",
+    "Go to the \"{dir}\" directory" : "转到 \"{dir}\" 目录",
+    "Select the row for {displayName}" : "选择 {displayName} 的行",
+    "Open folder {name}" : "打开文件夹 {name}",
+    "Download file {name}" : "下载文件 {name}",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" 操作执行成功",
+    "\"{displayName}\" action failed" : "\"{displayName}\" 操作执行失败",
+    "Select all" : "全部选择",
+    "Unselect all" : "取消全选",
+    "ascending" : "升序",
+    "descending" : "降序",
+    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序列表",
+    "Storage informations" : "存储信息",
+    "{usedQuotaByte} used" : "{usedQuotaByte} 已使用",
+    "{relative}% used" : "{relative}% 已使用",
+    "Could not refresh storage stats" : "无法刷新存储统计数据",
     "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
     "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
     "Change" : "修改",
     "New owner" : "新的拥有者",
-    "Search users" : "搜索用户",
     "Choose a file or folder to transfer" : "选择要转移的文件或文件夹",
     "Transfer" : "转移",
     "Transfer {path} to {userid}" : "将 {path} 转移给 {userid}",
@@ -177,13 +193,25 @@ OC.L10N.register(
     "Unknown error" : "未知错误",
     "Ownership transfer request sent" : "所有权转移请求已发送",
     "Cannot transfer ownership of a file or folder you do not own" : "无法转让您未拥有的文件或文件夹的所有权",
+    "Select file or folder to link to" : "选择需要链接的文件或文件夹",
+    "Loading current folder" : "正在载入当前文件夹",
+    "No files in here" : "这里没有文件",
+    "No files or folders have been deleted yet" : "尚未删除任何文件或文件夹",
+    "Go to the previous folder" : "回到前一个文件夹",
+    "Go back" : "返回",
+    "Open the files app settings" : "打开文件设置",
     "Files settings" : "文件设置",
+    "File cannot be accessed" : "文件无法访问",
+    "You might not have have permissions to view it, ask the sender to share it" : "您可能没有权限浏览它，请要求发送者分享它",
     "Show hidden files" : "显示隐藏文件",
     "Crop image previews" : "裁剪图片预览",
     "Additional settings" : "其他设置",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "复制到剪贴板",
     "Use this address to access your Files via WebDAV" : "使用此地址通过 WebDAV 访问您的文件",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "如果您启用了两步验证，您必须点击此处来创建和使用一个新的应用程序密码。",
+    "Clipboard is not available" : "剪贴板不可用",
+    "WebDAV URL copied to clipboard" : "WebDAV 链接已复制到剪贴板",
     "Unable to change the favourite state of the file" : "无法修改文件的收藏状态",
     "Error while loading the file data" : "加载文件数据时出错",
     "Pick a template for {name}" : "给 {name} 挑选一个模板",
@@ -193,20 +221,18 @@ OC.L10N.register(
     "Creating file" : "正在创建文件",
     "Blank" : "空白",
     "Unable to create new file from template" : "无法从模板创建新文件",
+    "Delete permanently" : "彻底删除",
     "Set up templates folder" : "设置模板文件夹",
     "Templates" : "模板",
     "Unable to initialize the templates directory" : "无法初始化模板目录",
     "Toggle %1$s sublist" : "切换 %1$s 子列表",
     "Toggle grid view" : "切换网格视图",
-    "No files in here" : "这里没有文件",
     "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
     "No entries found in this folder" : "在此文件夹中找不到项目",
-    "Select all" : "全部选择",
     "Upload too large" : "上传文件过大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "正在上传的文件超过了此服务器允许上传的最大容量限制",
     "No favorites yet" : "暂无收藏",
     "Files and folders you mark as favorite will show up here" : "收藏的文件和文件夹会在这里显示",
-    "Deleted files" : "已删除的文件",
     "Shares" : "共享",
     "Shared with others" : "已与他人共享",
     "Shared with you" : "与您共享的",
@@ -221,10 +247,12 @@ OC.L10N.register(
     "New" : "新建",
     "Copied!" : "已复制",
     "Unlimited" : "无限制",
+    "Search users" : "搜索用户",
     "Cannot transfer ownership of a file or folder you don't own" : "无法转让您未拥有的文件或文件夹的所有权",
     "%s used" : "已使用 %s",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "已使用 %2$s 中的 %1$s",
-    "Settings" : "设置"
+    "Settings" : "设置",
+    "Deleted files" : "已删除的文件"
 },
 "nplurals=1; plural=0;");
