@@ -166,6 +166,22 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "來自 {user} 的 \"{path}\" 所有權轉移已經完成",
     "in %s" : "在 %s",
     "File Management" : "檔案管理",
+    "Reload current directory" : "重新加載目前目錄",
+    "Go to the \"{dir}\" directory" : "轉到 \"{dir}\" 目錄",
+    "Select the row for {displayName}" : "選擇 {displayName} 的行",
+    "Open folder {name}" : "打開資料夾 {name}",
+    "Download file {name}" : "下載檔案 {name}",
+    "\"{displayName}\" action executed successfully" : "成功執行 “{displayName}” 操作",
+    "\"{displayName}\" action failed" : "“{displayName}” 操作失敗",
+    "Total rows summary" : "總列摘要",
+    "Select all" : "全選",
+    "Unselect all" : "取消全選",
+    "\"{displayName}\" failed on some elements " : "“{displayName}” 在某些元素上失敗",
+    "\"{displayName}\" batch action executed successfully" : "成功執行 “{displayName}” 批處理操作",
+    "ascending" : "升",
+    "descending" : "降",
+    "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序清單",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "出於性能考慮，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "Storage informations" : "儲存資訊",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte} ",
     "{relative}% used" : "已使用 {relative}%",
@@ -174,7 +190,7 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Change" : "更改",
     "New owner" : "新的擁有者",
-    "Search users" : "搜尋用戶",
+    "Search for an account" : "搜尋賬號",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
     "Transfer {path} to {userid}" : "轉移 \"{path}\" 給 {userid}",
@@ -183,6 +199,11 @@ OC.L10N.register(
     "Ownership transfer request sent" : "已送出擁有權轉移的請求",
     "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或是資料夾所有權",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
+    "Loading current folder" : "目前資料夾加載中",
+    "No files in here" : "沒有任何檔案",
+    "No files or folders have been deleted yet" : "尚未刪除任何檔案或資料夾",
+    "Go to the previous folder" : "前往上一個資料夾",
+    "Go back" : "返回",
     "Open the files app settings" : "開啟 Files 應用程式設定",
     "Files settings" : "檔案設定",
     "File cannot be accessed" : "檔案無法存取",
@@ -205,20 +226,18 @@ OC.L10N.register(
     "Creating file" : "創建檔案中",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從模板創建新檔案",
+    "Delete permanently" : "永久刪除",
     "Set up templates folder" : "設定範本料夾",
     "Templates" : "模板",
     "Unable to initialize the templates directory" : "無法初始化模板目錄",
     "Toggle %1$s sublist" : "切換 %1$s 子列表",
     "Toggle grid view" : "切換網格檢視",
-    "No files in here" : "沒有任何檔案",
     "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
-    "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
     "No favorites yet" : "尚無最愛",
     "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
-    "Deleted files" : "回收桶",
     "Shares" : "分享",
     "Shared with others" : "與其他人分享",
     "Shared with you" : "與您分享",
@@ -233,10 +252,12 @@ OC.L10N.register(
     "New" : "新增",
     "Copied!" : "已複製",
     "Unlimited" : "無限制",
+    "Search users" : "搜尋用戶",
     "Cannot transfer ownership of a file or folder you don't own" : "無法轉移您未擁有的檔案或是資料夾所有權。",
     "%s used" : "使用了 %s 的存儲空間",
     "%s%%" : "%s%%",
     "%1$s of %2$s used" : "在 %2$s 中使用了 %1$s",
-    "Settings" : "設定"
+    "Settings" : "設定",
+    "Deleted files" : "回收桶"
 },
 "nplurals=1; plural=0;");
