@@ -1,6 +1,9 @@
 OC.L10N.register(
     "logreader",
     {
+    "Info" : "Info",
+    "Warning" : "Aviso",
+    "Error" : "Error",
     "Copy" : "Copiar",
     "Time" : "Tempore"
 },
