@@ -1,6 +1,10 @@
 OC.L10N.register(
     "logreader",
     {
+    "Logging" : "Logovanie",
+    "Log Reader" : "Čítačka logov",
+    "A log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
+    "Log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
     "Error parsing log" : "Chyba pri analýze logov",
     "Caused by " : "Spôsobené",
     "Debug" : "Ladenie",
@@ -23,11 +27,6 @@ OC.L10N.register(
     "Log levels" : "Úroveň logov",
     "Log content" : "Obsah logov",
     "Live update" : "Živá aktualizácia",
-    "Download logs" : "Prevziať logy",
-    "Logging" : "Logovanie",
-    "Log Reader" : "Čítačka logov",
-    "A log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
-    "Log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
-    "Load log file …" : "Načítanie log súboru ..."
+    "Download logs" : "Prevziať logy"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
