@@ -1,5 +1,7 @@
-<?php script($_['appId'], ['../build/main']); ?>
-<?php style($_['appId'], ['../build/main']); ?>
-<?php style($_['appId'], ['app']); ?>
+<?php
+
+\OCP\Util::addScript('logreader', 'logreader-main');
+\OCP\Util::addStyle('logreader', '../js/logreader-main');
+?>
 <div id="searchresults" style="display: none"></div>
 <div id="logreader-root" data-inline-settings="<?php echo $_['inline-settings'];?>"/>
