@@ -5,18 +5,18 @@ OC.L10N.register(
     "Hello %s," : "Dag %s,",
     "Admin notifications" : "Admin kennisgewings",
     "Notifications" : "Kennisgewings",
-    "No notifications" : "Geen kennisgewings",
-    "Failed to dismiss all notifications" : "Kon nie alle kennisgewings afwys nie ",
     "Failed to perform action" : "Kon nie aksie voltooi nie",
     "Dismiss" : "Wys Af",
     "seconds ago" : "sekondes gelede",
     "Failed to dismiss notification" : "Kon nie kennisgewing afwys nie",
     "in {path}" : "in {path}",
-    "You need to set up your email address before you can receive notification emails." : "U moet u e-posadres opstel alvorens u kennisgewings per e-pos kan ontvang.",
+    "No notifications" : "Geen kennisgewings",
+    "Failed to dismiss all notifications" : "Kon nie alle kennisgewings afwys nie ",
     "Never" : "Nooit",
     "1 hour" : "1 uur",
     "1 day" : "1 dag",
     "1 week" : "1 week",
-    "Your settings have been updated." : "U instellings is bygewerk."
+    "Your settings have been updated." : "U instellings is bygewerk.",
+    "You need to set up your email address before you can receive notification emails." : "U moet u e-posadres opstel alvorens u kennisgewings per e-pos kan ontvang."
 },
 "nplurals=2; plural=(n != 1);");
