@@ -13,8 +13,9 @@ OC.L10N.register(
     "Favorites" : "Favoriten",
     "On this day" : "An diesem Tag",
     "Shared with you" : "Mit Ihnen geteilt",
-    "Tags" : "Schlagwörter",
-    "Locations" : "Orte",
+    "Tags" : "Schlagworte",
+    "Places" : "Orte",
+    "Map" : "Karte",
     "Photos settings" : "Fotos-Einstellungen",
     "Mark selection as favorite" : "Auswahl als Favoriten markieren",
     "Add selection to favorites" : "Auswahl zu Favoriten hinzufügen",
@@ -100,6 +101,10 @@ OC.L10N.register(
     "This folder does not exist" : "Dieser Ordner existiert nicht",
     "Loading folders …" : "Ordner werden geladen...",
     "No photos in here" : "Keine Fotos vorhanden",
+    "This place does not have any photos or videos yet!" : "Dieser Ort enthält noch keine Fotos oder Videos!",
+    "Add photos to this place" : "Fotos zu diesem Ort hinzufügen",
+    "Cover photo for place {placeName}" : "Titelbild für Ort {placeName}",
+    "There is no place yet!" : "Es gibt noch keinen Ort",
     "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
     "Shared albums" : "Geteilte Alben",
     "Cover photo for shared album {albumName}." : "Titelbild für das geteilte Album {albumName}.",
@@ -114,6 +119,8 @@ OC.L10N.register(
     "Add to album" : "Zum Album hinzufügen",
     "Delete selection" : "Auswahl löschen",
     "No photos or videos in here" : "Hier gibt es keine Fotos oder Videos",
+    "Failed to fetch collection." : "Sammlung konnte nicht abgerufen werden.",
+    "Failed to fetch collections list." : "Sammlungsliste konnte nicht geladen werden.",
     "Failed to fetch faces list." : "Gesichter-Liste konnte nicht geladen werden.",
     "All your media" : "Alle Ihre Medien",
     "Album {title}" : "Album {title}",
@@ -134,6 +141,7 @@ OC.L10N.register(
     "Your photos" : "Ihre Fotos",
     "Your videos" : "Ihre Videos",
     "Your folders" : "Ihre Ordner",
+    "Locations" : "Orte",
     "Settings" : "Einstellungen"
 },
 "nplurals=2; plural=(n != 1);");
