@@ -14,7 +14,8 @@ OC.L10N.register(
     "On this day" : "On this day",
     "Shared with you" : "Shared with you",
     "Tags" : "Tags",
-    "Locations" : "Locations",
+    "Places" : "Places",
+    "Map" : "Map",
     "Photos settings" : "Photos settings",
     "Mark selection as favorite" : "Mark selection as favorite",
     "Add selection to favorites" : "Add selection to favourites",
@@ -100,6 +101,10 @@ OC.L10N.register(
     "This folder does not exist" : "This folder does not exist",
     "Loading folders …" : "Loading folders …",
     "No photos in here" : "No photos in here",
+    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
+    "Add photos to this place" : "Add photos to this place",
+    "Cover photo for place {placeName}" : "Cover photo for place {placeName}",
+    "There is no place yet!" : "There is no place yet!",
     "Failed to fetch albums list." : "Failed to fetch albums list.",
     "Shared albums" : "Shared albums",
     "Cover photo for shared album {albumName}." : "Cover photo for shared album {albumName}.",
@@ -114,6 +119,8 @@ OC.L10N.register(
     "Add to album" : "Add to album",
     "Delete selection" : "Delete selection",
     "No photos or videos in here" : "No photos or videos in here",
+    "Failed to fetch collection." : "Failed to fetch collection.",
+    "Failed to fetch collections list." : "Failed to fetch collections list.",
     "Failed to fetch faces list." : "Failed to fetch faces list.",
     "All your media" : "All your media",
     "Album {title}" : "Album {title}",
@@ -134,6 +141,7 @@ OC.L10N.register(
     "Your photos" : "Your photos",
     "Your videos" : "Your videos",
     "Your folders" : "Your folders",
+    "Locations" : "Locations",
     "Settings" : "Settings"
 },
 "nplurals=2; plural=(n != 1);");
