@@ -14,7 +14,8 @@ OC.L10N.register(
     "On this day" : "En este día",
     "Shared with you" : "Compartido contigo",
     "Tags" : "Etiquetas",
-    "Locations" : "Ubicaciones",
+    "Places" : "Ubicaciones",
+    "Map" : "Mapas",
     "Photos settings" : "Configuración de fotos",
     "Mark selection as favorite" : "Marcar selección como favorita",
     "Add selection to favorites" : "Añadir selección a favoritos",
@@ -100,6 +101,10 @@ OC.L10N.register(
     "This folder does not exist" : "Esta carpeta no existe",
     "Loading folders …" : "Cargando carpetas ...",
     "No photos in here" : "No hay fotos aquí",
+    "This place does not have any photos or videos yet!" : "¡Esta ubicación no tiene fotos ni videos todavía!",
+    "Add photos to this place" : "Añadir fotos a esta ubicación",
+    "Cover photo for place {placeName}" : "Foto de cubierta para la ubicación {placeName}",
+    "There is no place yet!" : "¡Todavía no hay ubicación!",
     "Failed to fetch albums list." : "Fallo al recuperar la lista de álbumes.",
     "Shared albums" : "Álbumes compartidos",
     "Cover photo for shared album {albumName}." : "Foto de cubierta para el álbum compartido {albumName}.",
@@ -114,6 +119,8 @@ OC.L10N.register(
     "Add to album" : "Añadir al álbum",
     "Delete selection" : "Borrar la selección",
     "No photos or videos in here" : "No se encuentran fotos ni videos aquí",
+    "Failed to fetch collection." : "Fallo al recuperar la colección.",
+    "Failed to fetch collections list." : "Fallo al recuperar la lista de colecciones.",
     "Failed to fetch faces list." : "Fallo al recuperar la lista de caras.",
     "All your media" : "Todos sus medios",
     "Album {title}" : "Álbum {title}",
@@ -134,6 +141,7 @@ OC.L10N.register(
     "Your photos" : "Tus fotos",
     "Your videos" : "Tus vídeos",
     "Your folders" : "Tus carpetas",
+    "Locations" : "Ubicaciones",
     "Settings" : "Ajustes"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
