@@ -14,7 +14,8 @@ OC.L10N.register(
     "On this day" : "A mai napon",
     "Shared with you" : "Megosztva Önnel",
     "Tags" : "Címkék",
-    "Locations" : "Helyek",
+    "Places" : "Helyek",
+    "Map" : "Térkép",
     "Photos settings" : "Fényképek beállításai",
     "Mark selection as favorite" : "Kiválasztás megjelölése kedvencként",
     "Add selection to favorites" : "Kiválasztás hozzáadása a kedvencekhez",
@@ -100,6 +101,10 @@ OC.L10N.register(
     "This folder does not exist" : "Ez a mappa nem létezik",
     "Loading folders …" : "Mappák betöltése…",
     "No photos in here" : "Itt nincsenek fényképek",
+    "This place does not have any photos or videos yet!" : "Ehhez a helyhez még nincs fénykép vagy videó.",
+    "Add photos to this place" : "Fényképek hozzáadása ehhez a helyhez",
+    "Cover photo for place {placeName}" : "A következő hely borítóképe: {placeName}",
+    "There is no place yet!" : "Még nincsenek helyek.",
     "Failed to fetch albums list." : "Az albumok lekérése sikertelen.",
     "Shared albums" : "Megosztott albumok",
     "Cover photo for shared album {albumName}." : "Borítókép a(z) „{albumName}” megosztott albumhoz.",
@@ -114,6 +119,8 @@ OC.L10N.register(
     "Add to album" : "Hozzáadás az albumhoz",
     "Delete selection" : "Kiválasztás törlése",
     "No photos or videos in here" : "Itt nincs fénykép vagy videó",
+    "Failed to fetch collection." : "A gyűjtemény lekérése sikertelen.",
+    "Failed to fetch collections list." : "A gyűjtemények lekérése sikertelen.",
     "Failed to fetch faces list." : "Az arcok lekérése sikertelen.",
     "All your media" : "Összes saját média",
     "Album {title}" : "Album: {title}",
@@ -134,6 +141,7 @@ OC.L10N.register(
     "Your photos" : "Saját fényképek",
     "Your videos" : "Saját videók",
     "Your folders" : "Saját mappák",
+    "Locations" : "Helyek",
     "Settings" : "Beállítások"
 },
 "nplurals=2; plural=(n != 1);");
