@@ -101,6 +101,10 @@ OC.L10N.register(
     "This folder does not exist" : "Esta pasta não existe",
     "Loading folders …" : "Carregando pastas…",
     "No photos in here" : "Não há fotos aqui",
+    "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
+    "Add photos to this place" : "Adicionar fotos a este espaço",
+    "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
+    "There is no place yet!" : "Ainda não há espaço!",
     "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
     "Shared albums" : "Álbuns compartilhados",
     "Cover photo for shared album {albumName}." : "Foto da capa do álbum compartilhado {albumName}.",
@@ -115,6 +119,8 @@ OC.L10N.register(
     "Add to album" : "Adicionar a álbum",
     "Delete selection" : "Excluir seleção",
     "No photos or videos in here" : "Não há fotos ou vídeos aqui",
+    "Failed to fetch collection." : "Failed to fetch collection.",
+    "Failed to fetch collections list." : "Failed to fetch collections list.",
     "Failed to fetch faces list." : "Falha ao buscar lista de rostos.",
     "All your media" : "Todas as suas mídias",
     "Album {title}" : "Álbum {título}",
