@@ -14,7 +14,8 @@ OC.L10N.register(
     "On this day" : "В этот день",
     "Shared with you" : "Предоставленные вам",
     "Tags" : "Метки",
-    "Locations" : "Места",
+    "Places" : "Места",
+    "Map" : "Карта",
     "Photos settings" : "Настройки фотографий",
     "Mark selection as favorite" : "Добавить выделенное в избранное",
     "Add selection to favorites" : "Добавить выделенное в избранное",
@@ -92,13 +93,18 @@ OC.L10N.register(
     "Remove from favorites" : "Убрать из избранного",
     "Remove person" : "Удалить",
     "Name of this person" : "Имя",
-    "Merge person" : "Объеденить метки",
+    "Merge person" : "Объединить метки",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица"],
     "_Remove photo from person_::_Remove photos from person_" : ["Снять отметку лица с фотографии","Снять отметку лица с фотографий","Снять отметку лица с фотографий","Снять отметку лица с фотографий"],
     "This might take some time depending on the size of your photo library." : "Выполнение этого действия может занять некоторое время, зависящее от размера библиотеки фотографий.",
     "Recognized people will show up here" : "Тут будут показаны лица людей, которые удалось распознать",
     "This folder does not exist" : "Эта папка не существует",
     "Loading folders …" : "Выполняется загрузка папок…",
     "No photos in here" : "Здесь нет ни одной фотографии",
+    "This place does not have any photos or videos yet!" : "С этим местом пока не связано ни одной фотографии или видео.",
+    "Add photos to this place" : "Связать фотографии с этим местом",
+    "Cover photo for place {placeName}" : "Заглавное изображение для места «{placeName}»",
+    "There is no place yet!" : "Пока нет ни одного места.",
     "Failed to fetch albums list." : "Не удалось получить список альбомов.",
     "Shared albums" : "Полученные альбомы",
     "Cover photo for shared album {albumName}." : "Заглавное изображение опубликованного альбома «{albumName}».",
@@ -113,9 +119,17 @@ OC.L10N.register(
     "Add to album" : "Добавить в альбом",
     "Delete selection" : "Удалить выбранное",
     "No photos or videos in here" : "Нет ни одной фотографии или видео",
-    "Failed to fetch faces list." : "Не удалось получить списко лиц.",
+    "Failed to fetch collection." : "Не удалось получить коллекцию.",
+    "Failed to fetch collections list." : "Не удалось получить список коллекций.",
+    "Failed to fetch faces list." : "Не удалось получить список лиц.",
     "All your media" : "Все фотографии и видео",
+    "Album {title}" : "Альбом «{title}»",
+    "Shared Albums" : "Опубликованные альбомы",
+    "Shared album {title}" : "Опубликованный альбом «{title}»",
+    "Public album {title}" : "Общедоступный альбом «{title}»",
     "Tagged photos" : "Фотографии с метками",
+    "Tagged photo {title}" : "Фотография с метками «{title}»",
+    "{title}'s face" : "Лицо {title}",
     "Failed to create {albumName}." : "Не удалось создать альбом «{albumName}».",
     "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не удалось переименовать альбом «{currentAlbumName}» в «{newAlbumName}».",
     "Failed to rename {oldName} to {faceName}." : "Не удалось переименовать метку лица «{oldName}» в «{faceName}».",
@@ -127,6 +141,7 @@ OC.L10N.register(
     "Your photos" : "Мои фотографии",
     "Your videos" : "Ваши видео",
     "Your folders" : "Ваши каталоги",
+    "Locations" : "Места",
     "Settings" : "Параметры"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
