@@ -4,14 +4,14 @@ OC.L10N.register(
     "Privacy" : "Datenschutz",
     "-" : "-",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Die Datenschutzübersicht zeigt Ihnen, wo Ihre Daten gespeichert werden und wer darauf Zugriff hat. Entweder weil Sie die Daten freigegeben haben oder es sich um Administratoren handelt.",
-    "Remove external {propertyName} admin" : "Externe {propertyName}-Administration entfernt",
+    "Remove external {propertyName} admin" : "Externe {propertyName}-Administration entfernen",
     "Add external admin" : "Einen externen Administrator hinzufügen",
     "Name of external admin" : "Namen des externen Administrators",
     "Adapt encryption" : "Verschlüsselung anpassen",
     "This server is using full-disk-encryption." : "Dieser Server verwendet Festplattenverschlüsselung.",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Ihr Heimspeicher wird mit {linkopen}serverseitiger Verschlüsselung ↗{linkclose} mit einem Hauptschlüssel verschlüsselt. Dies bedeutet, dass Administratoren auf Ihre Dateien zugreifen, aber nicht deren Inhalt lesen können.",
+    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Ihr Heimspeicher ist mit {linkopen}serverseitiger Verschlüsselung ↗{linkclose} mit einem Hauptschlüssel verschlüsselt. Dies bedeutet, dass die Administration auf Ihre Dateien zugreifen, aber nicht deren Inhalt lesen kann.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Ihre Dateien auf externen Speichern können mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose}  und einem Hauptschlüssel verschlüsselt werden.",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Ihr Heimspeicher wird mit {linkopen}serverseitiger Verschlüsselung ↗{linkclose} mit einem individuellen Benutzerschlüssel verschlüsselt. Dies bedeutet, dass Administratoren auf Ihre Dateien zugreifen, aber nicht deren Inhalt lesen können.",
+    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key. It means that administrators can access your files, but not read their content." : "Ihr Heimspeicher ist mit {linkopen}serverseitiger Verschlüsselung ↗{linkclose} mit einem individuellen Benutzerschlüssel verschlüsselt. Dies bedeutet, dass die Administration auf Ihre Dateien zugreifen, aber nicht deren Inhalt lesen kann.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Ihre Dateien auf externen Speichern können mittels der {linkopen}serverseitigen Verschlüsselung ↗{linkclose}  und einem individuellen Benutzerschlüssel verschlüsselt werden.",
     "Additionally, this server is protected with full-disk-encryption." : "Zusätzlich ist dieser Server mit einer Festplattenverschlüsselung geschützt.",
     "This server is protected with full-disk-encryption." : "Dieser Server ist mittels Festplattenverschlüsselung geschützt.",
