@@ -7,18 +7,6 @@ OC.L10N.register(
     "RAM info not available" : "Informationen zum RAM nicht verfügbar",
     "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Gesamt: {swapTotalBytes}/Aktuelle Nutzung: {swapUsageBytes}",
     "SWAP info not available" : "Informationen zum SWAP nicht verfügbar",
-    "Users" : "Benutzer",
-    "Groups" : "Gruppen",
-    "Links" : "Verknüpfungen",
-    "Emails" : "E-Mails",
-    "Federated sent" : "Federated gesendet",
-    "Federated received" : "Federated empfangen",
-    "Talk conversations" : "Talk Unterhaltungen",
-    "24 hours" : "24 Stunden",
-    "1 hour" : "1 Stunde",
-    "5 mins" : "5 Minuten",
-    "Copy" : "Kopieren",
-    "Copied!" : "Kopiert!",
     "Not supported!" : "Nicht unterstützt!",
     "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
     "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
@@ -51,12 +39,23 @@ OC.L10N.register(
     "Gateway:" : "Gateway:",
     "Status:" : "Status:",
     "Speed:" : "Geschwindigkeit:",
+    "Duplex:" : "Duplex:",
     "MAC:" : "MAC:",
     "IPv4:" : "IPv4:",
     "IPv6:" : "IPv6:",
     "Active users" : "Aktive Benutzer",
     "Total users:" : "Benutzer gesamt:",
+    "24 hours:" : "24 Stunden:",
+    "1 hour:" : "1 Stunde:",
+    "5 mins:" : "5 Minuten:",
     "Shares" : "Freigaben",
+    "Users:" : "Benutzer:",
+    "Groups:" : "Gruppen:",
+    "Links:" : "Links:",
+    "Emails:" : "E-Mails:",
+    "Federated sent:" : "Federated gesendet:",
+    "Federated received:" : "Federated empfangen:",
+    "Talk conversations:" : "Talk-Unterhaltungen:",
     "PHP" : "PHP",
     "Version:" : "Version:",
     "Memory limit:" : "Speicherlimit:",
@@ -68,9 +67,21 @@ OC.L10N.register(
     "Type:" : "Art:",
     "External monitoring tool" : "Externes Überwachungsprogramm",
     "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
+    "Copy" : "Kopieren",
     "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn du \"?format=json\" am Ende der URL anhängst, erhältst du das Ergebnis in JSON.",
     "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generiere bitte ein Token und lege es mit dem folgenden Befehl fest:",
     "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergib dann das Token mit dem \"NC-Token\"-Header bei der Abfrage der obigen URL.",
+    "Users" : "Benutzer",
+    "Groups" : "Gruppen",
+    "Links" : "Verknüpfungen",
+    "Emails" : "E-Mails",
+    "Federated sent" : "Federated gesendet",
+    "Federated received" : "Federated empfangen",
+    "Talk conversations" : "Talk Unterhaltungen",
+    "24 hours" : "24 Stunden",
+    "1 hour" : "1 Stunde",
+    "5 mins" : "5 Minuten",
+    "Copied!" : "Kopiert!",
     "Operating System" : "Betriebssystem",
     "CPU" : "Prozessor",
     "Server time" : "Server-Zeit",
