@@ -39,13 +39,23 @@ OC.L10N.register(
     "Gateway:" : "Átjáró:",
     "Status:" : "Állapot:",
     "Speed:" : "Sebesség:",
+    "Duplex:" : "Duplex:",
     "MAC:" : "MAC:",
     "IPv4:" : "IPv4:",
     "IPv6:" : "IPv6:",
     "Active users" : "Aktív felhasználók",
     "Total users:" : "Összes felhasználó:",
+    "24 hours:" : "24 óra:",
+    "1 hour:" : "1 óra:",
+    "5 mins:" : "5 perc:",
     "Shares" : "Megosztások",
     "Users:" : "Felhasználók:",
+    "Groups:" : "Csoportok:",
+    "Links:" : "Hivatkozások:",
+    "Emails:" : "E-mailek:",
+    "Federated sent:" : "Föderáltak elküldve:",
+    "Federated received:" : "Föderáltak fogadva:",
+    "Talk conversations:" : "Beszélgetések:",
     "PHP" : "PHP",
     "Version:" : "Verzió:",
     "Memory limit:" : "Memóriakorlát:",
