@@ -1,16 +1,18 @@
 OC.L10N.register(
     "serverinfo",
     {
-    "Users" : "Iseqdacen",
-    "1 hour" : "1 n usrag",
-    "Copy" : "Nɣel",
-    "Copied!" : "Yenɣel!",
     "Not supported!" : "Ur yettusefrak ara!",
     "Press ⌘-C to copy." : "Senned ɣef ⌘-C akken ad tneɣleḍ.",
     "Press Ctrl-C to copy." : "Senned ɣef Ctrl-C akken ad tneɣleḍ.",
     "Temperature" : "Lḥamu",
+    "Copy" : "Nɣel",
+    "Users" : "Iseqdacen",
+    "Groups" : "Igrawen",
+    "1 hour" : "1 n usrag",
+    "Copied!" : "Yenɣel!",
     "Size" : "Teɣzi",
     "Files" : "Ifuyla",
+    "Status" : "État",
     "Type" : "Anaw"
 },
 "nplurals=2; plural=(n != 1);");
