@@ -268,11 +268,12 @@ OC.L10N.register(
     "Current password" : "Aktuelles Passwort",
     "New password" : "Neues Passwort",
     "Change password" : "Passwort ändern",
+    "Your profile information" : "Ihre Profilinformation",
     "Your profile picture" : "Ihr Profilbild",
     "Upload profile picture" : "Profilbild hochladen",
-    "Choose profile picture from files" : "Profilbild aus Dateien auswählen",
+    "Choose profile picture from Files" : "Profilbild aus Dateien wählen",
     "Remove profile picture" : "Profilbild entfernen",
-    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
+    "The file must be a PNG or JPG" : "Die Datei muss im PNG- oder JPG-Format sein",
     "Picture provided by original account" : "Bild von Original-Konto zur Verfügung gestellt",
     "Cancel" : "Abbrechen",
     "Set as profile picture" : "Als Profilbild festlegen",
@@ -434,6 +435,7 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Es ist ein Fehler bei der Anfrage aufgetreten. Es kann nicht fortgefahren werden.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, muss aber aktualisiert werden. Sie werden in 5 Sekunden zur Aktualisierungsseite weitergeleitet.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da sie den Server instabil macht. ",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zu viele Anfragen aus Ihrem Netzwerk. Versuchen Sie es später erneut oder wenden Sie sich an Ihre Administration, wenn dies ein Fehler sein sollte.",
     "Documentation" : "Dokumentation",
     "Forum" : "Forum",
     "Login" : "Anmelden",
@@ -548,6 +550,7 @@ OC.L10N.register(
     "Upload new" : "Neues hochladen",
     "Select from Files" : "Aus Dateien wählen",
     "Remove image" : "Bild entfernen",
+    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Bitte beachten Sie, dass es bis zu 24 Stunden dauern kann, bis der Avatar überall aktualisiert wird.",
     "Choose as profile picture" : "Als Profilbild auswählen",
     "You are using <strong>%s</strong>" : "Sie benutzen <strong>%s</strong>",
@@ -559,6 +562,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Es kann bis zu 24 Stunden dauern, bis das Konto als überprüt angezeigt wird.",
     "Link https://…" : "Link https://…",
     "Change privacy level of Twitter profile" : "Datenschutzstufe des Twitter-Profils ändern",
-    "Twitter handle @…" : "Twitter-Handle @…"
+    "Twitter handle @…" : "Twitter-Handle @…",
+    "Choose profile picture from files" : "Profilbild aus Dateien auswählen"
 },
 "nplurals=2; plural=(n != 1);");
