@@ -268,11 +268,12 @@ OC.L10N.register(
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
     "Change password" : "Cambiar contraseña",
+    "Your profile information" : "Información de su perfil",
     "Your profile picture" : "Su imagen de perfil",
     "Upload profile picture" : "Subir imagen del perfil",
-    "Choose profile picture from files" : "Seleccionar imagen del perfil desde los archivos",
+    "Choose profile picture from Files" : "Seleccionar imagen del perfil desde los archivos",
     "Remove profile picture" : "Eliminar imagen del perfil",
-    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
+    "The file must be a PNG or JPG" : "El archivo debe ser un PNG o JPG",
     "Picture provided by original account" : "Imagen provista por la cuenta original",
     "Cancel" : "Cancelar",
     "Set as profile picture" : "Establecer como imagen del perfil",
@@ -434,6 +435,7 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Ha ocurrido un error durante la solicitud. No se puede continuar.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La app ha sido activada pero tiene que actualizarse. Serás redirigido a la página de actualización en 5 segundos.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: Esta app no se puede activar porque hace inestable al servidor",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hubo demasiadas peticiones desde su red. Vuelva a intentarlo más tarde o póngase en contacto con su administrador si se trata de un error.",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
     "Login" : "Iniciar sesión",
@@ -548,6 +550,7 @@ OC.L10N.register(
     "Upload new" : "Subir nueva",
     "Select from Files" : "Seleccionar desde Archivos",
     "Remove image" : "Borrar imagen",
+    "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Ten en cuenta que el avatar puede tardar hasta 24 horas en actualizarse en todas partes.",
     "Choose as profile picture" : "Seleccionar como imagen de perfil",
     "You are using <strong>%s</strong>" : "Estás usando <strong>%s</strong>",
@@ -559,6 +562,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Puede tardar hasta 24 horas que la cuenta aparezca como verificada.",
     "Link https://…" : "Enlace https://...",
     "Change privacy level of Twitter profile" : "Cambiar nivel de privacidad del perfí en Twitter",
-    "Twitter handle @…" : "Usuario de Twitter @..."
+    "Twitter handle @…" : "Usuario de Twitter @...",
+    "Choose profile picture from files" : "Seleccionar imagen del perfil desde los archivos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
