@@ -12,7 +12,6 @@ OC.L10N.register(
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Select a profile picture" : "Selecciona una imagen de perfil",
     "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
@@ -24,6 +23,7 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
+    "Apps" : "Aplicaciones",
     "Wrong password" : "Contraseña incorrecta",
     "Saved" : "Guardado",
     "No user supplied" : "No se proporcionó usuario alguno",
@@ -31,12 +31,15 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
     "Federated Cloud Sharing" : "Compartir en la Nube Federada",
+    "Administrator documentation" : "Documentación del adminsitrador",
+    "User documentation" : "Documentación del usuario",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
     "Email setting test" : "Prueba de ajustes de correo",
     "Well done, %s!" : "¡Bien hecho, %s!",
     "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
+    "Users" : "Usuarios",
     "Invalid user" : "Usuario inválido",
     "Invalid mail address" : "Dirección de correo inválida",
     "Settings saved" : "Se han guardado las configuraciones ",
@@ -63,13 +66,13 @@ OC.L10N.register(
     "Set your password" : "Establece tu contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
-    "Apps" : "Aplicaciones",
     "Settings" : "Configuraciones ",
     "Personal" : "Personal",
     "Administration" : "Administración",
     "Additional settings" : "Configuraciones adicionales",
     "Basic settings" : "Configuraciones  básicas",
     "Sharing" : "Compartiendo",
+    "Calendar" : "Calendario",
     "Personal info" : "Información Personal",
     "Email server" : "Servidor de correo electrónico",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
@@ -93,7 +96,6 @@ OC.L10N.register(
     "View in store" : "Ver en la tienda",
     "Visit website" : "Visita el sitio web",
     "Report a bug" : "Reporta un detalle",
-    "User documentation" : "Documentación del usuario",
     "Admin documentation" : "Documentación del administrador",
     "Developer documentation" : "Documentación del desarrollador",
     "Featured" : "Destacado",
@@ -126,12 +128,30 @@ OC.L10N.register(
     "Copy" : "Copiar",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
     "Enable" : "Habilitar",
+    "Server-side encryption" : "Encripción del lado del servidor",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
+    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
+    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
+    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
+    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
+    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
+    "Current password" : "Contraseña actual",
+    "New password" : "Nueva contraseña",
+    "Change password" : "Cambiar contraseña",
+    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
+    "Cancel" : "Cancelar",
+    "Details" : "Detalles",
     "Your email address" : "Tu dirección de correo electrónico",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Language" : "Idioma",
     "Help translate" : "Ayuda a traducir",
+    "Your phone number" : "Su número telefónico",
+    "Your Twitter handle" : "Tu cuenta de Twitter",
+    "Your website" : "Tu sitio web",
     "Add" : "Agregar",
-    "Cancel" : "Cancelar",
     "{size} used" : "{size} usado",
     "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
@@ -143,10 +163,6 @@ OC.L10N.register(
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
     "Your apps" : "Tus aplicaciones",
-    "Disabled apps" : "Aplicaciones deshabilitadas",
-    "Updates" : "Actualizaciones",
-    "App bundles" : "Paquetes de aplicación",
-    "Details" : "Detalles",
     "Changelog" : "Bitácora de cambios",
     "Add group" : "Agregar grupo",
     "Active users" : "Usuarios activos",
@@ -154,38 +170,35 @@ OC.L10N.register(
     "Show last login" : "Mostrar último inicio de sesión",
     "Show user backend" : "Mostrar backend del usuario",
     "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
-    "Migration started …" : "La migración ha comenzado ...",
     "Not saved" : "No guardado",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
-    "Address" : "Dirección",
-    "Avatar" : "Avatar",
+    "Location" : "Ubicación",
+    "Profile picture" : "Foto de perfil",
     "About" : "Acerca",
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
     "Twitter" : "Twitter",
     "Website" : "Sitio web",
+    "Disabled apps" : "Aplicaciones deshabilitadas",
+    "Updates" : "Actualizaciones",
+    "App bundles" : "Paquetes de aplicación",
     "Hide" : "Ocultar",
     "Never" : "Nunca",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
-    "Administrator documentation" : "Documentación del adminsitrador",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
     "Login" : "Iniciar sesión",
-    "Plain" : "Plano",
-    "NT LAN Manager" : "Administrador de LAN NT",
     "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
     "Open documentation" : "Abrir documentación",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
     "Send mode" : "Modo de envío",
     "Encryption" : "Encripción",
     "From address" : "De la dirección",
-    "Authentication method" : "Método de autenticación",
-    "Authentication required" : "Autenticación requerida",
     "Server address" : "Dirección del servidor",
     "Port" : "Puerto",
+    "Authentication method" : "Método de autenticación",
+    "Authentication required" : "Autenticación requerida",
     "Credentials" : "Credenciales",
     "SMTP Username" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
@@ -193,21 +206,6 @@ OC.L10N.register(
     "Send email" : "Enviar correo electrónico",
     "All checks passed." : "Pasaron todas las verificaciones. ",
     "Version" : "Versión",
-    "Server-side encryption" : "Encripción del lado del servidor",
-    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
-    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
-    "Please read carefully before activating server-side encryption: " : "Por favor lee detenidamente antes de activar la encripción del lado de servidor:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
-    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
-    "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
-    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
-    "Enable encryption" : "Habilitar encripción",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
-    "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesitas migrar tus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Por favor habilita el \"Módulo de encripción predeterminado\" y ejecuta el comando 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Necesitas migar tus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
-    "Start migration" : "Iniciar migración",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
     "Enforce expiration date" : "Forzar fecha de expiración",
@@ -226,33 +224,34 @@ OC.L10N.register(
     "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Profile picture" : "Foto de perfil",
-    "Upload new" : "Cargar nuevo",
-    "Select from Files" : "Seleccionar desde Archivos",
-    "Remove image" : "Eliminar imagen",
-    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
-    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
-    "Choose as profile picture" : "Seleccionar como foto del perfil",
-    "Your phone number" : "Su número telefónico",
-    "Your postal address" : "Tu dirección postal",
-    "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
-    "Link https://…" : "Liga https:// ...",
-    "Twitter handle @…" : "Cuenta de twitter @...",
-    "Current password" : "Contraseña actual",
-    "New password" : "Nueva contraseña",
-    "Change password" : "Cambiar contraseña",
+    "Select a profile picture" : "Selecciona una imagen de perfil",
     "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
     "Couldn't update app." : "No fue posible actualizar la aplicación.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
-    "You need to set your user email before being able to send test emails." : "Requieres establecer tu correo electrónico antes de poder enviar correos electrónicos de prueba. ",
-    "All languages" : "Todos los idiomas",
-    "Everyone" : "Todos",
-    "Test email settings" : "Probar las configuraciones de correo electrónico",
+    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
+    "Migration started …" : "La migración ha comenzado ...",
+    "Address" : "Dirección",
+    "Avatar" : "Avatar",
+    "Plain" : "Plano",
+    "NT LAN Manager" : "Administrador de LAN NT",
+    "STARTTLS" : "STARTTLS",
+    "Please read carefully before activating server-side encryption: " : "Por favor lee detenidamente antes de activar la encripción del lado de servidor:",
+    "Enable encryption" : "Habilitar encripción",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesitas migrar tus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Por favor habilita el \"Módulo de encripción predeterminado\" y ejecuta el comando 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Necesitas migar tus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
+    "Start migration" : "Iniciar migración",
     "Last job execution ran %s. Something seems wrong." : "La última ejecución del trabajo corrió %s. Algo parece estar mal. ",
     "Last job ran %s." : "El último trabajo corrió %s.",
     "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
     "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
-    "days" : "días",
-    "No display name set" : "No se ha establecido el nombre a desplegar"
+    "Upload new" : "Cargar nuevo",
+    "Select from Files" : "Seleccionar desde Archivos",
+    "Remove image" : "Eliminar imagen",
+    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
+    "Choose as profile picture" : "Seleccionar como foto del perfil",
+    "Your postal address" : "Tu dirección postal",
+    "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
+    "Link https://…" : "Liga https:// ...",
+    "Twitter handle @…" : "Cuenta de twitter @..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
