@@ -232,9 +232,7 @@ OC.L10N.register(
     "Change password" : "تغییر گذر واژه",
     "Your profile picture" : "نگارهٔ نمایه‌تان",
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
-    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها",
     "Remove profile picture" : "برداشتن نگارهٔ نمایه",
-    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Cancel" : "منصرف شدن",
     "Details" : "جزییات",
@@ -399,12 +397,14 @@ OC.L10N.register(
     "Upload new" : "بارگذاری جدید",
     "Select from Files" : "از میان پرونده ها انتخاب کنید",
     "Remove image" : "تصویر پاک شود",
+    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
     "Choose as profile picture" : "یک تصویر برای پروفایل انتخاب کنید",
     "You are using <strong>%s</strong>" : "شما با استفاده از <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "شما با استفاده از <strong>%1$s</strong> از <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
     "Your postal address" : "آدرس پستی شما",
     "It can take up to 24 hours before the account is displayed as verified." : "24 ساعت طول می کشد تا اعتبار حساب تأیید شود.",
     "Link https://…" : "پیوند https://…",
-    "Twitter handle @…" : "دسته توییتر @…"
+    "Twitter handle @…" : "دسته توییتر @…",
+    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها"
 },
 "nplurals=2; plural=(n > 1);");
