@@ -232,11 +232,11 @@ OC.L10N.register(
     "Current password" : "Nykyinen salasana",
     "New password" : "Uusi salasana",
     "Change password" : "Vaihda salasana",
+    "Your profile information" : "Profiilitietosi",
     "Your profile picture" : "Profiilikuvasi",
     "Upload profile picture" : "Lähetä profiilikuva",
-    "Choose profile picture from files" : "Valitse profiilikuva tiedostoista",
+    "Choose profile picture from Files" : "Valitse profiilikuva tiedostoista",
     "Remove profile picture" : "Poista profiilikuva",
-    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
     "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
     "Cancel" : "Peru",
     "Set as profile picture" : "Aseta profiilikuvaksi",
@@ -283,6 +283,7 @@ OC.L10N.register(
     "Your role" : "Roolisi",
     "Your Twitter handle" : "Twitter-tunnuksesi",
     "Your website" : "Verkkosivustosi",
+    "Add additional email" : "Lisää toissijainen sähköpostiosoite",
     "Add" : "Lisää",
     "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "Add new password" : "Lisää uusi salasana",
@@ -303,6 +304,7 @@ OC.L10N.register(
     "Delete {userid}'s account" : "Poista käyttäjän {userid} tili",
     "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
     "Edit User" : "Muokkaa käyttäjää",
+    "Toggle user actions menu" : "Näytä tai piilota käyttäjätoimintojen valikko",
     "{size} used" : "{size} käytetty",
     "New user" : "Uusi käyttäjä",
     "Will be autogenerated" : "Luodaan automaattisesti",
@@ -355,6 +357,7 @@ OC.L10N.register(
     "Profile picture" : "Profiilikuva",
     "About" : "Tietoja",
     "Full name" : "Koko nimi",
+    "Additional email" : "Toissijainen sähköpostiosoite",
     "Headline" : "Otsikko",
     "Organisation" : "Organisaatio",
     "Phone number" : "Puhelinnumero",
@@ -378,6 +381,7 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
     "Documentation" : "Dokumentaatio",
     "Forum" : "Keskustelupalsta",
     "Login" : "Kirjaudu",
@@ -477,6 +481,7 @@ OC.L10N.register(
     "Upload new" : "Lähetä uusi",
     "Select from Files" : "Valitse tiedostosovelluksesta",
     "Remove image" : "Poista kuva",
+    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Ota huomioon, että kuvan päivittyminen kaikkialle saattaa kestää jopa 24 tuntia.",
     "Choose as profile picture" : "Valitse profiilikuvaksi",
     "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
@@ -488,6 +493,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Saattaa kestää jopa 24 tuntia, ennen kuin tili näytetään vahvistettuna.",
     "Link https://…" : "Linkki https://…",
     "Change privacy level of Twitter profile" : "Muuta Twitter-tunnuksen yksityisyystasoa",
-    "Twitter handle @…" : "Twitter-tunnus @…"
+    "Twitter handle @…" : "Twitter-tunnus @…",
+    "Choose profile picture from files" : "Valitse profiilikuva tiedostoista"
 },
 "nplurals=2; plural=(n != 1);");
