@@ -268,11 +268,12 @@ OC.L10N.register(
     "Current password" : "Mot de passe actuel",
     "New password" : "Nouveau mot de passe",
     "Change password" : "Changer de mot de passe",
+    "Your profile information" : "Informations de votre profil",
     "Your profile picture" : "Votre photo de profil",
     "Upload profile picture" : "Téléverser une photo de profil",
-    "Choose profile picture from files" : "Choisir une image parmi les fichiers",
+    "Choose profile picture from Files" : "Choisir une image de profil dans Fichiers",
     "Remove profile picture" : "Retirer la photo de profil",
-    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
+    "The file must be a PNG or JPG" : "Le fichier doit être au format PNG ou JPG",
     "Picture provided by original account" : "Photo fournie par le compte original",
     "Cancel" : "Annuler",
     "Set as profile picture" : "Définir comme image de profil",
@@ -427,13 +428,14 @@ OC.L10N.register(
     "Show to logged in users only" : "Montrer seulement aux utilisateurs connectés",
     "Hide" : "Cacher",
     "Download and enable" : "Télécharger et activer",
-    "Enable untested app" : "Activer les applications non testées",
+    "Enable untested app" : "Activer l'application non testée",
     "The app will be downloaded from the App Store" : "L'application sera téléchargée depuis le magasin d'applications",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Cette application n'est pas indiquée comme étant compatible avec votre version de Nextcloud. Si vous continuez vous pourrez toujours installer l'app. Notez cependant qu'elle pourrait ne pas fonctionner comme prévu.",
     "Never" : "Jamais",
     "An error occurred during the request. Unable to proceed." : "Une erreur s'est produite pendant la demande. Impossible de poursuivre.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'application a été activée mais doit être mise à jour. Vous allez être redirigé vers la page des mises à jour dans 5 secondes.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Erreur : cette application ne peut être activée car elle rend le serveur instable",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
     "Documentation" : "Documentation",
     "Forum" : "Forum",
     "Login" : "Login",
@@ -548,6 +550,7 @@ OC.L10N.register(
     "Upload new" : "Téléverser une nouvelle image",
     "Select from Files" : "Sélectionner depuis Fichiers",
     "Remove image" : "Supprimer la photo",
+    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 Mo",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Veuillez noter que cela peut prendre jusqu'à 24 heures pour que l'avatar soit mis à jour partout.",
     "Choose as profile picture" : "Définir comme image de profil",
     "You are using <strong>%s</strong>" : "Vous utilisez <strong>%s</strong>",
@@ -559,6 +562,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Cela peut prendre jusqu'à 24 heures avant que le compte soit affiché comme vérifié.",
     "Link https://…" : "Lien https://…",
     "Change privacy level of Twitter profile" : "Changer le niveau de confidentialité du profil Twitter",
-    "Twitter handle @…" : "Pseudo Twitter @..."
+    "Twitter handle @…" : "Pseudo Twitter @...",
+    "Choose profile picture from files" : "Choisir une image parmi les fichiers"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
