@@ -38,6 +38,8 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} cambiou o seu enderezo de correo",
     "You changed your email address" : "Vostede cambiou o seu enderezo de correo",
     "Your email address was changed by an administrator" : "O seu enderezo de correo foi cambiado por un administrador",
+    "You created an app password for a session named \"{token}\"" : "Creou un contrasinal de aplicación para unha sesión chamada \"{token}\"",
+    "An administrator created an app password for a session named \"{token}\"" : "Un administrador creou un contrasinal de aplicación para unha sesión chamada \"{token}\"",
     "You deleted app password \"{token}\"" : "Vostede eliminou o contrasinal da aplicación «{token}»",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Vostede renomeou o contrasinal da aplicación «{token}» como «{newToken}»",
     "You granted filesystem access to app password \"{token}\"" : "Vostede concedeu acceso ao sistema de ficheiros ao contrasinal da aplicación «{token}»",
@@ -48,6 +50,7 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Iniciouse a limpeza remota en %1$s",
     "Remote wipe has finished on %1$s" : "Rematou a limpeza remota en %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Foi modificado o seu <strong>contrasinal</strong> ou o seu <strong>correo electrónico</strong>",
+    "Apps" : "Aplicacións",
     "Could not remove app." : "Non se puido eliminar a aplicación.",
     "Could not update app." : "Non se puido actualizar a aplicación.",
     "Wrong password" : "Contrasinal incorrecto",
@@ -68,6 +71,7 @@ OC.L10N.register(
     "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache está configurado para eliminar comentarios de código. Con OPcache activado, debe configurarse <code>opcache.save_comments=1</code> para que Nextcloud funcione.",
     "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud non pode usar a API OPcache. Con OPcache activado, é moi recomendable incluír todos os directorios de Nextcloud con <code>opcache.restrict_api</code> ou desactivar esta configuración para desactivar as restricións da API de OPcache, para evitar erros durante as actualizacións do núcleo de Nextcloud ou da aplicación.",
     "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud non pode usar a API OPcache. É moi recomendable incluír todos os directorios de Nextcloud con <code>opcache.restrict_api</code> ou desactivar esta configuración para desactivar as restricións da API de OPcache, para evitar erros durante as actualizacións do núcleo de Nextcloud ou das aplicacións.",
+    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "O OPcache baseado na memoria compartida está desactivado. Para un mellor rendemento, recoméndase aplicar <code>opcache.file_cache_only=0</code> á súa configuración de PHP e utilizar a caché de ficheiros só como caché de segundo nivel.",
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves OPcache está case superado. Para garantir que todos os scripts poden manterse na caché, recoméndase aplicar <code>opcache.max_accelerated_files</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer OPcache está case cheo. Para garantir que todos os scripts se poidan gardar na caché, recoméndase aplicar <code>opcache.memory_consumption</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer de cadeas internadas en OPcache está case cheo. Para asegurarse de que as cadeas que se repiten poidan almacenarse na caché de forma efectiva, recoméndase aplicar <code>opcache.interned_strings_buffer</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
@@ -80,6 +84,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "Non foi posíbel enviar o correo. Comprobe o rexistro do servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu un problema ao enviar o correo. Revise a súa configuración. (Erro: %s)",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Debes configurar o teu correo electrónico de usuario antes de poder enviar correos electrónicos de proba. Vaia a %spara iso.",
+    "Users" : "Usuarios",
     "Invalid user" : "Usuario incorrecto",
     "Invalid mail address" : "Enderezo de correo incorrecto",
     "Settings saved" : "Axustes gardados",
@@ -111,7 +116,6 @@ OC.L10N.register(
     "Go to %s" : "Ira a %s",
     "Install Client" : "Instalar o cliente",
     "Logged in user must be a subadmin" : "O usuario rexistrado debe ser un subadministrador",
-    "Apps" : "Aplicacións",
     "Settings" : "Axustes",
     "Personal" : "Persoal",
     "Administration" : "Administración",
@@ -183,13 +187,14 @@ OC.L10N.register(
     "Disable all" : "Desactivar todo",
     "Enable all" : "Activar todo",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicación ten unha actualización dispòñíbel.","%n aplicacións teñen unha actualización dispoñíbel."],
+    "_Update_::_Update all_" : ["Actualizar","Actualiza todo"],
     "Marked for remote wipe" : "Marcado para limpeza remota",
     "Device settings" : "Axustes do dispositivo",
     "Allow filesystem access" : "Permitir o acceso aos  sistema de ficheiros",
     "Rename" : "Renomear",
     "Revoke" : "Revogar",
     "Wipe device" : "Limpar o dispositivo",
-    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "A revogación deste token pode impedir a eliminación do teu dispositivo se aínda non iniciou a eliminación.",
+    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "A revogación deste testemuño pode impedir a limpeza do seu dispositivo se aínda non iniciou a limpeza.",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -263,11 +268,11 @@ OC.L10N.register(
     "Current password" : "Contrasinal actual",
     "New password" : "Novo contrasinal",
     "Change password" : "Cambiar o contrasinal",
+    "Your profile information" : "A información do teu perfil",
     "Your profile picture" : "A túa imaxe de perfil",
     "Upload profile picture" : "Subir imaxe de perfil",
-    "Choose profile picture from files" : "Escolle a imaxe de perfil dende Ficheiros",
+    "Choose profile picture from Files" : "Escolle a imaxe de perfil de Ficheiros",
     "Remove profile picture" : "Eliminar a imaxe de perfil",
-    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
     "Picture provided by original account" : "Imaxe fornecida pola conta orixinal ",
     "Cancel" : "Cancelar",
     "Set as profile picture" : "Establecer como imaxe de perfil",
@@ -429,8 +434,10 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non se pode continuar.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicación foi activada pero necesita ser actualizada. Vai ser redirixido cara a páxina de actualizarións en 5 segundos.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Erro: esta aplicación non se pode activar porque fai que o servidor sexa inestable",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto co seu administrador se se trata dun erro.",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
+    "Login" : "Acceso",
     "SSL/TLS" : "SSL/TLS",
     "Open documentation" : "Abrir a documentación",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para que poida enviar correos, por exemplo para cambios de contrasinais e notificacións.",
@@ -440,6 +447,9 @@ OC.L10N.register(
     "From address" : "Dende o enderezo",
     "Server address" : "Enderezo do servidor",
     "Port" : "Porto",
+    "Authentication method" : "Método de autenticación",
+    "Only applies when authentication is required" : "Só se aplica cando é necesaria a autenticación",
+    "Authentication required" : "É necesaria a autenticación",
     "Credentials" : "Credenciais",
     "SMTP Username" : "Nome de usuario SMTP",
     "SMTP Password" : "Contrasinal SMTP",
@@ -518,12 +528,9 @@ OC.L10N.register(
     "Address" : "Enderezo",
     "Avatar" : "Avatar",
     "An error occured during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non é posíbel continuar.",
-    "Login" : "Acceso",
     "Plain" : "Simple",
     "NT LAN Manager" : "Xestor NT LAN",
     "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Método de autenticación",
-    "Authentication required" : "É necesaria a autenticación",
     "Please read carefully before activating server-side encryption: " : "Lea detidamente antes de activar o cifrado do lado do servidor:",
     "Enable encryption" : "Activar o cifrado",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "É necesario migrar as súas claves de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Active o «Módulo predeterminado de cifrado» e execute «occ encryption:migrate»",
@@ -542,6 +549,7 @@ OC.L10N.register(
     "Upload new" : "Novo envío",
     "Select from Files" : "Seleccionar dende Ficheiros",
     "Remove image" : "Retirar a imaxe",
+    "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Ten en conta que o avatar pode tardar ata 24 horas en actualizarse en todas partes.",
     "Choose as profile picture" : "Seleccionar como imaxe do perfil",
     "You are using <strong>%s</strong>" : "Está usando <strong>%s</strong>",
@@ -553,6 +561,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Pode levar ata 24 horas antes de que a conta apareza como como verificada.",
     "Link https://…" : "Ligazón https://…",
     "Change privacy level of Twitter profile" : "Cambia o nivel de privacidade do perfil de Twitter",
-    "Twitter handle @…" : "Usuario do Twitter @…"
+    "Twitter handle @…" : "Usuario do Twitter @…",
+    "Choose profile picture from files" : "Escolle a imaxe de perfil dende Ficheiros"
 },
 "nplurals=2; plural=(n != 1);");
