@@ -267,9 +267,7 @@ OC.L10N.register(
     "Change password" : "パスワードを変更",
     "Your profile picture" : "プロフィール画像",
     "Upload profile picture" : "新しいプロフィール画像のアップロード",
-    "Choose profile picture from files" : "ファイルからプロフィール画像を選択",
     "Remove profile picture" : "プロフィール画像を削除",
-    "png or jpg, max. 20 MB" : "pngまたはjpg。最大20MB",
     "Picture provided by original account" : "オリジナルのアカウントで提供されている写真",
     "Cancel" : "キャンセル",
     "Set as profile picture" : "プロフィール画像として設定",
@@ -430,6 +428,7 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "要求中にエラーが発生しました。 続行できません。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "アプリは有効ですが、更新が必要です。5秒後に更新ページにリダイレクトします。",
     "Error: This app cannot be enabled because it makes the server unstable" : "エラー：このアプリは、サーバーを不安定にするため、有効にすることができません。",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "ネットワークからのリクエストが多すぎました。このようなエラーが発生した場合は、後で再試行するか、管理者に連絡してください。",
     "Documentation" : "ドキュメント",
     "Forum" : "フォーラム",
     "Login" : "ログイン",
@@ -543,6 +542,7 @@ OC.L10N.register(
     "Upload new" : "新たにアップロード",
     "Select from Files" : "ファイルから選択",
     "Remove image" : "画像を削除",
+    "png or jpg, max. 20 MB" : "pngまたはjpg。最大20MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "全ての場所でアバターが更新されるまでに最大二四時間かかる場合があります。",
     "Choose as profile picture" : "プロフィール画像として選択",
     "You are using <strong>%s</strong>" : "<strong>%s</strong>を現在使用中です",
@@ -554,6 +554,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "アカウントが確認済みとして表示されるまでには最大24時間かかることがあります。",
     "Link https://…" : "リンク https://...",
     "Change privacy level of Twitter profile" : "Twitterプロフィールのプライバシーレベルを変更",
-    "Twitter handle @…" : "あなたのTwitter ID @..."
+    "Twitter handle @…" : "あなたのTwitter ID @...",
+    "Choose profile picture from files" : "ファイルからプロフィール画像を選択"
 },
 "nplurals=1; plural=0;");
