@@ -268,11 +268,11 @@ OC.L10N.register(
     "Current password" : "Nuvarande lösenord",
     "New password" : "Nytt lösenord",
     "Change password" : "Ändra lösenord",
+    "Your profile information" : "Din profilinformation",
     "Your profile picture" : "Din profilbild",
     "Upload profile picture" : "Ladda upp profilbild",
-    "Choose profile picture from files" : "Välj profilbild från filer",
+    "Choose profile picture from Files" : "Välj profilbild från filer",
     "Remove profile picture" : "Ta bort profilbild",
-    "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
     "Picture provided by original account" : "Bild gjordes tillgänglig av orginalkonto",
     "Cancel" : "Avbryt",
     "Set as profile picture" : "Ställ in som profilbild",
@@ -434,6 +434,7 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "Ett fel uppstod under begäran. Det gick inte att fortsätta.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det kom för många förfrågningar från ditt nätverk. Försök senare eller kontakta din administratör om detta är ett fel.",
     "Documentation" : "Dokumentation",
     "Forum" : "Forum",
     "Login" : "Logga in",
@@ -548,6 +549,7 @@ OC.L10N.register(
     "Upload new" : "Ladda upp ny",
     "Select from Files" : "Välj från Filer",
     "Remove image" : "Ta bort bild",
+    "png or jpg, max. 20 MB" : "png eller jpg, max 20 MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Observera att det kan ta upp till 24 timmar för avataren att uppdateras överallt.",
     "Choose as profile picture" : "Välj som profilbild",
     "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
@@ -559,6 +561,7 @@ OC.L10N.register(
     "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
     "Link https://…" : "Länk https://...",
     "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
-    "Twitter handle @…" : "Twitter handle @…"
+    "Twitter handle @…" : "Twitter handle @…",
+    "Choose profile picture from files" : "Välj profilbild från filer"
 },
 "nplurals=2; plural=(n != 1);");
