@@ -30,7 +30,7 @@ OC.L10N.register(
     "{actor} removed {user} from group {group}" : "{actor} {user} kullanıcısını {group} grubundan çıkardı",
     "An administrator removed you from group {group}" : "Bir yönetici sizi {group} grubundan çıkardı",
     "An administrator removed {user} from group {group}" : "Bir yönetici {user} kullanıcısını {group} grubundan çıkardı",
-    "Your <strong>group memberships</strong> were modified" : "<strong>Grup üyelikleriniz</strong> değiştirildi",
+    "Your <strong>group memberships</strong> were modified" : "<strong>Grup üyelikleriniz</strong> değiştirildiğinde",
     "{actor} changed your password" : "{actor} parolanızı değiştirdi",
     "You changed your password" : "Parolanızı değiştirdiniz",
     "Your password was reset by an administrator" : "Parolanız bir yönetici tarafından sıfırlandı",
@@ -45,11 +45,12 @@ OC.L10N.register(
     "You granted filesystem access to app password \"{token}\"" : "\"{token}\" uygulama parolasına dosya sistemi erişim izni verdiniz",
     "You revoked filesystem access from app password \"{token}\"" : "\"{token}\" uygulama parolasından dosya sistemi erişim iznini kaldırdınız",
     "Security" : "Güvenlik",
-    "You successfully logged in using two-factor authentication (%1$s)" : "İki aşamalı kimlik doğrulama ile oturum açtınız (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "İki aşamalı kimlik doğrulama ile oturum açma girişimi reddedildi (%1$s)",
+    "You successfully logged in using two-factor authentication (%1$s)" : "İki adımlı doğrulama ile oturum açtınız (%1$s)",
+    "A login attempt using two-factor authentication failed (%1$s)" : "İki adımlı doğrulama ile oturum açma girişimi reddedildi (%1$s)",
     "Remote wipe was started on %1$s" : "Uzaktan silme işlemi %1$s zamanında başlatıldı",
     "Remote wipe has finished on %1$s" : "Uzaktan silme işlemi %1$s zamanında tamamlandı",
-    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parolanız</strong> ya da <strong>e-posta adresiniz</strong> değiştirildi",
+    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parolanız</strong> ya da <strong>e-posta adresiniz</strong> değiştirildiğinde",
+    "Apps" : "Uygulamalar",
     "Could not remove app." : "Uygulama kaldırılamadı.",
     "Could not update app." : "Uygulama güncellenemedi.",
     "Wrong password" : "Parola yanlış",
@@ -83,16 +84,17 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "E-posta gönderilemedi. E-posta sunucunuzun günlüklerine bakın",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-posta gönderilirken bir sorun çıktı. Lütfen ayarlarınızı gözden geçirin. (Hata: %s)",
     "You need to set your user email before being able to send test emails. Go to %s for that." : "Sınama e-postaları göndermeden önce kullanıcı e-postanızı ayarlamalısınız. Bunun için %s bölümüne gidin.",
+    "Users" : "Kullanıcılar",
     "Invalid user" : "Kullanıcı geçersiz",
     "Invalid mail address" : "E-posta adresi geçersiz",
     "Settings saved" : "Ayarlar kaydedildi",
     "Unable to change full name" : "Tam adınız değiştirilemedi",
     "Unable to change email address" : "E-posta adresi değiştirilemedi",
     "Unable to set invalid phone number" : "Telefon numarası geçersiz olduğundan ayarlanamadı",
-    "Unable to set invalid website" : "Web sitesi geçersiz olduğundan ayarlanamadı",
+    "Unable to set invalid website" : "Site geçersiz olduğundan ayarlanamadı",
     "Some account data was invalid" : "Bazı hesap bilgileri geçersiz",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Twitter hesabınızı doğrulamak için şu iletiyi Twitter üzerine gönderin (satır sonu olmadan gönderdiğinizden emin olun):",
-    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Web sitenizi doğrulamak için şu içeriği web sitenizin kök klasörüne '.well-known/CloudIdVerificationCode.txt' dosyası içine ekleyin (tüm içeriğin tek bir satır olarak eklendiğinden emin olun):",
+    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Sitenizi doğrulamak için şu içeriği sitenizin kök klasörüne '.well-known/CloudIdVerificationCode.txt' dosyası içine ekleyin (tüm içeriğin tek bir satır olarak eklendiğinden emin olun):",
     "%1$s changed your password on %2$s." : "%1$s, %2$s üzerindeki parolanızı değiştirdi.",
     "Your password on %s was changed." : "%s üzerindeki parolanız değiştirildi.",
     "Your password on %s was reset by an administrator." : "%s üzerindeki parolanız bir yönetici tarafından sıfırlandı.",
@@ -114,7 +116,6 @@ OC.L10N.register(
     "Go to %s" : "%s sayfasına gidin",
     "Install Client" : "İstemciyi kurun",
     "Logged in user must be a subadmin" : "Oturum açmış kullanıcı bir alt yönetici olmalıdır",
-    "Apps" : "Uygulamalar",
     "Settings" : "Ayarlar",
     "Personal" : "Kişisel",
     "Administration" : "Yönetim",
@@ -124,7 +125,7 @@ OC.L10N.register(
     "Overview" : "Özet",
     "Basic settings" : "Temel ayarlar",
     "Sharing" : "Paylaşım",
-    "Availability" : "Kullanılabilirlik",
+    "Availability" : "Uygunluk",
     "Calendar" : "Takvim",
     "Personal info" : "Kişisel bilgiler",
     "Mobile & desktop" : "Mobil ve masaüstü",
@@ -145,21 +146,21 @@ OC.L10N.register(
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL \"%s\" sürümü kullanılıyor. Nextcloud 21 sürümünde bu sürüm desteklenmiyor. MySQL 8.0 ya da MariaDB 10.2 ve üzerindeki bir sürüm kullanılmalıdır.",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL \"%s\" sürümü kullanılıyor. Nextcloud 21 sürümünde bu sürüm desteklenmiyor. PostgreSQL 9.6 ve üzerindeki bir sürüm kullanılmalıdır.",
     "Profile information" : "Profil bilgileri",
-    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profil görseli, tam ad, e-posta adresi, telefon numarası, adres, web sitesi, Twitter, kuruluş, rol, başlık, özgeçmi ve profilde etkinleştirilmiş diğer bilgiler",
+    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profil görseli, tam ad, e-posta adresi, telefon numarası, adres, site, Twitter, kuruluş, rol, başlık, özgeçmiş ve profilde etkinleştirilmiş diğer bilgiler",
     "Nextcloud settings" : "Nextcloud ayarları",
     "Here you can decide which group can access certain sections of the administration settings." : "Hangi yönetici ayarlarına hangi grubun erişebileceğini bu bölümden belirleyebilirsiniz.",
     "None" : "Yok",
     "Unable to modify setting" : "Ayar değiştirilemedi",
-    "Two-Factor Authentication" : "İki aşamalı kimlik doğrulama",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tüm kullanıcılar ve belirli gruplar için iki aşamalı kimlik doğrulama kullanılır. Yapılandırılmış bir iki aşamalı kimlik doğrulama hizmeti sağlayıcısı olmayan kullanıcılar oturum açamaz.",
-    "Enforce two-factor authentication" : "İki aşamalı kimlik doğrulama dayatılsın",
-    "Limit to groups" : "Şu gruplarla sınırlansın",
-    "Enforcement of two-factor authentication can be set for certain groups only." : "İki aşamalı kimlik doğrulaması yalnızca belirli gruplar için sınırlanabilir.",
-    "Two-factor authentication is enforced for all members of the following groups." : "Belirtilen grupların tüm üyeleri için iki aşamalı kimlik doğrulaması kullanımı zorunlu olur.",
+    "Two-Factor Authentication" : "İki adımlı doğrulama",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tüm kullanıcılar ve belirli gruplar için iki adımlı doğrulama kullanılır. İki adımlı doğrulama hizmeti sağlayıcısını yapılandırmayan kullanıcılar oturum açamaz.",
+    "Enforce two-factor authentication" : "İki adımlı doğrulama dayatılsın",
+    "Limit to groups" : "Sınırlanacak gruplar",
+    "Enforcement of two-factor authentication can be set for certain groups only." : "İki adımlı doğrulama yalnızca belirli gruplar için sınırlanabilir.",
+    "Two-factor authentication is enforced for all members of the following groups." : "Belirtilen grupların tüm üyeleri için iki adımlı doğrulama kullanımı zorunlu olur.",
     "Enforced groups" : "Uygulanacak gruplar",
-    "Two-factor authentication is not enforced for members of the following groups." : "Belirtilen grupların tüm üyeleri için iki aşamalı kimlik doğrulaması kullanımı zorunlu olmaz.",
+    "Two-factor authentication is not enforced for members of the following groups." : "Belirtilen grupların tüm üyeleri için iki adımlı doğrulama kullanımı zorunlu olmaz.",
     "Excluded groups" : "Uygulanmayacak gruplar",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Uygulanan ya da uygulanmayan gruplar belirtildiğinde, bir kullanıcının iki aşamalı kimlik doğrulaması kullanıp kullanmayacağına şu şekilde karar verilir. Herhangi bir grup belirtilmemiş ise, uygulanmayan grupların üyeleri dışındaki tüm üyeler için iki aşamalı kimlik doğrulaması kullanılır. Belirtilmiş gruplar varsa, uygulanan bu grupların üyeleri için iki aşamalı kimlik doğrulaması kullanılır. Bir kullanıcının hem uygulanan hem de uygulanmayan gruplarda üyeliği varsa, uygulanan grupların önceliği vardır ve iki aşamalı kimlik doğrulaması kullanılır.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Uygulanan ya da uygulanmayan gruplar belirtildiğinde, bir kullanıcının iki adımlı doğrulama kullanıp kullanmayacağına şu şekilde karar verilir. Herhangi bir grup belirtilmemiş ise, uygulanmayan grupların üyeleri dışındaki tüm üyeler için iki adımlı doğrulama kullanılır. Belirtilmiş gruplar varsa, uygulanan bu grupların üyeleri için iki adımlı doğrulama kullanılır. Bir kullanıcının hem uygulanan hem de uygulanmayan gruplarda üyeliği varsa, uygulanan grupların önceliği vardır ve iki adımlı doğrulama kullanılır.",
     "Save changes" : "Değişiklikleri kaydet",
     "All" : "Tümü",
     "Limit app usage to groups" : "Uygulama kullanımı şu gruplarla sınırlansın",
@@ -171,7 +172,7 @@ OC.L10N.register(
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Bu uygulama için en yüksek Nextcloud sürümü belirtilmemiş. Bu durum ileride sorun çıkarır.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Aşağıdaki bağımlılıklar sağlanmadığından bu uygulama kurulamıyor:",
     "View in store" : "Mağazada görüntüle",
-    "Visit website" : "Web sayfasına bakın",
+    "Visit website" : "Siteye bakın",
     "Report a bug" : "Hata bildirin",
     "Admin documentation" : "Yönetici belgeleri",
     "Developer documentation" : "Geliştirici belgeleri",
@@ -211,7 +212,7 @@ OC.L10N.register(
     "Device" : "Aygıt",
     "Last activity" : "Son işlem",
     "Devices & sessions" : "Aygıt ve oturumlar",
-    "Web, desktop and mobile clients currently logged in to your account." : "Şu anda hesabınıza oturum açmış web, masaüstü ve mobil istemciler.",
+    "Web, desktop and mobile clients currently logged in to your account." : "Şu anda hesabınıza oturum açmış internet, masaüstü ve mobil istemcileri.",
     "Do you really want to wipe your data from this device?" : "Bu aygıt üzerindeki verilerinizi silmek istediğinize emin misiniz?",
     "Confirm wipe" : "Silmeyi onayla",
     "Error while creating device token" : "Aygıt kodu oluşturulurken sorun çıktı",
@@ -235,16 +236,16 @@ OC.L10N.register(
     "Last job ran {relativeTime}." : "Son görev yürütülmesi: {relativeTime}.",
     "Background job did not run yet!" : "Arka plan görevi henüz yürütülmemiş!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Her sayfa yüklendiğinde bir görrev yürütülür. Kullanım şekli: Tek kullanıcılı kopya.",
-    "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php, HTTP üzerinden her 5 dakikada bir cron.php sayfasını çağıran bir webcron hizmetinde kayıtlıdır. Kullanım şekli: Çok küçük kopya (kullanıma bağlı olarak 1–5 kullanıcı).",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Her sayfa yüklendiğinde bir görev yürütülür. Kullanım şekli: Tek kullanıcılı kopya.",
+    "Webcron" : "İnternet zamanlanmış görevi",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php, HTTP üzerinden her 5 dakikada bir cron.php sayfasını çağıran bir internet zamanlanmış görevi hizmetinde kayıtlıdır. Kullanım şekli: Çok küçük kopya (kullanıma bağlı olarak 1–5 kullanıcı).",
     "Cron (Recommended)" : "Cron (önerilen)",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Bunu çalıştıraiblmek için PHP POSIX eklentisi gereklidir. Ayrıntılı bilgi almak için {linkstart}PHP belgelerine{linkend} bakabilirsiniz.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "5 dakikada bir cron.php dosyasının çağrılması için sistem cron hizmeti kullanılır. Tüm kopyalar için önerilir.",
     "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php dosyası \"{user}\" sistem kullanıcısı tarafından yürütülmelidir.",
     "Unable to update background job mode" : "Arka plan görevi kipi güncellenemedi",
     "Profile" : "Profil",
-    "Enable or disable profile by default for new users." : "Bu seçenek etkinleştirildiğinde, profil yeni kullanıcılar için varsayılan oluır.",
+    "Enable or disable profile by default for new users." : "Bu seçenek etkinleştirildiğinde, profil yeni kullanıcılar için varsayılan olur.",
     "Enable" : "Etkinleştir",
     "Unable to update profile default setting" : "Profil varsayılan ayarı güncellenemedi",
     "Server-side encryption" : "Sunucu tarafı şifreleme",
@@ -267,11 +268,12 @@ OC.L10N.register(
     "Current password" : "Geçerli parola",
     "New password" : "Yeni parola",
     "Change password" : "Parola değiştir",
+    "Your profile information" : "Profil bilgileriniz",
     "Your profile picture" : "Profil görseliniz",
     "Upload profile picture" : "Profil görseli yükle",
-    "Choose profile picture from files" : "Profil görselini dosyalardan seçin",
+    "Choose profile picture from Files" : "Dosyalar uygulamasından profil görseli seçin",
     "Remove profile picture" : "Profil görselini kaldır",
-    "png or jpg, max. 20 MB" : "png ya da jpg, en fazla 20 MB",
+    "The file must be a PNG or JPG" : "Dosya PNG ya da JPG biçiminde olmalıdır",
     "Picture provided by original account" : "Görsel özgün hesabınız tarafından sağlanıyor",
     "Cancel" : "İptal",
     "Set as profile picture" : "Profil görseli olarak ayarla",
@@ -324,7 +326,7 @@ OC.L10N.register(
     "Unable to update visibility of {displayId}" : "{displayId} görünürlüğü güncellenemedi",
     "Your role" : "Pozisyonunuz",
     "Your Twitter handle" : "Twitter adresiniz",
-    "Your website" : "Web sitesi adresiniz",
+    "Your website" : "Sitenizin adresi",
     "No {property} set" : "Herhangi bir {property} ayarlanmamış",
     "Unable to update {property}" : "{property} güncellenemedi",
     "Change scope level of {property}, current scope is {scope}" : "{property} kapsam düzeyini değiştir. Geçerli kapsam: {scope}",
@@ -381,7 +383,7 @@ OC.L10N.register(
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Hesabınız için FIDO2 standardına uygun parolasız kimlik doğrulamasını kurun.",
     "No devices configured." : "Herhangi bir aygıt yapılandırılmamış.",
     "The following devices are configured for your account:" : "Hesabınız için şu aygıtlar yapılandırılmış:",
-    "Your browser does not support WebAuthn." : "Web tarayıcınız WebAuthn desteklemiyor.",
+    "Your browser does not support WebAuthn." : "Tarayıcınız WebAuthn desteklemiyor.",
     "Your apps" : "Uygulamalarınız",
     "{license}-licensed" : "{license}-lisanslı",
     "Changelog" : "Değişiklik günlüğü",
@@ -412,7 +414,7 @@ OC.L10N.register(
     "Role" : "Pozisyon",
     "Twitter" : "Twitter",
     "Fediverse (e.g. Mastodon)" : "Fediverse (Mastodon gibi)",
-    "Website" : "Web sitesi",
+    "Website" : "Site",
     "Profile visibility" : "Profil görünürlüğü",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Bu özellik, dosya paylaşımı ve takvim çağrıları gibi temel işlevler için gerekli olduğundan kullanılamıyor",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Hesabınızda birleşik kullanım devre dışı bırakılmış olduğundan kullanılamıyor. Herhangi bir sorunuz varsa sistem yöneticinizle görüşün.",
@@ -433,8 +435,10 @@ OC.L10N.register(
     "An error occurred during the request. Unable to proceed." : "İstek sırasında bir sorun çıktı. İşlem sürdürülemiyor.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Uygulama etkinleştirilmiş fakat güncellenmesi gerekiyor. 5 saniye içinde güncelleme sayfasına yönlendirileceksiniz.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Hata: Bu uygulama sunucuda kararsızlığa yol açtığından etkinleştirilemez",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ağınızdan çok fazla istekte bulunuldu. Bir süre sonra yeniden deneyin ya da bir sorun olduğunu düşünüyorsanız BT yöneticiniz ile görüşün.",
     "Documentation" : "Belgeler",
     "Forum" : "Forum",
+    "Login" : "Oturum açın",
     "SSL/TLS" : "SSL/TLS",
     "Open documentation" : "Belgeleri aç",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Bu sunucunun parola sıfırlama ve bildirim işlemleri için e-posta gönderebilecek şekilde ayarlanmış olması önemlidir.",
@@ -443,12 +447,15 @@ OC.L10N.register(
     "Sendmail mode" : "Sendmail kipi",
     "From address" : "Kimden adresi",
     "Server address" : "Sunucu adresi",
-    "Port" : "Kapı numarası",
+    "Port" : "Bağlantı noktası",
+    "Authentication method" : "Kimlik doğrulama yöntemi",
+    "Only applies when authentication is required" : "Yalnızca kimlik doğrulaması istendiğinde uygulanır",
+    "Authentication required" : "Kimlik doğrulaması gerekli",
     "Credentials" : "Kimlik doğrulama bilgileri",
     "SMTP Username" : "SMTP kullanıcı adı",
     "SMTP Password" : "SMTP parolası",
     "Save" : "Kaydet",
-    "Test and verify email settings" : "E-posta ayarlarını sınama ve doğrulama",
+    "Test and verify email settings" : "E-posta ayarlarını sınayın ve doğrulayın",
     "Send email" : "E-posta gönder",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Kopyanızın güvenli ve yüksek başarımla çalışması için ayarların doğru yapılmış olması önemlidir. Bunu sağlamak için bazı otomatik denetimler yapılır. Ayrıntılı bilgi almak için İpuçları bölümüne ve belgelere bakın.",
     "All checks passed." : "Tüm denetimlerden geçti.",
@@ -461,18 +468,18 @@ OC.L10N.register(
     "You need to enable the File sharing App." : "Dosya paylaşımı uygulamasını etkinleştirmelisiniz.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Yönetici olarak paylaşma davranışı ile ilgili ince ayarları yapabilirsiniz. Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
     "Allow apps to use the Share API" : "Uygulamalar Paylaşım API kullanabilsin",
-    "Set default expiration date for shares" : "Paylaşımların varsayılan kullanma süresi sonu",
+    "Set default expiration date for shares" : "Paylaşımlar için varsayılan kullanma süresi sonu ayarlansın",
     "Expire after" : "Geçerlilik süresi sonu",
     "day(s)" : "gün",
     "Enforce expiration date" : "Son kullanma tarihi dayatılsın",
-    "Set default expiration date for shares to other servers" : "Diğer sunuculara yapılan paylaşımların varsayılan kullanma süresi sonu",
+    "Set default expiration date for shares to other servers" : "Diğer sunuculara yapılan paylaşımlar için varsayılan kullanma süresi sonu ayarlansın",
     "Allow users to share via link and emails" : "Kullanıcılar bağlantı ve e-posta ile paylaşabilsin",
     "Allow public uploads" : "Herkes yükleyebilsin",
     "Always ask for a password" : "Her zaman parola sorulsun",
     "Enforce password protection" : "Parola koruması dayatılsın",
     "Exclude groups from password requirements:" : "Parola gereksinimlerine katılmayacak gruplar:",
-    "Set default expiration date" : "Varsayılan son kullanma tarihini ayarla",
-    "Exclude groups from creating link shares:" : "Bağlantı paylaşımı oluşturamayacak gruplar:",
+    "Set default expiration date" : "Varsayılan son kullanma tarihi ayarlansın",
+    "Exclude groups from creating link shares:" : "Şu gruplar bağlantı paylaşımı oluşturamasın:",
     "Allow resharing" : "Yeniden paylaşılabilsin",
     "Allow sharing with groups" : "Gruplar ile paylaşılabilsin",
     "Restrict users to only share with users in their groups" : "Kullanıcılar, yalnızca kendi gruplarındaki kullanıcılarla paylaşabilsin",
@@ -483,8 +490,8 @@ OC.L10N.register(
     "Allow username autocompletion to users based on phone number integration" : "Telefon numarası bütünleştirmesi eşleşmelerine göre kullanıcı adları otomatik olarak tamamlanabilsin",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "\"Aynı grup\" ve \"telefon numarası bütünleştirmesi\" etkinleştirilmiş ise. Kullanıcının görüntülenmesi için ikisinden birinde eşleşme olması yeterlidir.",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tam ad ya da e-posta adresi yazılırken otomatik olarak tamamlanabilsin (aynı grupta olma ya da telefon defteri eşleşmesi yok sayılarak)",
-    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Herkese açık bağlantı yükleme sayfasındaki sorumluluk reddi bildirim metni (yalnızca dosya listesi gizli iken görüntülenir)",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Dosya listesi gizli iken herkese açık bağlantı yükleme sayfasında görüntülenecek sorumluluk reddi bildirimi metni.",
+    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Herkese açık bağlantı yükleme sayfasında sorumluluk reddi bildirimi görüntülensin (yalnızca dosya listesi gizli iken görüntülenir)",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Dosya listesi gizliyken herkese açık bağlantı yükleme sayfasında görüntülenecek sorumluluk reddi bildirimi metnini buraya yazabilirsiniz.",
     "Default share permissions" : "Varsayılan paylaşım izinleri",
     "Reasons to use Nextcloud in your organization" : "Kuruluşunuzda Nextcloud kullanma nedenleriniz",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud topluluğu tarafından geliştirilmiştir{linkclose}.  {githubopen}Kaynak kodu{linkclose} {licenseopen}AGPL{linkclose} koşulları altında lisanslanmıştır.",
@@ -495,7 +502,7 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Bültenimize abone olun",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Bu Nextcloud topluluk sürümü desteklenmiyor ve anlık bildirimler kullanılamıyor.",
     "Use a second factor besides your password to increase security for your account." : "Parolanızın yanında ikinci bir doğrulama kullanarak hesabınızın güvenliğini arttırabilirsiniz.",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud bağlantısı kurmak için üçüncü taraf uygulamaları kullanıyorsanız, lütfen iki aşamalı kimlik doğrulamasını etkinleştirmeden önce her biri için bir uygulama parolası oluşturduğunuzdan ve yapılandırdığınızdan emin olun.",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Nextcloud bağlantısı kurmak için üçüncü taraf uygulamaları kullanıyorsanız, lütfen iki adımlı doğrulamayı etkinleştirmeden önce her biri için bir uygulama parolası oluşturduğunuzdan ve yapılandırdığınızdan emin olun.",
     "An error occurred while changing your language. Please reload the page and try again." : "Dil değiştirilirken bir sorun çıktı. Lütfen sayfayı yeniden yükleyerek yeniden deneyin.",
     "An error occurred while changing your locale. Please reload the page and try again." : "Yerel ayarlarınız değiştirilirken bir sorun çıktı. Lütfen sayfayı yeniden yükleyerek yeniden deneyin.",
     "Select a profile picture" : "Bir profil fotoğrafı seçin",
@@ -522,12 +529,9 @@ OC.L10N.register(
     "Address" : "Adres",
     "Avatar" : "Avatar",
     "An error occured during the request. Unable to proceed." : "İstek sırasında bir sorun çıktı. İşlem sürdürülemiyor.",
-    "Login" : "Oturum açın",
     "Plain" : "Düz",
     "NT LAN Manager" : "NT ağ yöneticisi",
     "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Kimlik doğrulama yöntemi",
-    "Authentication required" : "Kimlik doğrulaması gerekli",
     "Please read carefully before activating server-side encryption: " : "Lütfen sunucu tarafında şifrelemeyi etkinleştirmeden önce dikkatlice okuyun: ",
     "Enable encryption" : "Şifreleme kullanılsın",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Şifreleme anahtarlarınızı eski şifrelemeden (ownCloud <= 8.0) yenisine aktarmalısınız. Lütfen \"Varsayılan şifreleme modülü\"nü etkinleştirip 'occ encryption:migrate' komutunu yürütün",
@@ -546,6 +550,7 @@ OC.L10N.register(
     "Upload new" : "Yeni yükle",
     "Select from Files" : "Dosyalardan seç",
     "Remove image" : "Görseli kaldır",
+    "png or jpg, max. 20 MB" : "png ya da jpg, en fazla 20 MB",
     "Please note that it can take up to 24 hours for the avatar to get updated everywhere." : "Lütfen Avatarın her yerde güncellenmesinin 24 saat kadar sürebileceğini unutmayın.",
     "Choose as profile picture" : "Profil görseli olarak seç",
     "You are using <strong>%s</strong>" : "<strong>%s</strong> kullanıyorsunuz",
@@ -553,10 +558,11 @@ OC.L10N.register(
     "Change privacy level of phone number" : "Telefon numarasının gizlilik düzeyini değiştir",
     "Change privacy level of address" : "Adresin gizlilik düzeyini değiştir",
     "Your postal address" : "Posta adresiniz",
-    "Change privacy level of website" : "Web sitesinin gizlilik düzeyini değiştir",
+    "Change privacy level of website" : "Sitenin gizlilik düzeyini değiştir",
     "It can take up to 24 hours before the account is displayed as verified." : "Hesabın doğrulanması ve görüntülenmesi 24 saate kadar zaman alabilir.",
     "Link https://…" : "Bağlantı https://…",
     "Change privacy level of Twitter profile" : "Twitter profilinin gizlilik düzeyini değiştir",
-    "Twitter handle @…" : "Twitter kodu @…"
+    "Twitter handle @…" : "Twitter kodu @…",
+    "Choose profile picture from files" : "Profil görselini dosyalardan seçin"
 },
 "nplurals=2; plural=(n > 1);");
