@@ -143,7 +143,7 @@ class SectionSearch implements IProvider {
 					$section->getName(),
 					$subline,
 					$this->urlGenerator->linkToRouteAbsolute($routeName, ['section' => $section->getID()]),
-					'icon-settings'
+					'icon-settings-dark'
 				);
 			}
 		}
