@@ -39,10 +39,12 @@ OC.L10N.register(
     "You removed system tag {systemtag} from {file}" : "{systemtag} sistem etiketini {file} dosyasından sildiniz",
     "%1$s removed system tag %3$s from %2$s" : "%1$s, %3$s sistem etiketini %2$s dosyasından sildi",
     "{actor} removed system tag {systemtag} from {file}" : "{actor}, {systemtag} sistem etiketini {file} dosyasından sildi",
-    "%s (restricted)" : "%s (kısıtlı)",
+    "%s (restricted)" : "%s (kısıtlanmış)",
     "%s (invisible)" : "%s (gizli)",
-    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildi",
+    "<strong>System tags</strong> for a file have been modified" : "Bir dosyanın <strong>sistem etiketleri</strong> değiştirildiğinde",
     "Tags" : "Etiketler",
+    "All tagged %s …" : "Tüm %s etiketliler…",
+    "tagged %s" : "%s etiketli",
     "Collaborative tags" : "İşbirliği etiketleri",
     "Collaborative tagging functionality which shares tags among users." : "Etiketlerin kullanıcılar arasında paylaşılabilmesini sağlayan işbirlikli etiketleme özelliği.",
     "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "İşbirlikli etiketleme özelliği etiketlerin kullanıcılar arasında paylaşılabilmesini sağlar. Takımlar için harikadır. \n\t(Birden çok kuruluşun olduğu bir kurulumda etiketler zaten paylaşıldığı için bu uygulamanın devre dışı bırakılması önerilir).",
@@ -51,11 +53,11 @@ OC.L10N.register(
     "No tags found" : "Herhangi bir etiket bulunamadı",
     "Please select tags to filter by" : "Lütfen süzülecek etiketleri seçin",
     "No files found for the selected tags" : "Seçilmiş etiketlere uyan bir dosya bulunamadı",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İşbirliği etiketlerini tüm kullanıcılar kullanabilir. Kısıtlı etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "İşbirliği etiketlerini tüm kullanıcılar kullanabilir. Kısıtlanmış etiketleri kullanıcılar görebilir ancak atayamaz. Görünmeyen etiketler iç kullanım içindir ve kullanıcılar tarafından görülüp ve atanamaz.",
     "Create a new tag" : "Etiket ekle",
     "Name" : "Ad",
     "Public" : "Herkese açık",
-    "Restricted" : "Kısıtlı",
+    "Restricted" : "Kısıtlanmış",
     "Invisible" : "Gizli",
     "Delete" : "Sil",
     "Reset" : "Sıfırla",
