@@ -28,11 +28,12 @@ namespace OCA\Text\Service;
 
 use Exception;
 use OC\Files\Node\File;
+use OCA\Files_Sharing\SharedStorage;
 use OCA\Text\AppInfo\Application;
-use OCA\Text\DocumentHasUnsavedChangesException;
-use OCA\Text\DocumentSaveConflictException;
+use OCA\Text\Exception\DocumentHasUnsavedChangesException;
+use OCA\Text\Exception\DocumentSaveConflictException;
 use OCA\Text\TextFile;
-use OCA\Text\VersionMismatchException;
+use OCA\Text\Exception\VersionMismatchException;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
 use OCP\AppFramework\Http\DataResponse;
@@ -41,30 +42,37 @@ use OCP\AppFramework\Http\NotFoundResponse;
 use OCP\Constants;
 use OCP\Files\Lock\ILock;
 use OCP\Files\NotFoundException;
-use OCP\ILogger;
+use OCP\Files\NotPermittedException;
+use OCP\IL10N;
 use OCP\IRequest;
 use OCP\Lock\LockedException;
+use OCP\Share\IShare;
+use Psr\Log\LoggerInterface;
 
 class ApiService {
-	protected $request;
-	protected $sessionService;
-	protected $documentService;
-	protected $logger;
-	private $imageService;
-	private $encodingService;
+	private IRequest $request;
+	private SessionService $sessionService;
+	private DocumentService $documentService;
+	private LoggerInterface $logger;
+	private AttachmentService $attachmentService;
+	private EncodingService $encodingService;
+	private IL10N $l10n;
 
 	public function __construct(IRequest $request,
 								SessionService $sessionService,
 								DocumentService $documentService,
-								ImageService $imageService,
+								AttachmentService $attachmentService,
 								EncodingService $encodingService,
-								ILogger $logger) {
+								LoggerInterface $logger,
+								IL10N $l10n
+	) {
 		$this->request = $request;
 		$this->sessionService = $sessionService;
 		$this->documentService = $documentService;
 		$this->logger = $logger;
-		$this->imageService = $imageService;
+		$this->attachmentService = $attachmentService;
 		$this->encodingService = $encodingService;
+		$this->l10n = $l10n;
 	}
 
 	public function create($fileId = null, $filePath = null, $token = null, $guestName = null, bool $forceRecreate = false): DataResponse {
@@ -81,6 +89,8 @@ class ApiService {
 					$this->documentService->checkSharePermissions($token, Constants::PERMISSION_READ);
 				} catch (NotFoundException $e) {
 					return new DataResponse([], Http::STATUS_NOT_FOUND);
+				} catch (NotPermittedException $e) {
+					return new DataResponse($this->l10n->t('This file cannot be displayed as download is disabled by the share'), 404);
 				}
 			} elseif ($fileId) {
 				$file = $this->documentService->getFileById($fileId);
@@ -88,6 +98,17 @@ class ApiService {
 				return new DataResponse('No valid file argument provided', 500);
 			}
 
+			$storage = $file->getStorage();
+
+			// Block using text for disabled download internal shares
+			if ($storage->instanceOfStorage(SharedStorage::class)) {
+				/** @var IShare $share */
+				$share = $storage->getShare();
+				if ($share->getAttributes()->getAttribute('permissions', 'download') === false) {
+					return new DataResponse($this->l10n->t('This file cannot be displayed as download is disabled by the share'), 403);
+				}
+			}
+
 			$readOnly = $this->documentService->isReadOnly($file, $token);
 
 			$this->sessionService->removeInactiveSessions($file->getId());
@@ -101,7 +122,7 @@ class ApiService {
 
 			$document = $this->documentService->createDocument($file);
 		} catch (Exception $e) {
-			$this->logger->logException($e);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			return new DataResponse('Failed to create the document session', 500);
 		}
 
@@ -112,10 +133,10 @@ class ApiService {
 
 			$content = $this->encodingService->encodeToUtf8($content);
 			if ($content === null) {
-				$this->logger->log(ILogger::WARN, 'Failed to encode file to UTF8. File ID: ' . $file->getId());
+				$this->logger->warning('Failed to encode file to UTF8. File ID: ' . $file->getId());
 			}
 		} catch (NotFoundException $e) {
-			$this->logger->logException($e, ['level' => ILogger::INFO]);
+			$this->logger->info($e->getMessage(), ['exception' => $e]);
 			$content = null;
 		}
 
@@ -158,7 +179,7 @@ class ApiService {
 		if (count($activeSessions) === 0) {
 			try {
 				$this->documentService->resetDocument($documentId);
-				$this->imageService->cleanupAttachments($documentId);
+				$this->attachmentService->cleanupAttachments($documentId);
 			} catch (DocumentHasUnsavedChangesException $e) {
 			}
 		}
@@ -167,7 +188,7 @@ class ApiService {
 
 	/**
 	 * @throws NotFoundException
-	 * @throws \OCP\AppFramework\Db\DoesNotExistException
+	 * @throws DoesNotExistException
 	 */
 	public function push($documentId, $sessionId, $sessionToken, $version, $steps, $token = null): DataResponse {
 		$session = $this->sessionService->getSession($documentId, $sessionId, $sessionToken);
@@ -198,12 +219,12 @@ class ApiService {
 			$session = $this->sessionService->getSession($documentId, $sessionId, $sessionToken);
 			$file = $this->documentService->getFileForSession($session, $token);
 		} catch (NotFoundException $e) {
-			$this->logger->logException($e, ['level' => ILogger::INFO]);
+			$this->logger->info($e->getMessage(), ['exception' => $e]);
 			return new DataResponse([
 				'message' => 'File not found'
 			], 404);
 		} catch (DoesNotExistException $e) {
-			$this->logger->logException($e, ['level' => ILogger::INFO]);
+			$this->logger->info($e->getMessage(), ['exception' => $e]);
 			return new DataResponse([
 				'message' => 'Document no longer exists'
 			], 404);
@@ -220,7 +241,7 @@ class ApiService {
 		} catch (NotFoundException $e) {
 			return new DataResponse([], 404);
 		} catch (Exception $e) {
-			$this->logger->logException($e);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			return new DataResponse([
 				'message' => 'Failed to autosave document'
 			], 500);
@@ -230,16 +251,13 @@ class ApiService {
 	}
 
 	/**
-	 * @throws \OCP\AppFramework\Db\DoesNotExistException
+	 * @throws DoesNotExistException
 	 */
 	public function updateSession(int $documentId, int $sessionId, string $sessionToken, string $guestName): DataResponse {
 		if (!$this->sessionService->isValidSession($documentId, $sessionId, $sessionToken)) {
-			return new DataResponse([], 500);
+			return new DataResponse([], 403);
 		}
 
-		if ($guestName === '') {
-			return new DataResponse([ 'message' => 'A guest name needs to be provided'], 500);
-		}
 		return new DataResponse($this->sessionService->updateSession($documentId, $sessionId, $sessionToken, $guestName));
 	}
 }
