@@ -79,7 +79,7 @@ OC.L10N.register(
     "Custom background" : "Benutzerdefinierter Hintergrund",
     "Default background" : "Standardhintergrund",
     "Change color" : "Farbe ändern",
-    "Remove background" : "Hintergrund entfernen",
+    "No background" : "Kein Hintergrund",
     "Select a background from your files" : "Wählen Sie einen Hintergrund aus Ihren Dateien",
     "Theme selection is enforced" : "Designauswahl wird erzwungen",
     "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
