@@ -8,7 +8,7 @@ OC.L10N.register(
     "Weather status" : "Прогноз погоди",
     "Weather status in your dashboard" : "Статус погоди на вашій інформаційній панелі",
     "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Статус погоди інтегрований до застосунку з панеллю віджетів (Dashboard). Розташування користувача може визначатися автоматично або вручну. В застосунку показується прогноз на 6 годин.\nСтатус може показуватися й інших застосунках, як-от у \"Календарі\".",
-    "Detect location" : "Визначити місцезнаходження",
+    "Detect location" : "Визначити місце розташування",
     "Set custom address" : "Встановити власну адресу",
     "Favorites" : "Улюблене",
     "{temperature} {unit} clear sky later today" : "{temperature} {unit} ясне небо пізніше сьогодні",
@@ -40,9 +40,9 @@ OC.L10N.register(
     "You are not logged in." : "Ви не ввійшли до системи.",
     "There was an error getting the weather status information." : "Виникла помилка при отриманні інформації про стан погоди.",
     "No weather information found" : "Інформацію про погоду не знайдено",
-    "Location not found" : "Місцезнаходження не знайдено",
-    "There was an error setting the location address." : "Виникла помилка при встановленні адреси місцезнаходження.",
-    "There was an error setting the location." : "Під час встановлення місцезнаходження сталася помилка.",
+    "Location not found" : "Місце розташування не знайдено",
+    "There was an error setting the location address." : "Виникла помилка при встановленні адреси розташування.",
+    "There was an error setting the location." : "Під час встановлення місця розташування сталася помилка.",
     "There was an error saving the mode." : "Під час збереження режиму сталася помилка.",
     "There was an error using personal address." : "Під час використання особистої адреси сталася помилка.",
     "Set location for weather" : "Встановіть місце для погоди"
