@@ -54,11 +54,8 @@ OC.L10N.register(
     "Images" : "Изображения",
     "Office documents" : "Офисные документы",
     "PDF documents" : "PDF документы",
+    "Custom MIME type" : "Пользовательский тип MIME",
     "Custom mimetype" : "Пользовательский тип mime",
-    "Select a tag" : "Выберите метку",
-    "No results" : "Нет результатов",
-    "%s (invisible)" : "%s (невидимый)",
-    "%s (restricted)" : "%s (ограниченный)",
     "Please enter a valid time span" : "Введите верный диапазон",
     "Select a request URL" : "Выберите URL запроса",
     "Predefined URLs" : "Предопределенные URL",
@@ -114,6 +111,10 @@ OC.L10N.register(
     "Request user agent" : "Используемое приложение (user agent)",
     "User group membership" : "Участие в группе пользователей",
     "is member of" : "является участником",
-    "is not member of" : "не является участником"
+    "is not member of" : "не является участником",
+    "Select a tag" : "Выберите метку",
+    "No results" : "Нет результатов",
+    "%s (invisible)" : "%s (невидимый)",
+    "%s (restricted)" : "%s (ограниченный)"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
