@@ -30,7 +30,7 @@
 namespace OCA\WorkflowEngine;
 
 use Doctrine\DBAL\Exception;
-use OC\Cache\CappedMemoryCache;
+use OCP\Cache\CappedMemoryCache;
 use OCA\WorkflowEngine\AppInfo\Application;
 use OCA\WorkflowEngine\Check\FileMimeType;
 use OCA\WorkflowEngine\Check\FileName;
@@ -109,8 +109,8 @@ class Manager implements IManager {
 	/** @var ILogger */
 	protected $logger;
 
-	/** @var CappedMemoryCache */
-	protected $operationsByScope = [];
+	/** @var CappedMemoryCache<int[]> */
+	protected CappedMemoryCache $operationsByScope;
 
 	/** @var IUserSession */
 	protected $session;
@@ -373,10 +373,11 @@ class Manager implements IManager {
 		$qb->setParameters(['scope' => $scopeContext->getScope(), 'scopeId' => $scopeContext->getScopeId()]);
 		$result = $qb->execute();
 
-		$this->operationsByScope[$scopeContext->getHash()] = [];
+		$operations = [];
 		while (($opId = $result->fetchOne()) !== false) {
-			$this->operationsByScope[$scopeContext->getHash()][] = (int)$opId;
+			$operations[] = (int)$opId;
 		}
+		$this->operationsByScope[$scopeContext->getHash()] = $operations;
 		$result->closeCursor();
 
 		return in_array($id, $this->operationsByScope[$scopeContext->getHash()], true);
