@@ -92,7 +92,7 @@
 
 				if (hasWarnings) {
 					$el.find('.update-show-detailed').before(
-						$('<input type="button" class="update-continue" value="'+t('core', 'Continue to {productName}', OC.Update.options)+'">').on('click', function() {
+						$('<input type="button" class="primary" value="'+t('core', 'Continue to {productName}', OC.Update.options)+'">').on('click', function() {
 							window.location.reload();
 						})
 					);
