@@ -142,8 +142,6 @@ OC.L10N.register(
     "Your connection is not secure" : "اتصالك غير آمن",
     "Passwordless authentication is only available over a secure connection." : "المصادقة بدون كلمة مرور متاحة فقط عبر اتصال آمن.",
     "Reset password" : "تعديل كلمة السر",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "تم إرسال رسالة إعادة تعيين كلمة المرور إلى عنوان البريد الإلكتروني لهذا الحساب. إذا لم تستلمها ، فتحقق من مجلدات البريد الغير هام / غير المرغوب فيه أو اطلب المساعدة من المسؤول المحلي.",
-    "If it is not there ask your local administrator." : "إذا لم يكن هناك اسأل المسؤول التقني المحلي.",
     "Couldn't send reset email. Please contact your administrator." : "تعذر إرسال البريد الإلكتروني لإعادة التعيين. يرجى مراجعة المسؤول.",
     "Password cannot be changed. Please contact your administrator." : "كلمة المرور لا يمكن تغييرها. فضلاً تحدث مع المسؤول.",
     "Back to login" : "العودة إلى تسجيل الدخول",
@@ -179,7 +177,6 @@ OC.L10N.register(
     "Load more results" : " عرض المزيد من النتائج",
     "Search" : "البحث",
     "No results for {query}" : "لا يوجد ناتج لـ {query}",
-    "Press enter to start searching" : "اضغط على Enter لبدء البحث",
     "An error occurred while searching for {type}" : "حدث خطأ أثناء البحث عن {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength} أو أكثر للبحث","من فضلك ادخل أحرف {minSearchLength}  أو أكثر للبحث"],
     "Settings menu" : "قائمة الإعدادات",
@@ -318,6 +315,7 @@ OC.L10N.register(
     "Skip to main content" : "تخطّيه وانتقل إلى المحتوى الرئيسي",
     "Skip to navigation of app" : "تجاهل التنقل في التطبيق",
     "Get your own free account" : "احصل على حساب لك بالمجان",
+    "Go to %s" : "الإنتقال إلى %s",
     "Confirm your password" : "تأكيد كلمتك السرية",
     "Connect to your account" : "الاتصال بحسابك",
     "Please log in before granting %1$s access to your %2$s account." : "يرجى تسجيل الدخول قبل الحصول على اذن %1$s في حسابك %2$s.",
@@ -334,7 +332,6 @@ OC.L10N.register(
     "Email address" : "عنوان البريد الإلكتروني",
     "Password sent!" : "تم إرسال الكلمة السرية!",
     "You are not authorized to request a password for this share" : "لست مخولاً لطلب كلمة مرور لهذه المشاركة",
-    "Go to %s" : "الإنتقال إلى %s",
     "Two-factor authentication" : "المصادقة بخطوتين",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "تعزيز الآمان مفعل في حسابك. يرجى اختيار وسيلة ثانية للمصادقة:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "تعذر تحميل طريقة واحدة على الأقل من طرق المصادقة الثنائية الممكّنة. الرجاء الاتصال بالمسؤول الخاص بك.",
@@ -371,6 +368,8 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "إصدار المجتمع هذا من Nextcloud غير مدعوم والإشعارات الفورية غير متاحة.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: تحديث الجدول %s",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "لا يحتوي رأس HTTP \"{header}\" على \"{expected}\". يعد هذا خطرًا محتملاً على الأمان أو الخصوصية ، حيث يوصى بضبط هذا الإعداد وفقًا لذلك.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "تم إرسال رسالة إعادة تعيين كلمة المرور إلى عنوان البريد الإلكتروني لهذا الحساب. إذا لم تستلمها ، فتحقق من مجلدات البريد الغير هام / غير المرغوب فيه أو اطلب المساعدة من المسؤول المحلي.",
+    "If it is not there ask your local administrator." : "إذا لم يكن هناك اسأل المسؤول التقني المحلي.",
     "Collaboratively edit office documents." : "تحرير مستندات المكتب بشكل تعاوني.",
     "Local document editing back-end used by the Collabora Online app." : "خلفية تحرير المستندات المحلية المستخدمة بواسطة تطبيق Collabora Online.",
     "restricted" : "مُقيَّد",
@@ -381,6 +380,7 @@ OC.L10N.register(
     "More apps menu" : "المزيد من قائمة التطبيقات",
     "Contacts" : "جهات الإتصال",
     "Contacts menu" : "قائمة جهات الإتصال",
-    "Setup two-factor authentication" : "تعيين المصادقة بخطوتين"
+    "Setup two-factor authentication" : "تعيين المصادقة بخطوتين",
+    "Press enter to start searching" : "اضغط على Enter لبدء البحث"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
