@@ -39,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na tlačítko níže. Pokud jste o resetování hesla nežádali, tento e-mail ignorujte.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pokud chcete resetovat své heslo, klikněte na následující odkaz. Pokud jste o reset nežádali, tento e-mail ignorujte.",
     "Reset your password" : "Resetovat vaše heslo",
+    "No translation provider available" : "Není k dispozici žádný poskytovatel překladu",
+    "Could not detect language" : "Nepodařilo se zjistit jazyk",
+    "Unable to translate" : "Nedaří se přeložit",
     "Nextcloud Server" : "Server Nextcloud",
     "Some of your link shares have been removed" : "Některá vaše sdílení odkazem byla odstraněna",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kvůli chybě v zabezpečení bylo třeba odstranit některé z sdílení odkazem. Další informace viz odkaz.",
@@ -161,8 +164,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Vaše připojení není zabezpečené",
     "Passwordless authentication is only available over a secure connection." : "Ověření se bez hesla je k dispozici pouze přes zabezpečené připojení.",
     "Reset password" : "Resetovat heslo",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Na e-mailovou adresu, vedenou k tomuto účtu, byla odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
-    "If it is not there ask your local administrator." : "Pokud se tam nenachází, zeptejte se svého místního správce.",
     "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat e-mail pro změnu hesla. Obraťte se na správce.",
     "Password cannot be changed. Please contact your administrator." : "Heslo nelze změnit. Obraťte se na svého správce systému.",
     "Back to login" : "Zpět na přihlášení",
@@ -204,7 +205,6 @@ OC.L10N.register(
     "Load more results" : "Načíst další výsledky",
     "Search" : "Hledat",
     "No results for {query}" : "Pro {query} nic nenalezeno",
-    "Press enter to start searching" : "Vyhledávání zahájíte stisknutím klávesy Enter",
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znak","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaků","Aby bylo možné vyhledávat, zadejte alespoň {minSearchLength} znaky"],
     "This browser is not supported" : "Tento prohlížeč není podporován",
@@ -356,7 +356,7 @@ OC.L10N.register(
     "Skip to main content" : "Přeskočit a přejít k hlavnímu obsahu",
     "Skip to navigation of app" : "Přeskočit na navigaci aplikace",
     "Get your own free account" : "Získejte svůj vlastní účet zdarma",
-    "%s homepage" : "Domovská stránka %s",
+    "Go to %s" : "Jít na %s",
     "Confirm your password" : "Potvrdit heslo",
     "Connect to your account" : "Propojit s vaším účtem",
     "Please log in before granting %1$s access to your %2$s account." : "Přihlaste se abyste mohli %1$s udělit přístup k vašemu %2$s účtu.",
@@ -376,7 +376,6 @@ OC.L10N.register(
     "Email address" : "E-mailová adresa",
     "Password sent!" : "Heslo zasláno!",
     "You are not authorized to request a password for this share" : "Nejste oprávněni vyžádat si heslo pro toto sdílení",
-    "Go to %s" : "Jít na %s",
     "Two-factor authentication" : "Dvoufaktorové přihlášení",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Bylo zapnuto vylepšené zabezpečení pro tento účet. Zvolte druhý faktor pro ověřování:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedaří se načíst ani jednu ze zapnutých metod dvouúrovňového ověřování. Obraťte se na svého správce.",
@@ -415,6 +414,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Toto je nepodporované komunitní sestavení Nextcloud. Vzhledem k velikosti této instance, není garantován výkon, spolehlivost, ani škálovatelnost. Aby se zabránilo přetěžování našich služeb, které jsou zdarma, okamžitá oznámení byla vypnuta. Zjistěte více o výhodách Nextcloud pro podniky na nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 je posledním vydáním, které podporuje PHP 7.3. Nextcloud 24 vyžaduje přinejmenším PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP hlavička „{header}“ neobsahuje „{expected}“. To značí možné ohrožení bezpečnosti a soukromí a je doporučeno toto nastavení upravit.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Na e-mailovou adresu, vedenou k tomuto účtu, byla odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, podívejte se také do složek s nevyžádanou poštou (spam) a/nebo požádejte svého místního správce o pomoc.",
+    "If it is not there ask your local administrator." : "Pokud se tam nenachází, zeptejte se svého místního správce.",
     "Collaboratively edit office documents." : "Spolupracujte na kancelářských dokumentech s ostatními souběžně je upravujícími uživateli.",
     "Local document editing back-end used by the Collabora Online app." : "Podpůrná vrstva pro místní úpravu dokumentů používána aplikací Collabora Online.",
     "restricted" : "omezeno",
@@ -426,6 +427,8 @@ OC.L10N.register(
     "Contacts" : "Kontakty",
     "Contacts menu" : "Nabídka kontaktů",
     "Setup two-factor authentication" : "Nastavit dvoufázové ověřování",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Zdá se, že provozujete 32bitovou verzi PHP. Aby správně fungoval, potřebuje Nextcloud 64bit. Přejděte na 64bit instalaci operačního systému a PHP! Bližší podrobnosti naleznete {linkstart}na stránce v dokumentaci ↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Zdá se, že provozujete 32bitovou verzi PHP. Aby správně fungoval, potřebuje Nextcloud 64bit. Přejděte na 64bit instalaci operačního systému a PHP! Bližší podrobnosti naleznete {linkstart}na stránce v dokumentaci ↗{linkend}.",
+    "Press enter to start searching" : "Vyhledávání zahájíte stisknutím klávesy Enter",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Zaktualizujte z příkazového řádku, protože aktualizování z webového prohlížeče je vypnuté ve vašem config.php."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
