@@ -39,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following button to reset your password. If you have not requested the password reset, then ignore this email.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Click the following link to reset your password. If you have not requested the password reset, then ignore this email.",
     "Reset your password" : "Reset your password",
+    "No translation provider available" : "No translation provider available",
+    "Could not detect language" : "Could not detect language",
+    "Unable to translate" : "Unable to translate",
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Some of your link shares have been removed",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Due to a security bug we had to remove some of your link shares. Please see the link for more information.",
@@ -51,7 +54,7 @@ OC.L10N.register(
     "Repair info:" : "Repair info:",
     "Repair warning:" : "Repair warning:",
     "Repair error:" : "Repair error:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Please use the command line updater because updating via the browser is disabled in your config.php.",
     "Turned on maintenance mode" : "Turned on maintenance mode",
     "Turned off maintenance mode" : "Turned off maintenance mode",
     "Maintenance mode is kept active" : "Maintenance mode is kept active",
@@ -161,8 +164,7 @@ OC.L10N.register(
     "Your connection is not secure" : "Your connection is not secure",
     "Passwordless authentication is only available over a secure connection." : "Passwordless authentication is only available over a secure connection.",
     "Reset password" : "Reset password",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help.",
-    "If it is not there ask your local administrator." : "If it is not there ask your local administrator.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
     "Couldn't send reset email. Please contact your administrator." : "Couldn't send reset email. Please contact your administrator.",
     "Password cannot be changed. Please contact your administrator." : "Password cannot be changed. Please contact your administrator.",
     "Back to login" : "Back to login",
@@ -184,6 +186,7 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simple email app nicely integrated with Files, Contacts and Calendar.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
+    "Distraction free note taking app." : "Distraction free note taking app.",
     "Search contacts" : "Search contacts",
     "Forgot password?" : "Forgot password?",
     "Log in with a device" : "Log in with a device",
@@ -198,12 +201,11 @@ OC.L10N.register(
     "Reset search" : "Reset search",
     "Start search" : "Start search",
     "Search for {name} only" : "Search for {name} only",
-    "No results for {query}" : "No results for {query}",
-    "Press enter to start searching" : "Press enter to start searching",
     "Start typing to search" : "Start typing to search",
     "Loading more results …" : "Loading more results …",
     "Load more results" : "Load more results",
     "Search" : "Search",
+    "No results for {query}" : "No results for {query}",
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
     "This browser is not supported" : "This browser is not supported",
@@ -215,6 +217,7 @@ OC.L10N.register(
     "Settings menu" : "Settings menu",
     "Search {types} …" : "Search {types} …",
     "Settings" : "Settings",
+    "Avatar of {fullName}" : "Avatar of {fullName}",
     "Could not load your contacts" : "Could not load your contacts",
     "Search contacts …" : "Search contacts …",
     "No contacts found" : "No contacts found",
@@ -256,6 +259,7 @@ OC.L10N.register(
     "Show list view" : "Show list view",
     "Show grid view" : "Show grid view",
     "Pending" : "Pending",
+    "Home" : "Home",
     "Copy to {folder}" : "Copy to {folder}",
     "Move to {folder}" : "Move to {folder}",
     "Saving …" : "Saving …",
@@ -284,6 +288,7 @@ OC.L10N.register(
     "Strong password" : "Strong password",
     "No action available" : "No action available",
     "Error fetching contact actions" : "Error fetching contact actions",
+    "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
     "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
     "Restricted" : "Restricted",
     "Invisible" : "Invisible",
@@ -352,9 +357,8 @@ OC.L10N.register(
     "Skip to main content" : "Skip to main content",
     "Skip to navigation of app" : "Skip to navigation of app",
     "Get your own free account" : "Get your own free account",
-    "%s homepage" : "%s homepage",
+    "Go to %s" : "Go to %s",
     "Confirm your password" : "Confirm your password",
-    "%s's homepage" : "%s's homepage",
     "Connect to your account" : "Connect to your account",
     "Please log in before granting %1$s access to your %2$s account." : "Please log in before granting %1$s access to your %2$s account.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator.",
@@ -373,7 +377,6 @@ OC.L10N.register(
     "Email address" : "Email address",
     "Password sent!" : "Password sent!",
     "You are not authorized to request a password for this share" : "You are not authorised to request a password for this share",
-    "Go to %s" : "Go to %s",
     "Two-factor authentication" : "Two-factor authentication",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Enhanced security is enabled for your account. Choose a second factor for authentication:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Could not load at least one of your enabled two-factor auth methods. Please contact your admin.",
@@ -399,6 +402,7 @@ OC.L10N.register(
     "Detailed logs" : "Detailed logs",
     "Update needed" : "Update needed",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Please use the command line updater because automatic updating is disabled in the config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure.",
     "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
@@ -411,6 +415,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help.",
+    "If it is not there ask your local administrator." : "If it is not there ask your local administrator.",
     "Collaboratively edit office documents." : "Collaboratively edit office documents.",
     "Local document editing back-end used by the Collabora Online app." : "Local document editing back-end used by the Collabora Online app.",
     "restricted" : "restricted",
@@ -422,6 +428,8 @@ OC.L10N.register(
     "Contacts" : "Contacts",
     "Contacts menu" : "Contacts menu",
     "Setup two-factor authentication" : "Setup two-factor authentication",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}.",
+    "Press enter to start searching" : "Press enter to start searching",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Please use the command line updater because updating via browser is disabled in your config.php."
 },
 "nplurals=2; plural=(n != 1);");
