@@ -16,13 +16,14 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "No image or file provided" : "No se especificó un archivo o imagen",
     "Unknown filetype" : "Tipo de archivo desconocido",
-    "Invalid image" : "Imagen inválida",
     "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
+    "Invalid image" : "Imagen inválida",
     "No temporary profile picture available, try again" : "No hay una imagen de perfil temporal disponible, por favor inténtalo de nuevo",
     "No crop data provided" : "No se han proporcionado datos del recorte",
     "No valid crop data provided" : "No se han proporcionado datos válidos del recorte",
     "Crop is not square" : "El recorte no es cuadrado",
     "State token does not match" : "La ficha de estado no corresponde",
+    "Login" : "Iniciar sesión",
     "Password reset is disabled" : "Restablecer contraseña se encuentra deshabilitado",
     "%s password reset" : "%s restablecer la contraseña",
     "Password reset" : "Restablecer contraseña",
@@ -31,8 +32,6 @@ OC.L10N.register(
     "Reset your password" : "Restablecer tu contraseña",
     "Preparing update" : "Preparando actualización",
     "[%d / %d]: %s" : "[%d / %d]: %s ",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
-    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
     "Turned on maintenance mode" : "Modo mantenimiento activado",
     "Turned off maintenance mode" : "Modo mantenimiento desactivado",
     "Maintenance mode is kept active" : "El modo mantenimiento sigue activo",
@@ -63,34 +62,36 @@ OC.L10N.register(
     "Hello {name}" : "Hola {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son los resultados de tu búsqueda <script>alert(1)</script></strong>",
     "new" : "nuevo",
-    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos"],
+    "_download %n file_::_download %n files_" : ["Descargar %n archivos","Descargar %n archivos","Descargar %n archivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, abandonar esta página puede interrumpir el proceso en algunos ambientes. ",
     "Update to {version}" : "Actualizar a {version}",
     "An error occurred." : "Se presentó un error.",
     "Please reload the page." : "Por favor vuelve a cargar la página.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización no fue exitosa. Para más información <a href=\"{url}\">consulta nuestro comentario  en el foro </a> que cubre este tema. ",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
+    "More apps" : "Más aplicaciones",
     "Log in" : "Ingresar",
     "Logging in …" : "Iniciando sesión ...",
     "Server side authentication failed!" : "¡Falló la autenticación del lado del servidor!",
     "Please contact your administrator." : "Por favor contacta al administrador.",
     "An internal error occurred." : "Se presentó un error interno.",
     "Please try again or contact your administrator." : "Por favor vuelve a intentarlo o contacta a tu adminsitrador. ",
-    "Username or email" : "Usuario o correo electrónico",
     "Password" : "Contraseña",
     "Wrong username or password." : "Usuario o contraseña equivocado. ",
     "User disabled" : "Usuario deshabilitado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Hemos detectado múltiples intentos de inicio de sesión desde tu IP. Por lo tanto tu siguiente incio de sesión se retrasará hasta 30 segundos. ",
+    "Username or email" : "Usuario o correo electrónico",
     "Reset password" : "Restablecer contraseña",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
     "Back to login" : "Regresar al inicio de sesión",
     "New password" : "Nueva contraseña",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
-    "Cancel" : "Cancelar",
+    "Skip" : "Omitir",
     "Forgot password?" : "¿Olvidaste tu contraseña?",
     "Back" : "Atrás",
     "Reset search" : "Reestablecer búsqueda",
     "Search" : "Buscar",
+    "Settings menu" : "Menú de Configuraciones",
     "Settings" : "Configuraciones ",
     "Could not load your contacts" : "No fue posible cargar tus contactos",
     "Search contacts …" : "Buscar contactos ...",
@@ -117,26 +118,29 @@ OC.L10N.register(
     "OK" : "OK",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
     "read-only" : "sólo-lectura",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo"],
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos en el archivo","{count} conflictos en el archivo"],
     "One file conflict" : "Un conflicto en el archivo",
     "New Files" : "Archivos Nuevos",
     "Already existing files" : "Archivos ya existentes",
     "Which files do you want to keep?" : "¿Cuáles archivos deseas mantener?",
     "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, se le agregará un número al nombre del archivo copiado.",
+    "Cancel" : "Cancelar",
     "Continue" : "Continuar",
     "(all selected)" : "(todos seleccionados)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Se presentó un error al cargar la plantilla de existe archivo ",
     "Pending" : "Pendiente",
+    "Home" : "Inicio",
     "Copy to {folder}" : "Copiar a {folder}",
     "Move to {folder}" : "Mover a {folder}",
+    "Saving …" : "Saving …",
     "Authentication required" : "Se requiere autenticación",
     "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
     "Confirm" : "Confirmar",
     "Failed to authenticate, try again" : "Falla en la autenticación, por favor reintentalo",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión con el servidor",
-    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos"],
+    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Se presentó un error al cargar la página, recargando en %n segundo","Se presentó un error al cargar la página, recargando en %n segundos","Se presentó un error al cargar la página, recargando en %n segundos"],
     "Hide details" : "Ocultar detalles",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
@@ -146,8 +150,8 @@ OC.L10N.register(
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Non-existing tag #{tag}" : "Etiqueta #{tag} no-existente",
-    "restricted" : "restringido",
-    "invisible" : "invisible",
+    "Restricted" : "Restringido",
+    "Invisible" : "Invisible",
     "Delete" : "Borrar",
     "Rename" : "Renombrar",
     "Collaborative tags" : "Etiquetas colaborativas",
@@ -158,7 +162,7 @@ OC.L10N.register(
     "Admin" : "Administración",
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
-    "File not found" : "Archivo no encontrado",
+    "Page not found" : "Página no encontrada",
     "Error" : "Error",
     "Previous" : "Previo",
     "Internal Server Error" : "Error interno del servidor",
@@ -195,12 +199,7 @@ OC.L10N.register(
     "Need help?" : "¿Necesitas ayuda?",
     "See the documentation" : "Ver la documentación",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
-    "More apps" : "Más aplicaciones",
-    "More" : "Más",
-    "More apps menu" : "Menú de más aplicaciones",
-    "Contacts" : "Contactos",
-    "Contacts menu" : "Menú de Contactos",
-    "Settings menu" : "Menú de Configuraciones",
+    "Go to %s" : "Ir a %s",
     "Confirm your password" : "Confirma tu contraseña",
     "Connect to your account" : "Conectate a tu cuenta",
     "App token" : "Ficha de la aplicación",
@@ -208,8 +207,6 @@ OC.L10N.register(
     "Alternative log in using app token" : "Inicio de sesión alternativo usando una ficha de aplicación",
     "Account access" : "Acceo de cuenta",
     "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
-    "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "Go to %s" : "Ir a %s",
     "Two-factor authentication" : "Autenticación de dos-factores",
     "Use backup code" : "Usar código de respaldo",
     "Error while validating your second factor" : "Se presentó un error al validar tu segundo factor",
@@ -224,12 +221,19 @@ OC.L10N.register(
     "Detailed logs" : "Bitácoras detalladas",
     "Update needed" : "Se requiere de una actualización",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Favor de usar el actualizador desde la línea de comandos ya que tu instancia cuenta con más de 50 usuarios.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Por favor usa el actualizador de línea de comandos ya que el actualizador automático se encuentra deshabilitado en config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para más ayuda, por favor consulta la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentación</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Estoy conciente de que si continúo haciendo la actualización vía web, la interfaz de usuario corre el riesgo de que el tiempo de la solicitud expire y cause pérdida de datos, pero cuento con un respaldo y sé como restaurar mi instancia en caso de una falla. ",
     "Upgrade via web on my own risk" : "Actualizar vía Web bajo mi propio riesgo",
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia %s se encuentra actualmente en modo mantenimiento, que podría tomar algo de tiempo. ",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacta a tu administrador del sistema si este mensaje persiste o se presentó de manera inesperada.",
-    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "El servidor no cuenta con una conexión a Internet: No se pudieron alcanzar múltiples endpoints. Esto significa que algunas características como montar almacenamiento externo, notificaciones de actualizaciones o instalación de aplicaciones de 3ros no funcionarán correctamente. Acceder archivos de forma remota y el envío de de notificaciones por correo electrónico puede que no funcionen tampoco. Establece una conexión desde este servidor a Internet para aprovechar todas las funcionalidades.",
-    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Probablemente tu directorio de datos y archivos sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda ampliamente que configures tu servidor web para que el directorio de datos no sea accesible, o bien, que muevas el directorio de datos fuera del directorio raíz del servidor web."
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Verificando tabla %s",
+    "restricted" : "restringido",
+    "invisible" : "invisible",
+    "File not found" : "Archivo no encontrado",
+    "More" : "Más",
+    "More apps menu" : "Menú de más aplicaciones",
+    "Contacts" : "Contactos",
+    "Contacts menu" : "Menú de Contactos"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
