@@ -49,6 +49,7 @@ OC.L10N.register(
     "Repair info:" : "Korjaustiedot:",
     "Repair warning:" : "Korjausvaroitus:",
     "Repair error:" : "Korjausvirhe:",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Käytä komentorivipäivitintä, koska päivitys selainkäyttöliittymällä on estetty config.php-asetustiedostossa.",
     "Turned on maintenance mode" : "Siirrytty huoltotilaan",
     "Turned off maintenance mode" : "Poistuttu huoltotilasta",
     "Maintenance mode is kept active" : "Huoltotila pidetään aktiivisena",
@@ -69,12 +70,16 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tietokantaasi ei suoriteta \"READ COMMITTED\"-transaktioeristystasolla. Tämä saattaa aiheuttaa ongelmia, kun useita toimintoja suoritetaan rinnakkaisesti.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHP \"fileinfo\" moduuli puuttuu. Moduulin käyttöönottaminen on vahvasti suositeltua paremman MIME tyyppien tunnistuksen saavuttamiseksi.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Cron-työtä ei voitu suorittaa komentorivin kautta. Seuraavat tekniset virheet havaittiin:",
+    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP:n OPcache-moduulin asetukset eivät ole kunnossa. Lue {linkstart}dokumentaatio ↗{linkend} saadaksesi lisätietoja.",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Puuttuva indeksi \"{indexName}\" taulussa \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Tietokannasta puuttuu indeksejä. Suuriin tauluihin indeksien lisääminen saattaa kestää kauan, ja sen vuoksi indeksejä ei lisätty automaattisesti. Suorita \"occ db:add-missing-indices\" lisätäksesi puuttuvat indeksit manuaalisesti samalla, kun instanssi pysyy käynnissä. Kun indeksit on lisätty, kyselyt kyseisiin tauluihin ovat yleensä huomattavasti aiempaa nopeampia.",
     "Missing primary key on table \"{tableName}\"." : "Primary key puuttuu taulusta \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Tietokannasta puuttuu primääriavaimia. Suuriin tauluihin primääriavainten lisääminen saattaa kestää kauan, ja sen vuoksi primääriavaimia ei lisätty automaattisesti. Suorita \"occ db:add-missing-primary-keys\" lisätäksesi puuttuvat primääriavaimet manuaalisesti samalla, kun instanssi pysyy käynnissä.",
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Valinnainen sarake \"{columnName}\" puuttuu taulusta \"{tableName}\".",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Tästä instanssista puuttuu joitain suositeltuja PHP-moduuleja. Nykyistä paremman suorituskyvyn ja yhteensopivuuden vuoksi kyseisten moduulien asentaminen on erittäin suositeltavaa.",
+    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP-moduulit \"gmp\" ja/tai \"bcmath\" eivät ole käytössä. Jos käytät WebAuthn-todennusta (ei salasanaa), nämä moduulit vaaditaan.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Palvelimen php-imagick-moduulissa ei ole SVG-tukea. Parempaa yhteensopivuutta varten sen asentaminen on suositeltua.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite on parhaillaan käytössä tietokantaratkaisuna. Suuria asennuksia varten suosittelemme vaihtamaan toiseen tietokantaratkaisuun.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Tämä on suositeltavaa erityisesti silloin, kun työpöytäsovellusta käytetään tiedostojen synkronointiin.",
@@ -124,8 +129,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Yhteytesi ei ole turvallinen",
     "Passwordless authentication is only available over a secure connection." : "Tunnistautuminen ilman salasanaa on mahdollista vain salattua yhteyttä käyttäessä.",
     "Reset password" : "Palauta salasana",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Salasanan nollausviesti on lähetetty käyttäjätilin sähköpostiin. Jos et vastaanota sähköpostia, tarkista roskapostikansio tai pyydä apua järjestelmävalvojaltasi.",
-    "If it is not there ask your local administrator." : "Jos se ei ole siellä, niin pyydä järjestelmänvalvojaltasi.",
     "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
     "Password cannot be changed. Please contact your administrator." : "Salasanaa ei voi vaihtaa. Ole yhteydessä ylläpitäjään.",
     "Back to login" : "Palaa kirjautumiseen",
@@ -165,7 +168,6 @@ OC.L10N.register(
     "Load more results" : "Lataa lisää tuloksia",
     "Search" : "Etsi",
     "No results for {query}" : "Ei tuloksia haulle {query}",
-    "Press enter to start searching" : "Paina enter aloittaaksesi haun",
     "An error occurred while searching for {type}" : "Haettaessa tyyppiä {type} tapahtui virhe.",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Kirjoita vähintään {minSearchLength} merkki etsiäksesi","Kirjoita vähintään {minSearchLength} merkkiä etsiäksesi"],
     "This browser is not supported" : "Tämä selain ei ole tuettu",
@@ -248,6 +250,7 @@ OC.L10N.register(
     "Strong password" : "Vahva salasana",
     "No action available" : "Toimintoa ei saatavilla",
     "Error fetching contact actions" : "Virhe yhteystiedon toimintojen haussa",
+    "Close \"{dialogTitle}\" dialog" : "Sulje \"{dialogTitle}\"-ikkuna",
     "Non-existing tag #{tag}" : "Ei olemassa oleva tunniste #{tag}",
     "Restricted" : "Rajoitettu",
     "Invisible" : "Näkymätön",
@@ -316,6 +319,7 @@ OC.L10N.register(
     "Skip to main content" : "Siirry pääsisältöön",
     "Skip to navigation of app" : "Hyppää sovelluksen navigointiin.",
     "Get your own free account" : "Hanki ilmainen tili itsellesi",
+    "Go to %s" : "Siirry %s§",
     "Confirm your password" : "Vahvista salasanasi",
     "Connect to your account" : "Yhdistä tiliisi",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Jos et ole asentamassa uutta laitetta tai sovellusta, joku yrittää huijata sinut antamaan käyttöoikeudet tietoihisi. Tässä tapauksessa älä jatka, ota yhteys järjestelmänvalvojaan.",
@@ -333,7 +337,6 @@ OC.L10N.register(
     "Email address" : "Sähköpostiosoite",
     "Password sent!" : "Salasana lähetetty!",
     "You are not authorized to request a password for this share" : "Sinulla ei ole valtuutta pyytää salasanaa tähän jakoon",
-    "Go to %s" : "Siirry %s§",
     "Two-factor authentication" : "Kaksivaiheinen tunnistautuminen",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tilisi tietoturvatasoa on korotettu. Käytä kaksivaiheista tunnistautumista:",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Kaksivaiheinen tunnistautuminen on pakotettu, mutta sitä ei ole määritelty tilillesi. Ole yhteydessä ylläpitoon saadaksesi apua.",
@@ -368,6 +371,8 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
     "[%d / %d]: Checking table %s" : "[%d / %d]: Tarkistetaan taulua %s",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 on viimeinen julkaiusu, joka tukee PHP:n versiota 7.3. Nextcloud 24 vaatii vähintään PHP:n version 7.4.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Salasanan nollausviesti on lähetetty käyttäjätilin sähköpostiin. Jos et vastaanota sähköpostia, tarkista roskapostikansio tai pyydä apua järjestelmävalvojaltasi.",
+    "If it is not there ask your local administrator." : "Jos se ei ole siellä, niin pyydä järjestelmänvalvojaltasi.",
     "Collaboratively edit office documents." : "Muokkaa toimistodokumentteja yhteistyössä.",
     "Local document editing back-end used by the Collabora Online app." : "Collabora Online-sovelluksen käyttämä taustasovellus paikalliseen dokumenttien muokkaamiseen.",
     "restricted" : "rajoitettu",
@@ -378,6 +383,8 @@ OC.L10N.register(
     "More apps menu" : "Lisäsovellusvalikko",
     "Contacts" : "Yhteystiedot",
     "Contacts menu" : "Yhteystietovalikko",
-    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen"
+    "Setup two-factor authentication" : "Määritä kaksivaiheinen tunnistautuminen",
+    "Press enter to start searching" : "Paina enter aloittaaksesi haun",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Käytä komentorivipäivitintä, koska päivitys selainkäyttöliittymällä on estetty config.php-asetustiedostossa."
 },
 "nplurals=2; plural=(n != 1);");
