@@ -161,8 +161,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Votre connexion n'est pas sécurisée",
     "Passwordless authentication is only available over a secure connection." : "L'authentification sans mot de passe n'est possible qu'au travers d'une connexion sécurisée.",
     "Reset password" : "Réinitialiser le mot de passe",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Un message de réinitialisation de votre mot de passe a été envoyé à l'adresse e-mail renseignée pour ce compte. Si vous ne le recevez pas, veuillez vérifier dans votre dossier spam ou demander de l'aide à l'administrateur de cette instance.",
-    "If it is not there ask your local administrator." : "Si ce n'est pas le cas, veuillez contacter votre administrateur.",
     "Couldn't send reset email. Please contact your administrator." : "Impossible d'envoyer l'e-mail de réinitialisation. Veuillez contacter votre administrateur.",
     "Password cannot be changed. Please contact your administrator." : "Le mot de passe ne pas être modifié. Veuillez contacter votre administrateur.",
     "Back to login" : "Retour à la page de connexion",
@@ -191,7 +189,7 @@ OC.L10N.register(
     "Back" : "Retour",
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
     "Edit Profile" : "Modifier le profil",
-    "The headline and about sections will show up here" : "Le titre et la section \"A propos\" apparaîtront ici",
+    "The headline and about sections will show up here" : "Le titre et la section \"À propos\" apparaîtront ici",
     "You have not added any info yet" : "Vous n'avez pas ajouté d'informations pour le moment",
     "{user} has not added any info yet" : "{user} n'a pas ajouté d'informations pour le moment",
     "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
@@ -204,7 +202,6 @@ OC.L10N.register(
     "Load more results" : "Charger plus de résultats",
     "Search" : "Rechercher",
     "No results for {query}" : "Aucun résultat pour {query}",
-    "Press enter to start searching" : "Appuyez sur Entrée pour démarrer la recherche",
     "An error occurred while searching for {type}" : "Une erreur s'est produite lors de la recherche de {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
     "This browser is not supported" : "Ce navigateur n'est pas supporté",
@@ -356,7 +353,7 @@ OC.L10N.register(
     "Skip to main content" : "Passer au contenu principal",
     "Skip to navigation of app" : "Passer à la navigation d'application",
     "Get your own free account" : "Obtenez votre compte personnel gratuit",
-    "%s homepage" : "Page d'accueil de %s",
+    "Go to %s" : "Aller à %s",
     "Confirm your password" : "Confirmer votre mot de passe",
     "Connect to your account" : "Connectez vous à votre compte",
     "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
@@ -376,7 +373,6 @@ OC.L10N.register(
     "Email address" : "Adresse e-mail",
     "Password sent!" : "Mot de passe envoyé !",
     "You are not authorized to request a password for this share" : "Vous n'êtes pas autorisé à demander un mot de passe pour ce partage",
-    "Go to %s" : "Aller à %s",
     "Two-factor authentication" : "Second facteur d'authentification",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sécurité renforcée est activée pour votre compte. Choisissez un second facteur pour l'authentification :",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossible de charger au moins l'une de vos méthodes activées d'authentification à deux facteurs . Veuillez contacter votre administrateur.",
@@ -415,6 +411,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Il s'agit de la version communautaire non prise en charge de Nextcloud. Compte tenu de la taille de cette instance, les performances, la fiabilité et l'extensibilité ne peuvent être garanties. Les notifications push ont été désactivées pour éviter de surcharger notre service gratuit. Apprenez-en plus sur les avantages de Nextcloud Enterprise sur nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 est la dernière version prenant en charge PHP 7.3. Nextcloud 24 nécessite au moins PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "L'en-tête HTTP \"{header}\" ne contient pas \"{expected}\". Ceci est un risque potentiel pour la sécurité ou la vie privée, et il est recommandé d'ajuster ce paramètre en conséquence.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Un message de réinitialisation de votre mot de passe a été envoyé à l'adresse e-mail renseignée pour ce compte. Si vous ne le recevez pas, veuillez vérifier dans votre dossier spam ou demander de l'aide à l'administrateur de cette instance.",
+    "If it is not there ask your local administrator." : "Si ce n'est pas le cas, veuillez contacter votre administrateur.",
     "Collaboratively edit office documents." : "Modifier des documents de manière collaborative.",
     "Local document editing back-end used by the Collabora Online app." : "Moteur d'édition de document local utilisé par l'application Collabora Online.",
     "restricted" : "Restreint",
@@ -426,6 +424,8 @@ OC.L10N.register(
     "Contacts" : "Contacts",
     "Contacts menu" : "Menu des contacts",
     "Setup two-factor authentication" : "Paramétrer l'authentification à double facteur",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Il semble que vous utilisez une version 32-bits de PHP. Nextcloud nécessite une version 64-bits pour bien fonctionner. Merci de mettre à niveau votre système d'exploitation et PHP en 64-bits. Pour plus de détails consultez {linkstart}the documentation page about this ↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Il semble que vous utilisez une version 32-bits de PHP. Nextcloud nécessite une version 64-bits pour bien fonctionner. Merci de mettre à niveau votre système d'exploitation et PHP en 64-bits. Pour plus de détails consultez {linkstart}the documentation page about this ↗{linkend}.",
+    "Press enter to start searching" : "Appuyez sur Entrée pour démarrer la recherche",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Veuillez utiliser la mise à jour en ligne de commande, car la mise à jour via le navigateur est désactivée dans votre fichier config.php."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
