@@ -39,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti gombra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Kattintson a lenti hivatkozásra a jelszava visszaállításához. Ha ezt nem Ön kérte, akkor hagyja figyelmen kívül ezt a levelet.",
     "Reset your password" : "Jelszó visszaállítása",
+    "No translation provider available" : "Nem érhető el fordítási szolgáltató",
+    "Could not detect language" : "Nem sikerült észlelni a nyelvet",
+    "Unable to translate" : "Nem fordítható le",
     "Nextcloud Server" : "Nextcloud kiszolgáló",
     "Some of your link shares have been removed" : "Néhány megosztási hivatkozása eltávolításra került",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Egy biztonsági hiba miatt el kellett távolítsunk néhány megosztási hivatkozását. További információkért lásd a lenti hivatkozást.",
@@ -51,6 +54,7 @@ OC.L10N.register(
     "Repair info:" : "Javítási információ:",
     "Repair warning:" : "Javítási figyelmeztetés:",
     "Repair error:" : "Javítási hiba:",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Használja a parancssoros frissítőt, mert a frissítés ki van kapcsolva a config.php fájlban.",
     "Turned on maintenance mode" : "Karbantartási mód bekapcsolva",
     "Turned off maintenance mode" : "Karbantartási mód kikapcsolva",
     "Maintenance mode is kept active" : "Karbantartási mód aktiválva maradt",
@@ -160,8 +164,7 @@ OC.L10N.register(
     "Your connection is not secure" : "A kapcsolat nem biztonságos",
     "Passwordless authentication is only available over a secure connection." : "A jelszó nélküli hitelesítés csak biztonságos kapcsolaton keresztül érhető el.",
     "Reset password" : "Jelszó-visszaállítás",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Egy jelszó visszaállítási e-mail lett küldve a fiók e-mail-címére. Ha nem kapta meg, akkor ellenőrizze a levélszemét mappát, vagy kérje a helyi rendszergazda segítségét.",
-    "If it is not there ask your local administrator." : "Ha nincs ott, akkor kérdezze a helyi rendszergazdát.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ha a fiók létezik, akkor egy jelszó-visszaállítási üzenet lett küldve az e-mail-címére. Ha nem kapja meg, akkor ellenőrizze az e-mail-címet és a fióknevet, nézze meg a levélszemét mappáját vagy kérje a helyi rendszergazda segítségét.",
     "Couldn't send reset email. Please contact your administrator." : "Nem küldhető visszaállítási e-mail. Lépjen kapcsolatba a rendszergazdával.",
     "Password cannot be changed. Please contact your administrator." : "A jelszó nem módosítható. Lépjen kapcsolatba a rendszergazdával.",
     "Back to login" : "Vissza a bejelentkezéshez",
@@ -183,6 +186,7 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Egyszerű e-mail alkalmazás, amely szépen integrálódik a Fájlok, Névjegyek és Naptár alkalmazásba.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Csevegés, videóhívások, képernyőmegosztás, online megbeszélések és webes konferencia – a böngészőjében és mobilalkalmazásokkal.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Közösen szerkeszthető dokumentumok, táblázatok és bemutatók, a Collabora Online-ra építve.",
+    "Distraction free note taking app." : "Figyelemelterelés nélküli jegyzetelési alkalmazás.",
     "Search contacts" : "Névjegyek keresése",
     "Forgot password?" : "Elfelejtett jelszó?",
     "Log in with a device" : "Bejelentkezés eszközzel",
@@ -202,7 +206,6 @@ OC.L10N.register(
     "Load more results" : "További találatok betöltése",
     "Search" : "Keresés",
     "No results for {query}" : "Nincs találat a következőre: {query}",
-    "Press enter to start searching" : "A keresés indításához nyomjon Entert",
     "An error occurred while searching for {type}" : "Hiba történt a(z) {type} keresése sorá",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["A kereséshez írjon be a legalább {minSearchLength} karaktert","A kereséshez írjon be a legalább {minSearchLength} karaktert"],
     "This browser is not supported" : "Ez a böngésző nem támogatott.",
@@ -214,6 +217,7 @@ OC.L10N.register(
     "Settings menu" : "Beállítások menü",
     "Search {types} …" : "{types} keresése…",
     "Settings" : "Beállítások",
+    "Avatar of {fullName}" : "{fullName} profilképe",
     "Could not load your contacts" : "Nem lehet betölteni a névjegyeit",
     "Search contacts …" : "Névjegyek keresése…",
     "No contacts found" : "Nem találhatók névjegyek",
@@ -284,6 +288,7 @@ OC.L10N.register(
     "Strong password" : "Erős jelszó",
     "No action available" : "Nincs elérhető művelet",
     "Error fetching contact actions" : "Hiba a kapcsolati műveletek lekérésekor",
+    "Close \"{dialogTitle}\" dialog" : "A(z) „{dialogTitle}” párbeszédablak bezárása",
     "Non-existing tag #{tag}" : "Nem létező címke #{tag}",
     "Restricted" : "Korlátozott",
     "Invisible" : "Láthatatlan",
@@ -352,6 +357,7 @@ OC.L10N.register(
     "Skip to main content" : "Ugrás a fő tartalomhoz",
     "Skip to navigation of app" : "Ugrás az alkalmazás navigációjához",
     "Get your own free account" : "Szerezzen saját ingyenes fiókot",
+    "Go to %s" : "Ugrás ide: %s",
     "Confirm your password" : "Erősítse meg a jelszavát:",
     "Connect to your account" : "Kapcsolódás a fiókjához",
     "Please log in before granting %1$s access to your %2$s account." : "Lépjen be mielőtthozzáférést biztosít a(z) %1$s kliensnek a(z) %2$s fiókjához.",
@@ -371,7 +377,6 @@ OC.L10N.register(
     "Email address" : "E-mail-cím",
     "Password sent!" : "Jelszó elküldve.",
     "You are not authorized to request a password for this share" : "Nincs jogosultsága, hogy jelszót kérjen ehhez a megosztáshoz",
-    "Go to %s" : "Ugrás ide: %s",
     "Two-factor authentication" : "Kétfaktoros hitelesítés",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "A fokozott biztonság engedélyezett a fiókja számára. Válasszon egy második faktort a hitelesítéshez.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nem lehet betölteni legalább egy engedélyezett kétfaktoros hitelesítési módot. Lépjen kapcsolatba a rendszergazdával.",
@@ -410,6 +415,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ez a Nextcloud nem támogatott közösségi kiadása. A példány mérete miatt a teljesítménye, megbízhatósága és skálázhatósága nem garantálható. A leküldéses értesítések letiltásra kerültek, hogy ne terheljék túl az ingyenes szolgáltatásunkat. Tudjon meg többet a Nextcloud Enterprise előnyeiről a nextcloud.com/enterprise oldalon.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "A Nextcloud 23 az utolsó olyan kiadás, amely támogatja a PHP 7.3-as verzióját. A Nextcloud 21 legalább PHP 7.4-et igényel.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "A(z) „{header}” HTTP-fejléc nem tartalmazza ezt: „{expected}”. Ez egy lehetséges biztonsági és adatvédelmi kockázat, ezért javasolt, hogy módosítsa megfelelően a beállítást.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Egy jelszó visszaállítási e-mail lett küldve a fiók e-mail-címére. Ha nem kapta meg, akkor ellenőrizze a levélszemét mappát, vagy kérje a helyi rendszergazda segítségét.",
+    "If it is not there ask your local administrator." : "Ha nincs ott, akkor kérdezze a helyi rendszergazdát.",
     "Collaboratively edit office documents." : "Szerkesszen közösen irodai dokumentumokat.",
     "Local document editing back-end used by the Collabora Online app." : "Helyi dokumentumszerkesztési háttérprogram, amit a Collabora Online alkalmazás használ.",
     "restricted" : "korlátozott",
@@ -421,6 +428,8 @@ OC.L10N.register(
     "Contacts" : "Névjegyek",
     "Contacts menu" : "Névjegyek menü",
     "Setup two-factor authentication" : "Kétfaktoros hitelesítés beállítása",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Úgy tűnik, hogy 32 bites PHP verziót használ. A Nextcloud megfelelő futtatásához 64 bites szükséges. Frissítse 64 bitesre az operációs rendszerét és a PHP-ját. További részletekért olvassa el az {linkstart}erről szóló dokumentációs oldalt ↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Úgy tűnik, hogy 32 bites PHP verziót használ. A Nextcloud megfelelő futtatásához 64 bites szükséges. Frissítse 64 bitesre az operációs rendszerét és a PHP-ját. További részletekért olvassa el az {linkstart}erről szóló dokumentációs oldalt ↗{linkend}.",
+    "Press enter to start searching" : "A keresés indításához nyomjon Entert",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Használja a parancssoros frissítőt, mert a böngészőbeli frissítés ki van kapcsolva a config.php fájlban."
 },
 "nplurals=2; plural=(n != 1);");
