@@ -135,8 +135,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Tengingin þín er ekki örugg",
     "Passwordless authentication is only available over a secure connection." : "Lykilorðalaus auðkenning er aðeins tiltæk í gegnum örugga tengingu.",
     "Reset password" : "Endursetja lykilorð",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Tengill til að endurstilla lykilorðið þitt hefur verið sendur á tölvupósfang þessa notandaaðgangs. Ef þú færð ekki póstinn, athugaðu þá ruslpóstmöppurnar þínar eða spurðu kerfisstjórann þinn um mögulegar ástæður þess.",
-    "If it is not there ask your local administrator." : "Ef hann er ekki þar, spurðu þá kerfisstjórann þinn. ",
     "Couldn't send reset email. Please contact your administrator." : "Gat ekki sent endurstillingu í tölvupósti. Hafðu samband við kerfisstjóra.",
     "Password cannot be changed. Please contact your administrator." : "Ekki er hægt að breyta lykilorði. Hafðu samband við kerfisstjóra.",
     "Back to login" : "Til baka í innskráningu",
@@ -172,7 +170,6 @@ OC.L10N.register(
     "Load more results" : "Hlaða inn fleiri niðurstöðum",
     "Search" : "Leita",
     "No results for {query}" : "Engar niðurstöður fyrir {query}",
-    "Press enter to start searching" : "Ýttu á Enter til að hefja leit",
     "An error occurred while searching for {type}" : "Villa kom upp við leit að {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Settu inn {minSearchLength} staf eða fleiri til að leita","Settu inn {minSearchLength} stafi eða fleiri til að leita"],
     "Open settings menu" : "Opna stillingavalmynd",
@@ -314,6 +311,7 @@ OC.L10N.register(
     "Skip to main content" : "Sleppa og fara í meginefni",
     "Skip to navigation of app" : "Hlaupa yfir í flakk innan forrits",
     "Get your own free account" : "Fáðu þér eigin ókeypis aðgang",
+    "Go to %s" : "Farðu í %s",
     "Confirm your password" : "Staðfestu lykilorðið þitt",
     "Connect to your account" : "Tengdu við notandaaðganginn þinn",
     "Please log in before granting %1$s access to your %2$s account." : "Skráðu þig inn áður en þú leyfir %1$s aðgang að %2$s notandaaðgangnum þínum.",
@@ -333,7 +331,6 @@ OC.L10N.register(
     "Email address" : "Tölvupóstfang",
     "Password sent!" : "Lykilorð sent!",
     "You are not authorized to request a password for this share" : "Þú hefur ekki heimild til að biðja um lykilorð fyrir þessa sameign",
-    "Go to %s" : "Farðu í %s",
     "Two-factor authentication" : "Tveggja-þrepa auðkenning",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Aukið öryggi var virkjað fyrir aðganginn þinn. Veldu aukaþrep til auðkenningar:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Gat ekki hlaðið inn a.m.k. einni af virkum tveggja-þrepa auðkenningaraðferðunum þínum. Hafðu samband við kerfisstjóra.",
@@ -371,6 +368,8 @@ OC.L10N.register(
     "[%d / %d]: Checking table %s" : "[%d / %d]: Athuga töflu %s",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 er síðasta útgáfan sem styður PHP 7.3. Nextcloud 24 krefst að minnsta kosti PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP-hausinn inniheldur ekki \"{expected}\". Þetta er möguleg áhætta varðandi öryggi og gagnaleynd, við mælum með því að laga þessa stillingu.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Tengill til að endurstilla lykilorðið þitt hefur verið sendur á tölvupósfang þessa notandaaðgangs. Ef þú færð ekki póstinn, athugaðu þá ruslpóstmöppurnar þínar eða spurðu kerfisstjórann þinn um mögulegar ástæður þess.",
+    "If it is not there ask your local administrator." : "Ef hann er ekki þar, spurðu þá kerfisstjórann þinn. ",
     "Collaboratively edit office documents." : "Vinna í hóp með skrifstofuskjöl.",
     "restricted" : "takmarkaður aðgangur",
     "invisible" : "ósýnilegt",
@@ -380,6 +379,7 @@ OC.L10N.register(
     "More apps menu" : "Valmynd með fleiri forrit",
     "Contacts" : "Tengiliðir",
     "Contacts menu" : "Tengiliðavalmynd",
-    "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu"
+    "Setup two-factor authentication" : "Setja upp tveggja-þátta auðkenningu",
+    "Press enter to start searching" : "Ýttu á Enter til að hefja leit"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
