@@ -25,17 +25,23 @@ OC.L10N.register(
     "State token does not match" : "Токен состояния не совпадает",
     "Invalid app password" : "Неверный пароль приложения",
     "Could not complete login" : "Не удалось завершить вход в систему",
+    "State token missing" : "Отсутствует токен состояния",
     "Your login token is invalid or has expired" : "Ваш токен неверен или истёк",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Используется сборка Nextcloud для сообщества. Данная сборка не поддерживается и имеет ограниченный функционал push-уведомлений.",
     "Login" : "Войти",
+    "Please try again" : "Попробуйте ещё раз",
     "Password reset is disabled" : "Сброс пароля отключён",
     "Could not reset password because the token is expired" : "Не было возможности сбросить пароль в связи с просроченным токеном",
     "Could not reset password because the token is invalid" : "Не было возможности сбросить пароль в связи с неверным токеном",
+    "Password is too long. Maximum allowed length is 469 characters." : " Пароль не может быть длиннее 469 символов.",
     "%s password reset" : "Сброс пароля %s",
     "Password reset" : "Сброс пароля",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на кнопку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на ссылку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
     "Reset your password" : "Сбросить пароль",
+    "No translation provider available" : "Поставщик услуг перевода недоступен",
+    "Could not detect language" : "Не удалось определить язык",
+    "Unable to translate" : "Не удается перевести",
     "Nextcloud Server" : "Сервер Nextcloud",
     "Some of your link shares have been removed" : "Некоторые из ваших ссылок на общие ресурсы были удалены",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Из-за ошибки в безопасности нам пришлось удалить некоторые из ваших ссылок на опубликованные файлы или папки. Перейдите по ссылке для получения дополнительной информации.",
@@ -48,7 +54,7 @@ OC.L10N.register(
     "Repair info:" : "Информация восстановления:",
     "Repair warning:" : "Предупреждение восстановления:",
     "Repair error:" : "Ошибка восстановления:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Автоматические обновления отключены в файле конфигурации  «config.php». Выполните обновление из командной строки.",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Автоматические обновления отключены в файле конфигурации  «config.php». Выполните обновление из командной строки.",
     "Turned on maintenance mode" : "Включён режим обслуживания ",
     "Turned off maintenance mode" : "Отключён режим обслуживания",
     "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
@@ -99,6 +105,7 @@ OC.L10N.register(
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В системе не установлены рекомендуемые модули PHP. Для улучшения производительности и совместимости рекомендуется установить эти модули.",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
     "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Модули «gmp» и / или «bcmath» подсистемы PHP не активированы. Эти модули необходимы при использовании аутентификации без пароля WebAuth.",
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Вероятно, на сервере используется 32-битная версия PHP. Для нормальной работы Nextcloud требуется 64-битная версия. Обновите вашу операционную систему и PHP до 64-битных версий. Для дополнительной информации {linkstart}обратитесь к документации ↗{linkend}.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль php-imagick в этом случае не поддерживает SVG. Для лучшей совместимости рекомендуется установить его.",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Некоторые поля базы данных не были преобразованы в тип big int. Операция преобразования таких полей может занять продолжительное время и должа быть запущена вручную. Чтобы выполнить преобразование, необходимо включить режим обслуживания и запустить в терминале команду «occ db:convert-filecache-bigint». Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "В настоящее время в качестве механизма БД используется SQLite. Для более крупных развёртываний рекомендуется перейти к использованию других баз данных.",
@@ -157,8 +164,7 @@ OC.L10N.register(
     "Your connection is not secure" : "Соединение установлено с использованием небезопасного протокола",
     "Passwordless authentication is only available over a secure connection." : "Безпарольная аутентификация доступна только через защищённое соединение",
     "Reset password" : "Сбросить пароль",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Письмо с инструкциями по сбросу пароля отправлено на адрес электронной почты этой учётной записи. Если это письмо не будет получено, проверьте папку «Спам» или сообщите об этом администратору системы.",
-    "If it is not there ask your local administrator." : "Если письмо не будет получено, сообщите об этом администратору системы.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Если эта учетная запись существует, на ее адрес электронной почты было отправлено сообщение о сбросе пароля. Если вы его не получили, подтвердите свой адрес электронной почты и/или имя учетной записи, проверьте папки со спамом/нежелательной почтой или обратитесь за помощью к Вашему локальному администратору.",
     "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Свяжитесь со своим администратором.",
     "Password cannot be changed. Please contact your administrator." : "Пароль не может быть изменён. Свяжитесь со своим системным администратором.",
     "Back to login" : "Вернуться на страницу входа",
@@ -180,6 +186,8 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простое приложение электронной почты, прекрасно интегрированное с приложениями Files, Contacts и Calendar.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Текстовые сообщения, видеозвонки, демонстрация содержимого экрана, онлайн общение и веб-конференции на ПК и мобильных устройствах. ",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Совместная работа с документами, таблицами и презентациями, основанная на Collabora Online.",
+    "Distraction free note taking app." : "Простые приложение для ведения заметок.",
+    "Search contacts" : "Поиск контактов",
     "Forgot password?" : "Забыли пароль?",
     "Log in with a device" : "Войти с устройства",
     "Back" : "Назад",
@@ -189,15 +197,15 @@ OC.L10N.register(
     "You have not added any info yet" : "Вы ещё не добавили никакой информации",
     "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
     "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
+    "Search starts once you start typing and results may be reached with the arrow keys" : "Поиск начнётся при наборе текста. Для перехода к результатам поиска используйте клавиши со стрелками.",
     "Reset search" : "Очистить поиск",
     "Start search" : "Запустить поиск",
     "Search for {name} only" : "Искать только для «{name}»",
-    "No results for {query}" : "По запросу «{query}» ничего не найдено",
-    "Press enter to start searching" : "Нажмите Enter для запуска поиска",
     "Start typing to search" : "Начините вводить символы для поиска",
     "Loading more results …" : "Загрузка дополнительных результатов…",
     "Load more results" : "Загрузить дополнительные результаты",
     "Search" : "Найти",
+    "No results for {query}" : "По запросу «{query}» ничего не найдено",
     "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Чтобы начать поиск необходимо ввести как минимум  {minSearchLength} символ","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символов","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа"],
     "This browser is not supported" : "Используемый браузер не поддерживается",
@@ -209,6 +217,7 @@ OC.L10N.register(
     "Settings menu" : "Меню настроек",
     "Search {types} …" : "Поиск {types}…",
     "Settings" : "Параметры",
+    "Avatar of {fullName}" : "Изображение профиля {fullName}",
     "Could not load your contacts" : "Ошибка получения контактов",
     "Search contacts …" : "Поиск контакта…",
     "No contacts found" : "Контактов не найдено",
@@ -250,6 +259,7 @@ OC.L10N.register(
     "Show list view" : "Просмотр списком",
     "Show grid view" : "Просмотр сеткой",
     "Pending" : "Ожидается",
+    "Home" : "Главная",
     "Copy to {folder}" : "Скопировать в «{folder}»",
     "Move to {folder}" : "Переместить в «{folder}»",
     "Saving …" : "Сохранение…",
@@ -278,6 +288,7 @@ OC.L10N.register(
     "Strong password" : "Надёжный пароль",
     "No action available" : "Нет доступных действий",
     "Error fetching contact actions" : "Ошибка получения действий контакта",
+    "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
     "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
     "Restricted" : "Ограниченный",
     "Invisible" : "Невидимый",
@@ -346,8 +357,8 @@ OC.L10N.register(
     "Skip to main content" : "Перейти к основному содержанию",
     "Skip to navigation of app" : "Перейти к навигации по приложению",
     "Get your own free account" : "Создайте свою бесплатную учётную запись",
+    "Go to %s" : "Перейти к %s",
     "Confirm your password" : "Подтвердите свой пароль",
-    "%s's homepage" : "Домашняя страница %s",
     "Connect to your account" : "Вход в систему",
     "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
@@ -366,7 +377,6 @@ OC.L10N.register(
     "Email address" : "Адрес эл. почты",
     "Password sent!" : "Пароль отправлен",
     "You are not authorized to request a password for this share" : "У вас недостаточно прав для запроса пароля для доступа к этому общему ресурсу",
-    "Go to %s" : "Перейти к %s",
     "Two-factor authentication" : "Двухфакторная аутентификация",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повышенная безопасность включена для вашей учетной записи. Выберете второй фактор для подтверждения подлинности пользователя.",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Не удалось использовать хотя бы один из двух настроенных способов двуфакторной аутентификации. Обратитесь к администратору.",
@@ -392,6 +402,7 @@ OC.L10N.register(
     "Detailed logs" : "Подробные журналы",
     "Update needed" : "Требуется обновление",
     "Please use the command line updater because you have a big instance with more than 50 users." : "В этом развёртывании создано более 50 пользователей. Используйте инструмент командной строки для выполнения обновления.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Автоматические обновления отключены в файле конфигурации  «config.php». Выполните обновление из командной строки.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Для получения помощи обратитесь к <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документации</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, что в случае продолжения обновления через веб-интерфейс возникает риск тайм-аута запроса, который может привести к потере данных. У меня есть резервная копия, и я знаю, как восстановить систему в случае сбоя.",
     "Upgrade via web on my own risk" : "Обновить используя веб-интерфейс на мой страх и риск",
@@ -404,6 +415,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Это неподдерживаемая сборка сообщества Nextcloud. Размер этого развёртывания не позволяет,  гарантировать производительность, надежность и масштабируемость. Push-уведомления отключены, чтобы не перегружать бесплатный сервис разработчиков Nextcloud. Узнайте больше о преимуществах корпоративной версии Nextcloud на сайте nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 - это последний релиз, поддерживающий PHP 7.3. Для Nextcloud 24 необходимо иметь минимальную версию PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не содержит параметр «{expected}». Это может привести к проблемам  безопасности. Рекомендуется задать этот параметр.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Письмо с инструкциями по сбросу пароля отправлено на адрес электронной почты этой учётной записи. Если это письмо не будет получено, проверьте папку «Спам» или сообщите об этом администратору системы.",
+    "If it is not there ask your local administrator." : "Если письмо не будет получено, сообщите об этом администратору системы.",
     "Collaboratively edit office documents." : "Совместная работа над документами.",
     "Local document editing back-end used by the Collabora Online app." : "Исполняемый на стороне клиента компонент для редактирования документов, используемый приложением Collabora Online.",
     "restricted" : "ограниченный",
@@ -415,6 +428,8 @@ OC.L10N.register(
     "Contacts" : "Контакты",
     "Contacts menu" : "Меню контактов",
     "Setup two-factor authentication" : "Установка двухфакторной аутентификации",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Похоже что вы используете 32-битную версию PHP. Для нормальной работы Nextcloud требуется 64-битная версия. Пожалуйста обновите вашу операционную систему и PHP до 64-битных версий. Для дополнительной информации {linkstart}обратитесь к документации.{linkend}"
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Похоже что вы используете 32-битную версию PHP. Для нормальной работы Nextcloud требуется 64-битная версия. Пожалуйста обновите вашу операционную систему и PHP до 64-битных версий. Для дополнительной информации {linkstart}обратитесь к документации.{linkend}",
+    "Press enter to start searching" : "Нажмите Enter для запуска поиска",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Пожалуйста, используйте обновление из терминала, поскольку обновление через браузер отключено в вашем файле конфигурации config.php."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
