@@ -156,8 +156,6 @@ OC.L10N.register(
     "Your connection is not secure" : "Pripojenie nie je bezpečné",
     "Passwordless authentication is only available over a secure connection." : "Bezheslové overovanie je dostupné len pomocou šifrovaného pripojenia.",
     "Reset password" : "Obnovenie hesla",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Správa s informáciami na zmenu hesla bola zaslaná na email tohoto účtu. Ak nebol doručený, skontrolujte si priečinok nevyžiadanej pošty a kôš, alebo požiadajte svojho administrátora o pomoc.",
-    "If it is not there ask your local administrator." : "Ak tam nie je, pýtajte sa vášho lokálneho administrátora.",
     "Couldn't send reset email. Please contact your administrator." : "Nemožno poslať email pre obnovu. Kontaktujte prosím vášho administrátora.",
     "Password cannot be changed. Please contact your administrator." : "Heslo nemožno zmeniť. Kontaktujte prosím vášho administrátora.",
     "Back to login" : "Späť na prihlásenie",
@@ -196,7 +194,6 @@ OC.L10N.register(
     "Load more results" : "Načítať viac výsledkov",
     "Search" : "Hľadať",
     "No results for {query}" : "Žiadne výsledky pre {query}",
-    "Press enter to start searching" : "Stlačte enter pre vyhľadávanie",
     "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Pre vyhľadávanie zadajte aspoň {minSearchLength} znak","Pre vyhľadávanie zadajte aspoň {minSearchLength} znaky","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov"],
     "This browser is not supported" : "Tento prehliadač nie je podporovaný",
@@ -346,6 +343,7 @@ OC.L10N.register(
     "Skip to main content" : "Prejsť na hlavný obsah",
     "Skip to navigation of app" : "Preskočiť do navigácie apky",
     "Get your own free account" : "Získajte zdarma svoj vlastný účet",
+    "Go to %s" : "Prejsť na %s",
     "Confirm your password" : "Potvrďte svoje heslo",
     "Connect to your account" : "Pripojte sa k svojmu účtu",
     "Please log in before granting %1$s access to your %2$s account." : "Skôr než udelíte prístup pre %1$s do vášho účtu %2$s je potrebné sa prihlásiť.",
@@ -365,7 +363,6 @@ OC.L10N.register(
     "Email address" : "E-mailová adresa",
     "Password sent!" : "Heslo odoslané!",
     "You are not authorized to request a password for this share" : "Nemáte oprávnenie žiadať o heslo pre toto zdieľanie",
-    "Go to %s" : "Prejsť na %s",
     "Two-factor authentication" : "Dvojzložkové overovanie",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Vylepšená bezpečnosť je pre váš účet povolená. Vyberte druhý faktor overenia:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Nedá sa načíťať minimálne jeden z vašich povolených spôsobov na dvojzložkové overovanie. Kontaktujte prosím správcu systému.",
@@ -404,6 +401,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Toto je nepodporovaná komunitná verzia Nextcloud. Vzhľadom na veľkosť tejto inštancie nemožno zaručiť výkon, spoľahlivosť a škálovateľnosť. Push notifikácie boli deaktivované, aby sa predišlo preťaženiu našej bezplatnej služby. Získajte viac informácií o výhodách Nextcloud Enterprise na nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 je posledné vydanie podporujúce PHP 7.3. Nextcloud 24 vyžaduje aspoň PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" neobsahuje \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Správa s informáciami na zmenu hesla bola zaslaná na email tohoto účtu. Ak nebol doručený, skontrolujte si priečinok nevyžiadanej pošty a kôš, alebo požiadajte svojho administrátora o pomoc.",
+    "If it is not there ask your local administrator." : "Ak tam nie je, pýtajte sa vášho lokálneho administrátora.",
     "Collaboratively edit office documents." : "Spolupracujte na úprave kancelárskych dokumentov.",
     "Local document editing back-end used by the Collabora Online app." : "Miestna úprava dokumentov využíva aplikáciu Collabora Online.",
     "restricted" : "obmedzený",
@@ -415,6 +414,7 @@ OC.L10N.register(
     "Contacts" : "Kontakty",
     "Contacts menu" : "Menu kontaktov",
     "Setup two-factor authentication" : "Nastaviť dvojzložkové overovanie",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Zdá sa, že používate 32-bitovú verziu PHP. Nextcloud potrebuje 64-bit, aby fungoval dobre. Inovujte svoj OS a PHP na 64-bitové! Ďalšie podrobnosti nájdete na {linkstart}stránke dokumentácie↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Zdá sa, že používate 32-bitovú verziu PHP. Nextcloud potrebuje 64-bit, aby fungoval dobre. Inovujte svoj OS a PHP na 64-bitové! Ďalšie podrobnosti nájdete na {linkstart}stránke dokumentácie↗{linkend}.",
+    "Press enter to start searching" : "Stlačte enter pre vyhľadávanie"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
