@@ -39,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следеће дугме за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следећу везу за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
     "Reset your password" : "Ресетуј лозинку",
+    "No translation provider available" : "Није доступан ниједан пружалац услиге превода",
+    "Could not detect language" : "Не може да се детектује језик",
+    "Unable to translate" : "Не може да се преведе",
     "Nextcloud Server" : "Nextcloud сервер",
     "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
@@ -161,8 +164,7 @@ OC.L10N.register(
     "Your connection is not secure" : "Ваша веза није безбедна",
     "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
     "Reset password" : "Ресетуј лозинку",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "На е-мејл адресу овог налога је послата порука за ресетовање лозинке. Ако је не примите, проверите фолдере за нежељену пошту/отпад или потражите помоћ од свог локалног администратора.",
-    "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или назив налога, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
     "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
     "Password cannot be changed. Please contact your administrator." : "Лозинка не може да се промени. Молимо вас контактирајте администратора.",
     "Back to login" : "Назад на пријаву",
@@ -204,7 +206,6 @@ OC.L10N.register(
     "Load more results" : "Учитај још резултата",
     "Search" : "Претражи",
     "No results for {query}" : "Нема резултата за упит {query}",
-    "Press enter to start searching" : "Притисните ентер да започнете претрагу",
     "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали"],
     "This browser is not supported" : "Овај веб читач није подржан",
@@ -356,7 +357,7 @@ OC.L10N.register(
     "Skip to main content" : "Прескочи на главни садржај",
     "Skip to navigation of app" : "Прескочи на навигацију апликације",
     "Get your own free account" : "Узмите бесплатан налог",
-    "%s homepage" : "%s почетна страна",
+    "Go to %s" : "Иди на %s",
     "Confirm your password" : "Потврдите лозинку",
     "Connect to your account" : "Повежите се на Ваш налог",
     "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
@@ -376,7 +377,6 @@ OC.L10N.register(
     "Email address" : "Адреса е-поште",
     "Password sent!" : "Лозинка је послата!",
     "You are not authorized to request a password for this share" : "Немате право да за овај дељени ресурс тражите лозинку",
-    "Go to %s" : "Иди на %s",
     "Two-factor authentication" : "Двофакторска провера идентитета",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
@@ -415,6 +415,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су искључена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 је последње издање које подржава PHP 7.3. Nextcloud 24 захтева барем PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "На е-мејл адресу овог налога је послата порука за ресетовање лозинке. Ако је не примите, проверите фолдере за нежељену пошту/отпад или потражите помоћ од свог локалног администратора.",
+    "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
     "Collaboratively edit office documents." : "Уређујте документа заједно.",
     "Local document editing back-end used by the Collabora Online app." : "Позадински мотор за локално уређивање докумената који користи Collabora апликацију.",
     "restricted" : "ограничено",
@@ -426,6 +428,8 @@ OC.L10N.register(
     "Contacts" : "Контакти",
     "Contacts menu" : "Мени контаката",
     "Setup two-factor authentication" : "Подеси двофакторску проверу идентитета",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изгледа да покрећете 32-битну PHP верзију. За правилно извршавање Nextcloud захтева 64-битну верзију. Молимо вас да ажурирате свој оперативни систем и PHP на 64-бита! За више детаља прочитајте {linkstart}страницу документације која се бави овим проблемом ↗{linkend}."
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изгледа да покрећете 32-битну PHP верзију. За правилно извршавање Nextcloud захтева 64-битну верзију. Молимо вас да ажурирате свој оперативни систем и PHP на 64-бита! За више детаља прочитајте {linkstart}страницу документације која се бави овим проблемом ↗{linkend}.",
+    "Press enter to start searching" : "Притисните ентер да започнете претрагу",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Молимо вас да користите алат за ажурирање из командне линије јер је ажурирање из прегледача искључено у вашем config.php."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
