@@ -25,6 +25,7 @@ OC.L10N.register(
     "State token does not match" : "Tillstånds-token matchar inte",
     "Invalid app password" : "Felaktigt app-lösenord",
     "Could not complete login" : "Kunde inte slutföra inloggningen",
+    "State token missing" : "Statustoken saknas",
     "Your login token is invalid or has expired" : "Din inloggnings-token är ogiltigt eller har gått ut",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Denna community-release av Nextcloud stöds inte och pushnotifikationer är begränsade.",
     "Login" : "Logga in",
@@ -38,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på knappen för att återställa ditt lösenord.  Om du inte har begärt att återställa ditt lösenord så kan du ignorera detta epost, inget kommer då att ske.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klicka på länken för att återställa ditt lösenord. Om du inte har begärt att lösenordet ska återställas så kan du ignorera detta epost.",
     "Reset your password" : "Återställ ditt lösenord",
+    "No translation provider available" : "Ingen översättning tillgänglig",
+    "Could not detect language" : "Kunde inte identifiera språk",
+    "Unable to translate" : "Kan inte översätta",
     "Nextcloud Server" : "Nextcloud-server",
     "Some of your link shares have been removed" : "Några av dina delade länkar har tagits bort",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grund av ett säkerhetsfel var vi tvungna att ta bort några av dina delade länkar. Se länken för mer information.",
@@ -50,7 +54,7 @@ OC.L10N.register(
     "Repair info:" : "Reparationsinfo:",
     "Repair warning:" : "Reperationsvarning:",
     "Repair error:" : "Reperationsfel:",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Uppdatera via kommandotolken då automatisk uppdatering är inaktiverat i config.php.",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Var vänlig och uppdatera via kommandotolken då uppdatering via webbläsaren är inaktiverat i config.php",
     "Turned on maintenance mode" : "Aktiverade underhållsläge",
     "Turned off maintenance mode" : "Inaktivera underhållsläge",
     "Maintenance mode is kept active" : "Underhållsläget förblir aktiverat",
@@ -87,11 +91,16 @@ OC.L10N.register(
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen lämplig källa för slumpmässighet hittas av PHP, Detta avråder vi från starkt på grund av säkerhetsskäl. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Du kör för nuvarande PHP {version}. Uppgradera din PHP version för att dra nytta av {linkstart}prestanda och säkerhetsuppdateringar tillhandahållna av PHP Group ↗{linkend} så snart din servermiljö stödjer det.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfigurationen av den omvända proxyhuvudet är felaktig, eller så använder du Nextcloud från en betrodd proxy. Om inte, är detta ett säkerhetsproblem och kan tillåta en angripare att förfalska sin IP-adress som synlig för Nextcloud. Mer information finns i {linkstart}dokumentationen ↗{linkend}.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Några filer har inte klarat integritetskontrollen. Vidare information om hur man löser detta problem kan hittas i {linkstart1}dokumentationen↗{linkend}. ({linkstart2}Lista med de ogiltiga filerna…{linkend} / {linkstart3}Scanna igen…{linkend})",
+    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modulen är felaktigt inställd. Se {linkstart}dokumentationen ↗{linkend} för mer information",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktionen \"set_time_limit\" är inte tillgänglig. Detta kan leda till att skript stoppas i mitten av utförandet och bryter din installation. Aktivering av denna funktion rekommenderas starkt.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Din PHP har inte FreeType-stöd, vilket resulterar i brott i profilbilder och inställningsgränssnittet.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Saknar index \"{indexName}\" i tabellen \"{tableName}\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Databasen saknar några index. Dessa adderas inte automatsikt då indexering av stora tabeller kan ta tid. Med kommandot  \"occ db:add-missing-indices\" kan de saknade indices läggas till manuellt utan att instansen behöver stoppas. Indexerade tabeller ger oftast mycket snabbare svar.",
+    "Missing primary key on table \"{tableName}\"." : "Saknar primärnyckel i tabellen \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Databasen saknar några primärnycklar. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-primary-keys\" läggs de saknade primärnycklarna till utan att instansen behöver stoppas.",
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Saknar den valfria kolumnen \"{columnName}\" i tabell \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Databasen saknar några valfria kolumner. Eftersom att lägga till sådana i stora tabeller kan ta en del tid, har det inte gjorts automatiskt. Genom att köra kommandot \"occ db:add-missing-columns\" läggs de saknade kolumnerna till utan att instansen behöver stoppas. Att lägga till de valfria kolumnerna kan förbättra svarstid eller användbarhet.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instansen saknar några rekommenderade PHP-moduler. För förbättrad prestanda och kompatibilitet är det starkt rekommenderat att installera dem.",
     "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modulen php-image har i det här fallet inget SVG-stöd. För bättre kompatibilitet rekommenderas det att installera det.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite används som databas. För större installationer så rekommenderar vi ett byte till en annan databasbackend.",
@@ -141,8 +150,7 @@ OC.L10N.register(
     "Your connection is not secure" : "Din anslutning är inte säker",
     "Passwordless authentication is only available over a secure connection." : "Lösenordsfri autentisering är endast tillgänglig via en säker anslutning.",
     "Reset password" : "Återställ lösenord",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Ett meddelande om lösenordsåterställning har skickats till e-postadressen för det här kontot. Om du får det, kontrollera dina spam/skräp -mappar eller fråga din lokala administratör om hjälp.",
-    "If it is not there ask your local administrator." : "Om det inte finns, fråga din lokala administratör.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Om det här kontot finns har ett meddelande om lösenordsåterställning skickats till dess e-postadress. Om du inte får det, verifiera din e-postadress och/eller kontonamn, kontrollera dina skräppost-/skräpmappar eller be din lokala administration om hjälp.",
     "Couldn't send reset email. Please contact your administrator." : "Kunde inte skicka återställningsmejl. Kontakta din administratör.",
     "Password cannot be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
     "Back to login" : "Tillbaka till inloggning",
@@ -177,12 +185,11 @@ OC.L10N.register(
     "Reset search" : "Återställ sökning",
     "Start search" : "Starta sökning",
     "Search for {name} only" : "Sök efter endast {name}",
-    "No results for {query}" : "Inga resultat för {query}",
-    "Press enter to start searching" : "Tryck på enter för att börja söka",
     "Start typing to search" : "Börja skriva för att söka",
     "Loading more results …" : "Hämtar fler resultat ...",
     "Load more results" : "Hämta fler resultat",
     "Search" : "Sök",
+    "No results for {query}" : "Inga resultat för {query}",
     "An error occurred while searching for {type}" : "Ett fel uppstod vid sökning efter {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Ange {minSearchLength} tecken eller mer för att söka","Ange {minSearchLength} tecken eller mer för att söka"],
     "This browser is not supported" : "Den här webbläsaren stöds inte",
@@ -194,6 +201,7 @@ OC.L10N.register(
     "Settings menu" : "Inställningsmeny",
     "Search {types} …" : "Sök {types} …",
     "Settings" : "Inställningar",
+    "Avatar of {fullName}" : "Avatar för {fullName}",
     "Could not load your contacts" : "Det gick inte att läsa in dina kontakter",
     "Search contacts …" : "Sök kontakter ...",
     "No contacts found" : "Inga kontakter hittades",
@@ -235,6 +243,7 @@ OC.L10N.register(
     "Show list view" : "Visa listvy",
     "Show grid view" : "Visa rutnätsvy",
     "Pending" : "Väntar",
+    "Home" : "Hem",
     "Copy to {folder}" : "Kopiera till {folder}",
     "Move to {folder}" : "Flytta till {folder}",
     "Saving …" : "Sparar ...",
@@ -263,6 +272,7 @@ OC.L10N.register(
     "Strong password" : "Starkt lösenord",
     "No action available" : "Ingen åtgärd tillgänglig",
     "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
+    "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
     "Non-existing tag #{tag}" : "Icke-existerande tag #{tag}",
     "Restricted" : "Begränsad",
     "Invisible" : "Osynlig",
@@ -331,8 +341,8 @@ OC.L10N.register(
     "Skip to main content" : "Skippa till huvudinnehållet",
     "Skip to navigation of app" : "Skippa till navigering av app",
     "Get your own free account" : "Skaffa ett eget gratiskonto",
+    "Go to %s" : "Gå till %s",
     "Confirm your password" : "Bekräfta ditt lösenord",
-    "%s's homepage" : "%s's hemsida",
     "Connect to your account" : "Anslut ditt konto",
     "Please log in before granting %1$s access to your %2$s account." : "Logga in innan du ger %1$s åtkomst till ditt %2$s konto.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Om du inte försöker konfigurera en ny enhet eller app, försöker någon lura dig att ge dem åtkomst till din data. Fortsätt i så fall inte, utan kontakta istället din systemadministratör.",
@@ -351,7 +361,6 @@ OC.L10N.register(
     "Email address" : "E-postadress",
     "Password sent!" : "Lösenord skickat!",
     "You are not authorized to request a password for this share" : "Du har inte behörighet att begära ett lösenord för denna delning",
-    "Go to %s" : "Gå till %s",
     "Two-factor authentication" : "Tvåfaktorsautentisering",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Förbättrad säkerhet är aktiverad för ditt konto. Välj en andra faktor för autentisering:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Det gick inte att läsa in minst en av dina aktiverade tvåfaktorsautentiseringsmetoder. Vänligen kontakta din systemadministratören.",
@@ -377,6 +386,7 @@ OC.L10N.register(
     "Detailed logs" : "Detaljerade loggar",
     "Update needed" : "Uppdatering krävs",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Vänligen uppdatera med kommando eftersom du har en stor instans med mer än 50 användare.",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Uppdatera via kommandotolken då automatisk uppdatering är inaktiverat i config.php.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "För hjälp, se  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentationen</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jag vet att om jag fortsätter göra uppdateringen via webbgränssnittet innebär risken att begäran får timeout och kan orsaka dataförluster men att jag har en backup och vet hur instansen återställs i fall fel uppstår.",
     "Upgrade via web on my own risk" : "Uppgradera via webben på min egen risk",
@@ -389,6 +399,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Detta är Nextclouds communitybygge som inte supporteras. Med tanke på storleken på denna instans kan prestanda, tillförlitlighet och skalbarhet inte garanteras. Push-meddelanden har inaktiverats för att undvika överbelastning av vår gratistjänst. Lär dig mer om fördelarna med Nextcloud Enterprise på nextcloud.com/enterprise.",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 är den sista versionen som stödjer PHP 7.3. Nextcloud 24 kräver minst PHP 7.4.",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-rubriken \"{header}\" innehåller inte \"{expected}\". Det innebär en potentiell säkerhetsrisk. Det är rekommenderat att ändra inställningen.",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Ett meddelande om lösenordsåterställning har skickats till e-postadressen för det här kontot. Om du får det, kontrollera dina spam/skräp -mappar eller fråga din lokala administratör om hjälp.",
+    "If it is not there ask your local administrator." : "Om det inte finns, fråga din lokala administratör.",
     "Collaboratively edit office documents." : "Redigera dokument tillsammans.",
     "Local document editing back-end used by the Collabora Online app." : "Lokal dokumentredigering back-end som används av Collabora Online-appen.",
     "restricted" : "begränsad",
@@ -399,6 +411,7 @@ OC.L10N.register(
     "More apps menu" : "Fler appar - meny",
     "Contacts" : "Kontakter",
     "Contacts menu" : "Kontaktmeny",
-    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering"
+    "Setup two-factor authentication" : "Ställ in tvåfaktorsautentisering",
+    "Press enter to start searching" : "Tryck på enter för att börja söka"
 },
 "nplurals=2; plural=(n != 1);");
