@@ -39,6 +39,9 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請忽略這封信件。",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。 如果您沒有要求重設密碼的話，請忽略這封信件。",
     "Reset your password" : "重設密碼",
+    "No translation provider available" : "沒有可用的翻譯提供者",
+    "Could not detect language" : "無法偵測語言",
+    "Unable to translate" : "無法翻譯",
     "Nextcloud Server" : "Nextcloud 伺服器",
     "Some of your link shares have been removed" : "部分分享連結己被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
@@ -51,7 +54,7 @@ OC.L10N.register(
     "Repair info:" : "修復資訊：",
     "Repair warning:" : "修復警告：",
     "Repair error:" : "修復錯誤：",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列更新系統。",
+    "Please use the command line updater because updating via the browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
     "Turned on maintenance mode" : "啟用維護模式",
     "Turned off maintenance mode" : "停用維護模式",
     "Maintenance mode is kept active" : "伺服器正處於維護模式",
@@ -161,8 +164,7 @@ OC.L10N.register(
     "Your connection is not secure" : "您的連線不安全",
     "Passwordless authentication is only available over a secure connection." : "無密碼身份驗證僅支援經加密的連線。",
     "Reset password" : "重設密碼",
-    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
-    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號名稱，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
     "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
     "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
     "Back to login" : "回到登入畫面",
@@ -184,6 +186,7 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機應用程式之中。",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的協作文件、試算表與簡報。",
+    "Distraction free note taking app." : "無干擾的筆記應用程式。",
     "Search contacts" : "搜尋聯絡人",
     "Forgot password?" : "忘記密碼？",
     "Log in with a device" : "使用免密碼裝置登入",
@@ -198,12 +201,11 @@ OC.L10N.register(
     "Reset search" : "重置搜尋",
     "Start search" : "開始搜尋",
     "Search for {name} only" : "僅搜尋 {name}",
-    "No results for {query}" : "{query} 查詢沒有結果",
-    "Press enter to start searching" : "按 Enter 以開始搜尋",
     "Start typing to search" : "開始輸入以搜尋",
     "Loading more results …" : "正在載入更多結果…",
     "Load more results" : "載入更多結果",
     "Search" : "搜尋",
+    "No results for {query}" : "{query} 查詢沒有結果",
     "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
     "This browser is not supported" : "不支援此瀏覽器",
@@ -215,6 +217,7 @@ OC.L10N.register(
     "Settings menu" : "設定選單",
     "Search {types} …" : "搜尋 {types} 中……",
     "Settings" : "設定",
+    "Avatar of {fullName}" : "{fullName} 的大頭照",
     "Could not load your contacts" : "無法載入您的聯絡人",
     "Search contacts …" : "搜尋聯絡人……",
     "No contacts found" : "查無聯絡人",
@@ -256,6 +259,7 @@ OC.L10N.register(
     "Show list view" : "顯示清單檢視",
     "Show grid view" : "顯示網格檢視",
     "Pending" : "擱置中",
+    "Home" : "家",
     "Copy to {folder}" : "複製到 {folder}",
     "Move to {folder}" : "移動到 {folder}",
     "Saving …" : "儲存中……",
@@ -284,6 +288,7 @@ OC.L10N.register(
     "Strong password" : "密碼安全性極佳",
     "No action available" : "沒有可用的動作",
     "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
+    "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
     "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
     "Restricted" : "受限",
     "Invisible" : "隱藏",
@@ -352,9 +357,8 @@ OC.L10N.register(
     "Skip to main content" : "跳到主內容",
     "Skip to navigation of app" : "跳到應用程式導覽",
     "Get your own free account" : "取得免費帳號",
-    "%s homepage" : "%s 的首頁",
+    "Go to %s" : "前往 %s",
     "Confirm your password" : "確認密碼",
-    "%s's homepage" : "%s 的首頁",
     "Connect to your account" : "連結您的帳號",
     "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若您並未嘗試設定新裝置或應用程式，那麼某人可能正在欺騙您讓他們存取您的資料。在這種情況下，請不要繼續，請聯絡您的系統管理員。",
@@ -373,7 +377,6 @@ OC.L10N.register(
     "Email address" : "電子郵件地址",
     "Password sent!" : "密碼已傳送！",
     "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
-    "Go to %s" : "前往 %s",
     "Two-factor authentication" : "雙因素驗證",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的帳號已啟用進階安全機制，請選擇一個雙因素驗證方法：",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何一個雙因素認證方法，請聯絡管理員",
@@ -399,6 +402,7 @@ OC.L10N.register(
     "Detailed logs" : "詳細記錄檔",
     "Update needed" : "需要更新",
     "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過 50 名使用者，服務規模較大，請透過命令列介面更新。",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列更新系統。",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁介面更新，我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
     "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
@@ -411,6 +415,8 @@ OC.L10N.register(
     "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
     "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 將是支援 PHP 7.3 的最後一個版本，Nextcloud 24 僅支援 PHP 7.4 以上的 PHP。",
     "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不包含 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
+    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
+    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
     "Collaboratively edit office documents." : "協同編輯辦公室文件。",
     "Local document editing back-end used by the Collabora Online app." : "由 Collabora Online 應用程式使用的本機文件編輯後端。",
     "restricted" : "受限",
@@ -422,6 +428,8 @@ OC.L10N.register(
     "Contacts" : "聯絡人",
     "Contacts menu" : "聯絡人選單",
     "Setup two-factor authentication" : "設定雙因素驗證",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。"
+    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。",
+    "Press enter to start searching" : "按 Enter 以開始搜尋",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。"
 },
 "nplurals=1; plural=0;");
