@@ -20,6 +20,7 @@ OC.L10N.register(
     "Unknown filetype" : "نوع الملف غير معروف",
     "Invalid image" : "الصورة غير صالحة",
     "Avatar image is not square" : "الصورة الرمزية ليست على شكل مربّع",
+    "Files" : "الملفات",
     "today" : "اليوم",
     "tomorrow" : "غدًا",
     "yesterday" : "يوم أمس",
@@ -51,7 +52,7 @@ OC.L10N.register(
     "Address" : "العنوان",
     "Profile picture" : "صورة الملف الشخصي",
     "About" : "عن",
-    "Full name" : "الاسم الكامل",
+    "Display name" : "الاسم المعروض",
     "Role" : "الدور",
     "Unknown user" : "المستخدم غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
@@ -124,7 +125,9 @@ OC.L10N.register(
     "Authentication error" : "لم يتم التأكد من الشخصية بنجاح",
     "Token expired. Please reload page." : "انتهت صلاحية الكلمة , يرجى اعادة تحميل الصفحة",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "تضبيط الإعدادات في ملف php.ini سوف يُمكّن نيكست كلاود من العمل مجدداً",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "نحتاج النسخة 2.7.0 من libxml2 على الأقل. النسخة المتوافرة حالياً هي %s",
     "Storage is temporarily not available" : "وحدة التخزين غير متوفرة",
+    "Full name" : "الاسم الكامل",
     "%s enter the database username and name." : "%s أدخِل اسم قاعدة البيانات واسم مستخدمها.",
     "%s enter the database username." : "%s ادخل اسم المستخدم الخاص بقاعدة البيانات.",
     "%s enter the database name." : "%s ادخل اسم فاعدة البيانات",
