@@ -56,6 +56,7 @@ OC.L10N.register(
     "Unknown filetype" : "Ismeretlen fájltípus",
     "Invalid image" : "Érvénytelen kép",
     "Avatar image is not square" : "A profilkép nem négyzetes.",
+    "Files" : "Fájlok",
     "View profile" : "Profil megtekintése",
     "Local time: %s" : "Helyi idő: %s",
     "today" : "ma",
@@ -113,7 +114,7 @@ OC.L10N.register(
     "Address" : "Cím",
     "Profile picture" : "Profilkép",
     "About" : "Névjegy",
-    "Full name" : "Teljes név",
+    "Display name" : "Megjelenítendő név",
     "Headline" : "Címsor",
     "Organisation" : "Szervezet",
     "Role" : "Szerepkör",
@@ -264,6 +265,7 @@ OC.L10N.register(
     "Storage connection error. %s" : "Tároló kapcsolódási hiba. %s",
     "Storage is temporarily not available" : "A tároló átmenetileg nem érhető el",
     "Storage connection timeout. %s" : "Időtúllépés a tárolókapcsolatban. %s",
+    "Full name" : "Teljes név",
     "%s enter the database username and name." : "%s adja meg az adatbázis nevét és a felhasználónevet.",
     "%s enter the database username." : "%s adja meg az adatbázishoz tartozó felhasználónevet.",
     "%s enter the database name." : "%s adja meg az adatbázis nevét.",
