@@ -56,7 +56,9 @@ OC.L10N.register(
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
     "Avatar image is not square" : "アバター画像が正方形ではありません",
+    "Files" : "ファイル",
     "View profile" : "プロフィールを表示",
+    "Local time: %s" : "現地時間: %s",
     "today" : "今日",
     "tomorrow" : "明日",
     "yesterday" : "昨日",
@@ -101,6 +103,8 @@ OC.L10N.register(
     "Users" : "ユーザー",
     "Email" : "メール",
     "Mail %s" : "メール %s",
+    "Fediverse" : "フェディバース",
+    "View %s on the fediverse" : "%sをフェディバース上で見る",
     "Phone" : "携帯",
     "Call %s" : "電話 %s",
     "Twitter" : "Twitter",
@@ -110,7 +114,6 @@ OC.L10N.register(
     "Address" : "アドレス",
     "Profile picture" : "プロフィールの写真",
     "About" : "詳細",
-    "Full name" : "フルネーム",
     "Headline" : "見出し",
     "Organisation" : "組織",
     "Role" : "ロール",
@@ -202,6 +205,7 @@ OC.L10N.register(
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "このユーザー名はすでに使われています",
     "Could not create user" : "ユーザーを作成できませんでした",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
@@ -260,6 +264,7 @@ OC.L10N.register(
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
+    "Full name" : "フルネーム",
     "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
