@@ -33,7 +33,7 @@ OC.L10N.register(
     "Invalid image" : "잘못된 사진",
     "Avatar image is not square" : "아바타 사진이 정사각형이 아님",
     "Files" : "파일",
-    "View profile" : "프로파일 보기",
+    "View profile" : "프로필 보기",
     "today" : "오늘",
     "tomorrow" : "내일",
     "yesterday" : "어제",
@@ -81,7 +81,6 @@ OC.L10N.register(
     "Address" : "주소",
     "Profile picture" : "프로필 사진",
     "About" : "정보",
-    "Full name" : "전체 이름",
     "Headline" : "표제",
     "Organisation" : "조직",
     "Role" : "직책",
@@ -193,6 +192,7 @@ OC.L10N.register(
     "Storage connection error. %s" : "저장소 연결 오류입니다. %s",
     "Storage is temporarily not available" : "저장소를 임시로 사용할 수 없음",
     "Storage connection timeout. %s" : "저장소 연결 시간이 초과되었습니다. %s",
+    "Full name" : "전체 이름",
     "%s enter the database username and name." : "%s 데이터베이스 사용자 이름과 이름을 입력해 주십시오.",
     "%s enter the database username." : "%s 데이터베이스 사용자 이름을 입력해 주십시오.",
     "%s enter the database name." : "%s 데이터베이스 이름을 입력하십시오.",
