@@ -112,9 +112,9 @@ OC.L10N.register(
     "Website" : "Веб страна",
     "Visit %s" : "Посети %s",
     "Address" : "Адреса",
-    "Profile picture" : "Фотографија за профил",
+    "Profile picture" : "Фотографија",
     "About" : "За",
-    "Full name" : "Цело име",
+    "Display name" : "Име и презиме",
     "Headline" : "Наслов",
     "Organisation" : "Организација",
     "Role" : "Улога",
@@ -265,6 +265,7 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Storage connection timeout. %s" : "Поврзувањето со складиштето не успеа. %s",
+    "Full name" : "Цело име",
     "%s enter the database username and name." : "%s внесете го корисничкото име и името на базата.",
     "%s enter the database username." : "%s внеси го корисничкото име за базата.",
     "%s enter the database name." : "%s внеси го името на базата.",
