@@ -28,7 +28,6 @@ OC.L10N.register(
     "Address" : "хаяг",
     "Profile picture" : "Профайл зураг",
     "About" : "Тухай",
-    "Full name" : "бүтэн нэр",
     "Unknown user" : "  хэрэглэгч",
     "Open »%s«" : "»%s« нээх",
     "Sunday" : "ням гариг",
@@ -42,6 +41,7 @@ OC.L10N.register(
     "November" : "Арван нэгдүгээр сар",
     "a safe home for all your data" : "Таны өгөгдлүүдийн аюулгүй гэр",
     "Authentication error" : "Нотолгооны алдаа",
-    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна"
+    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна",
+    "Full name" : "бүтэн нэр"
 },
 "nplurals=2; plural=(n != 1);");
