@@ -1,6 +1,7 @@
 OC.L10N.register(
     "lib",
     {
+    "The page could not be found on the server." : "Se podiá pas trobar la pagina sul servidor.",
     "Other activities" : "Autras activitats",
     "Authentication" : "Autentificacion",
     "Unknown filetype" : "filetype desconegut",
@@ -42,7 +43,6 @@ OC.L10N.register(
     "Address" : "Adreça",
     "Profile picture" : "Imatge de perfil",
     "About" : "A prepaus",
-    "Full name" : "Nom complèt",
     "Headline" : "Títol",
     "Organisation" : "Organizacion",
     "Role" : "Ròtle",
@@ -72,6 +72,7 @@ OC.L10N.register(
     "User disabled" : "Utilizaire desactivat",
     "a safe home for all your data" : "un ostal segur per vòstras donadas",
     "Authentication error" : "Error d’autentificacion",
-    "Storage is temporarily not available" : "Emmagazinatge temporàriament indisponible"
+    "Storage is temporarily not available" : "Emmagazinatge temporàriament indisponible",
+    "Full name" : "Nom complèt"
 },
 "nplurals=2; plural=(n > 1);");
